(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8486,        287]*)
(*NotebookOutlinePosition[      9199,        312]*)
(*  CellTagsIndexPosition[      9155,        308]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1. Getting Started", "Title",
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*`\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "1.0   Differences between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1 (used here) and v.2.x (used in the textbook)"
}], "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[TextData[{
  "1.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1 permits use of Greek letters, superscripts, subscripts, and \
mathematical notation."
}], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(\(fn\  = \ \ 
      Sqrt[x]\  - z^\((1/3)\) + \ Cos[\[Omega]\ t\  + \ \[Phi]]\  + \ 
        Sin[\[CapitalTheta]]\ \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "2.  The ",
  StyleBox["Simplify",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " operation is more extensive in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1,  and the new operation ",
  StyleBox["FullSimplify",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " is even more powerful.\nSee also Section 1.2.3 for examples."
}], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(\(y1 = 
      \((\[Sqrt]\((
              a\^4 - 2\ a\^6 + a\^8 - 2\ a\^2\ b\^2 - 6\ a\^4\ b\^2 + 
                4\ a\^6\ b\^2 + b\^4 - 6\ a\^2\ b\^4 + 6\ a\^4\ b\^4 - 
                2\ b\^6 + 4\ a\^2\ b\^6 + b\^8 - 8\ a\^5\ b\ c + 
                8\ a\^7\ b\ c - 16\ a\^3\ b\^3\ c + 24\ a\^5\ b\^3\ c - 
                8\ a\ b\^5\ c + 24\ a\^3\ b\^5\ c + 8\ a\ b\^7\ c - 
                8\ a\^4\ b\^2\ c\^2 + 24\ a\^6\ b\^2\ c\^2 - 
                8\ a\^2\ b\^4\ c\^2 + 48\ a\^4\ b\^4\ c\^2 + 
                24\ a\^2\ b\^6\ c\^2 + 32\ a\^5\ b\^3\ c\^3 + 
                32\ a\^3\ b\^5\ c\^3 + 16\ a\^4\ b\^4\ c\^4)\))\)/
        \((\[Sqrt]\((
              a\^4 - 2\ a\^6 + a\^8 - 2\ a\^2\ b\^2 - 2\ a\^4\ b\^2 + 
                4\ a\^6\ b\^2 + b\^4 + 2\ a\^2\ b\^4 + 6\ a\^4\ b\^4 + 
                2\ b\^6 + 4\ a\^2\ b\^6 + b\^8 - 8\ a\^5\ b\ c + 
                8\ a\^7\ b\ c + 24\ a\^5\ b\^3\ c + 8\ a\ b\^5\ c + 
                24\ a\^3\ b\^5\ c + 8\ a\ b\^7\ c - 8\ a\^4\ b\^2\ c\^2 + 
                24\ a\^6\ b\^2\ c\^2 + 8\ a\^2\ b\^4\ c\^2 + 
                48\ a\^4\ b\^4\ c\^2 + 24\ a\^2\ b\^6\ c\^2 + 
                32\ a\^5\ b\^3\ c\^3 + 32\ a\^3\ b\^5\ c\^3 + 
                16\ a\^4\ b\^4\ c\^4)\))\); \)\)], "Input"],

Cell[BoxData[
    \(y1 // Simplify\)], "Input"],

Cell[BoxData[
    \(y1 // FullSimplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "3.  The packages \"Algebra`Trigonometry`\" and \"Algebra`SymbolicSum`\" \
are obsolete, their functionality is already present in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1, and they should ",
  StyleBox["NOT",
    FontColor->RGBColor[1, 0, 0]],
  " be loaded,"
}], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(Needs["\<Algebra`Trigonometry`\>"]\)], "Input"],

Cell[BoxData[
    \(Needs["\<Algebra`SymbolicSum`\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "4.   In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1 the operations ",
  StyleBox["TrigToComplex",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " and ",
  StyleBox["ComplexToTrig",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " are obsolete and have been replaced by ",
  StyleBox["TrigToExp",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " and ",
  StyleBox["ExpToTrig",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  ".  These include hyperbolic functions, so the routines defined on p.147 of \
the text are also obsolete."
}], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(fn1\  = \ Cos[x]\  + \ I\ Sin[x]\  + \ Cosh[z]\)], "Input"],

Cell[BoxData[
    \(fn1 // TrigToComplex\)], "Input"],

Cell[BoxData[
    \(fn1 // TrigToExp\)], "Input"],

Cell[BoxData[
    \(fn2\  = \ 
      Exp[I\ \[Omega]\ t]\  + \ Exp[2\ I\ \[Omega]\ t]\  + \ 
        Exp[\(-z\)\ t]\)], "Input"],

Cell[BoxData[
    \(fn2 // ComplexToTrig\)], "Input"],

Cell[BoxData[
    \(fn2 // ExpToTrig\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "5.   In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1 the 3-D graphics option ",
  StyleBox["Graphics`VectorPlot`ScaleFunction",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FontColor->RGBColor[0, 0, 1]],
  "has been replaced by ",
  StyleBox["Graphics`Common`GraphicsCommon`ScaleFunction",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  ".  Use the latter designation when setting a scale function in vector \
plots.  See Section 1.6.3.",
  StyleBox["\n",
    FontColor->RGBColor[0, 0, 1]]
}], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(Context[ScaleFunction]\)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Needs",
        FontColor->GrayLevel[0]], 
      StyleBox["[",
        FontColor->GrayLevel[0]], 
      StyleBox["\"\<Graphics`PlotField`\>\"",
        FontColor->GrayLevel[0]], "]"}]], "Input"],

Cell[BoxData[
    \(Context[ScaleFunction]\)], "Input"],

Cell[BoxData[
    \(Context[Graphics`Common`GraphicsCommon`ScaleFunction]\)], "Input"],

Cell[BoxData[
    RowBox[{
      StyleBox["Options",
        FontColor->GrayLevel[0]], 
      StyleBox["[",
        FontColor->GrayLevel[0]], "PlotGradientField", "]"}]], "Input"]
}, Open  ]],

Cell[TextData[{
  "6.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1 is quite stable but is ",
  StyleBox["NOT",
    FontColor->RGBColor[1, 0, 0]],
  " immune to crashes (usually from insuffient memory) and to aberrant \
behavior.\nTherefore:\n(1) SAVE YOUR WORK FREQUENTLY,\n\n(2) Do a program \
Exit/Restart at the first observation of a \"glitch\" or unexpected response.\
\n\n(3)  When starting a new problem, always do a program Exit/Restart to \
avoid conflicts with variables already defined or initialized."
}], "Section",
  Background->RGBColor[0, 1, 0]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{609, 598},
WindowMargins->{{48, Automatic}, {Automatic, 11}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 102, 2, 121, "Title"],

Cell[CellGroupData[{
Cell[1858, 57, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[1993, 62, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2089, 69, 58, 1, 69, "Subtitle"],
Cell[2150, 72, 109, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2296, 79, 206, 6, 110, "Subtitle"],

Cell[CellGroupData[{
Cell[2527, 89, 223, 7, 90, "Section"],
Cell[2753, 98, 150, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2940, 106, 474, 14, 111, "Section"],
Cell[3417, 122, 1275, 21, 174, "Input"],
Cell[4695, 145, 47, 1, 30, "Input"],
Cell[4745, 148, 51, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4833, 154, 352, 10, 111, "Section"],
Cell[5188, 166, 67, 1, 30, "Input"],
Cell[5258, 169, 66, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5361, 175, 744, 23, 132, "Section"],
Cell[6108, 200, 79, 1, 30, "Input"],
Cell[6190, 203, 53, 1, 30, "Input"],
Cell[6246, 206, 49, 1, 30, "Input"],
Cell[6298, 209, 128, 3, 30, "Input"],
Cell[6429, 214, 53, 1, 30, "Input"],
Cell[6485, 217, 49, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6571, 223, 661, 19, 195, "Section"],
Cell[7235, 244, 55, 1, 30, "Input"],
Cell[7293, 247, 237, 7, 30, "Input"],
Cell[7533, 256, 55, 1, 30, "Input"],
Cell[7591, 259, 86, 1, 30, "Input"],
Cell[7680, 262, 179, 5, 30, "Input"]
}, Open  ]],
Cell[7874, 270, 584, 13, 258, "Section"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

