(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10819,        446]*)
(*NotebookOutlinePosition[     11471,        469]*)
(*  CellTagsIndexPosition[     11427,        465]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1. Getting Started", "Title",
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*`\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Arithmetic and Algebra", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["1.2.1  Arithemetic and Notation", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Function Form", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(N[Pi]\)], "Input"],

Cell[BoxData[
    \(N[Pi, 20]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Postfix Form", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(Pi\  // \ N\)], "Input"],

Cell[CellGroupData[{

Cell["Use # and & to make pure function", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Pi\  // \ N[#, 50]\ &\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Successive operations", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(E^\((I\ x)\)\  // \ Series[#, {x, 0, 5}]&\)\  // \ Normal\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2.2  Algebra", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[BoxData[
    \(eq0\  = \ \((1 + x^2)\)^5\)], "Input"],

Cell[BoxData[
    \(eq1\  = \ Expand[eq0]\)], "Input"],

Cell["Or we can use the postfix form of the same command:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq1\  = \ eq0 // Expand\)], "Input"],

Cell[BoxData[
    \(eq1\  // \ Simplify\)], "Input"],

Cell["Note, however, that many commands do NOT work on equations:", "Text",
  FontColor->RGBColor[1, 0, 1],
  Background->None],

Cell[BoxData[
    \(eq0\  = \ {\((1 + x^2)\)^5\  == \ 0}\)], "Input"],

Cell[BoxData[
    \(eq1\  = \ Expand[eq0]\)], "Input"],

Cell["Must use a work-around to change the form of  equations:", "Text",
  FontColor->RGBColor[1, 0, 1],
  Background->None],

Cell[BoxData[
    \(eq0[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(eq0[\([1, 1]\)]\)], "Input"],

Cell[BoxData[
    \(eq0[\([1, 1]\)] // Expand\)], "Input"],

Cell[BoxData[
    \(eq1\  = 
      \ {\((eq0[\([1, 1]\)] // Expand)\)\  == \ 
          \((eq0[\([1, 2]\)] // Expand)\)}\)], "Input"],

Cell["\<\
Can use the GaussianIntegers option of Factor to obtain complex factors.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1],
  Background->None],

Cell[BoxData[
    \(Factor[eq1[\([1, 1]\)]]\)], "Input"],

Cell[BoxData[
    \(Factor[eq1[\([1, 1]\)], GaussianIntegers\  -> \ True]\)], "Input"],

Cell[BoxData[
    \(Options[Factor]\)], "Input"],

Cell[TextData[{
  "Note difference (Extension\[Rule]None) from output shown in book.\nThis is \
a difference between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.2.x and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1."
}], "Text",
  FontColor->RGBColor[1, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2.3  Mapping Expressions", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[BoxData[
    \(eq0\  = \ a1\ \((b + c/2)\)^2\  + \ a2\ \((d + e/3)\)^3\)], "Input"],

Cell[BoxData[
    \(eq1\  = \ eq0 // Expand\)], "Input"],

Cell["\<\
Note:  This is the same output as in book, obtained without the //Simplify \
command.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq1\  // \ Simplify\)], "Input"],

Cell[TextData[{
  "Note:  After the //Simplify command, the output goes bact to essentially \
the input form.\nThis is a difference between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.2.x and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1."
}], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq2\  = \ eq1\  // \ Collect[#, {a1, a2}]&\)], "Input"],

Cell[BoxData[
    \(eq3\  = \ eq2\  // \ Map[Factor, #, {2}]&\)], "Input"],

Cell[TextData[{
  "Note:  This is the same output as produced with the //Simplify command.\n\
This is a difference between ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.2.x and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1."
}], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq3\  = \ eq2\  // \ Map[factor, #, {2}]&\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2.4  Rules", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["Substitution operation /. (single substitution)", "Subsubsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\((x + z)\)^2\  /. \ z -> \ Sin[k\ y]\)], "Input"],

Cell[BoxData[
    \(\((x + z)\)^2\  /. \ {z -> \ Sin[k\ y], \ k\  -> \ 1}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Replacement  operation //. (multiple substitutions)", "Subsubsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\((x + z)\)^2\  //. \ {z -> \ Sin[k\ y], \ k\  -> \ 1}\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2.5  Conjugation", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[BoxData[
    \(a\  + \ 2\ I\ b\  /. \ I\  -> \ \(-I\)\)], "Input"],

Cell["Note: Doesn't work!", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(a\  + \ 2\ I\ b\  // \ FullForm\)], "Input"],

Cell[TextData[{
  "Note: This is what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is really doing.  Construct rule accordingly."
}], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(\(conjugateRule\  = \ {Complex[re_, im_]\  -> \ Complex[re, \(-im\)]}; 
    \)\)], "Input"],

Cell[BoxData[
    \(a\  + \ 2\ I\ b\  /. \ conjugateRule\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2.6  User-Defined Complex Conjugate Rule", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[BoxData[
    \(conjugate::usage\  = \n\t
      "\<A simple method of computing the conjugate of an object which is \
explicitly Complex\>"; \n\n
    conjugateRule\  = \ {Complex[re_, im_] :> Complex[re, \(-im\)]}; \n
    conjugate[exp__]\  := \ exp\  /. \ conjugateRule; \)], "Input"],

Cell[BoxData[
    \(I\ Exp[\ I\ k\ x]\  // Conjugate\)], "Input"],

Cell["\<\
Note: Conjugate is not sure if kx is real or complex, and so it leaves \
Conjugate[k x] in the exponent.  The user rule treats kx as real.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(I\ Exp[\ I\ k\ x]\  // conjugate\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2.7  Algebraic Equations", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Equation solution", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[BoxData[
    \(eq1\  = \ a\ x^2\  + \ b\ x\  + \ c\  == \ 0; \n
    sol1\  = \ Solve[eq1, x]\)], "Input"],

Cell[BoxData[
    \(x\  /. \ sol1[\([1]\)]\)], "Input"],

Cell[BoxData[
    \(x\  /. \ sol1[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(\(eq1\  /. \ sol1\ \)\)], "Input"],

Cell[BoxData[
    \(eq1\  /. \ sol1\  // \ Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Coupled Equations", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[BoxData[
    \(\(eq2\  = \ {a\ x + b\ y == c, \ a\ x - b\ y == d}; \)\)], "Input"],

Cell["Use Reduce instead of Solve", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq3\  = \ Reduce[eq2, {x, y}]\)], "Input"],

Cell["Extract desired solution by specifying [[solution,{items}]]", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq3[\([3, {2, 3}]\)]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2.8  Threading Expressions", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell["Use Thread to relate components of two separate lists", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(vector1 = {x1, y1}; \nvector2 = {x2, y2}; \n
    Thread[vector1 == vector2]\)], "Input"],

Cell[BoxData[
    \(Thread[vector1 == 0]\)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input"],

Cell[BoxData[
    \(Thread[{x, y, z}\  -> \ 
        CoordinatesToCartesian[{r, theta, phi}, Spherical]\ ]\)], "Input"],

Cell[BoxData[
    \(\(eq1\  = \ x + 1/a\  == \ y/a; \)\)], "Input"],

Cell[BoxData[
    \(a\ eq1\)], "Input"],

Cell[BoxData[
    \(Thread[a\ eq1, Equal]\  // \ ExpandAll\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{632, 625},
WindowMargins->{{174, Automatic}, {Automatic, 31}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 102, 2, 121, "Title"],

Cell[CellGroupData[{
Cell[1858, 57, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[1993, 62, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2089, 69, 58, 1, 69, "Subtitle"],
Cell[2150, 72, 109, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2296, 79, 79, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2400, 84, 83, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2508, 89, 68, 1, 63, "Subsection"],
Cell[2579, 92, 38, 1, 30, "Input"],
Cell[2620, 95, 42, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2699, 101, 67, 1, 63, "Subsection"],
Cell[2769, 104, 44, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2838, 109, 93, 1, 59, "Subsubsection"],
Cell[2934, 112, 54, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3025, 118, 81, 1, 59, "Subsubsection"],
Cell[3109, 121, 92, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3262, 129, 66, 1, 69, "Section"],
Cell[3331, 132, 61, 1, 30, "Input"],
Cell[3395, 135, 58, 1, 30, "Input"],
Cell[3456, 138, 54, 1, 30, "Input"],
Cell[3513, 141, 99, 1, 33, "Text"],
Cell[3615, 144, 56, 1, 30, "Input"],
Cell[3674, 147, 52, 1, 30, "Input"],
Cell[3729, 150, 127, 2, 33, "Text"],
Cell[3859, 154, 69, 1, 30, "Input"],
Cell[3931, 157, 54, 1, 30, "Input"],
Cell[3988, 160, 124, 2, 33, "Text"],
Cell[4115, 164, 45, 1, 30, "Input"],
Cell[4163, 167, 48, 1, 30, "Input"],
Cell[4214, 170, 58, 1, 30, "Input"],
Cell[4275, 173, 133, 3, 30, "Input"],
Cell[4411, 178, 148, 4, 33, "Text"],
Cell[4562, 184, 56, 1, 30, "Input"],
Cell[4621, 187, 86, 1, 30, "Input"],
Cell[4710, 190, 48, 1, 30, "Input"],
Cell[4761, 193, 298, 10, 52, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5096, 208, 78, 1, 69, "Section"],
Cell[5177, 211, 61, 1, 30, "Input"],
Cell[5241, 214, 88, 1, 30, "Input"],
Cell[5332, 217, 56, 1, 30, "Input"],
Cell[5391, 220, 141, 4, 33, "Text"],
Cell[5535, 226, 52, 1, 30, "Input"],
Cell[5590, 229, 321, 10, 52, "Text"],
Cell[5914, 241, 75, 1, 30, "Input"],
Cell[5992, 244, 74, 1, 30, "Input"],
Cell[6069, 247, 304, 10, 52, "Text"],
Cell[6376, 259, 74, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6487, 265, 64, 1, 69, "Section"],
Cell[6554, 268, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[6640, 273, 105, 1, 59, "Subsubsection"],
Cell[6748, 276, 70, 1, 30, "Input"],
Cell[6821, 279, 86, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6944, 285, 109, 1, 59, "Subsubsection"],
Cell[7056, 288, 87, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7192, 295, 70, 1, 69, "Section"],
Cell[7265, 298, 61, 1, 30, "Input"],
Cell[7329, 301, 71, 1, 30, "Input"],
Cell[7403, 304, 67, 1, 33, "Text"],
Cell[7473, 307, 64, 1, 30, "Input"],
Cell[7540, 310, 187, 6, 33, "Text"],
Cell[7730, 318, 111, 2, 30, "Input"],
Cell[7844, 322, 69, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7950, 328, 94, 1, 69, "Section"],
Cell[8047, 331, 61, 1, 30, "Input"],
Cell[8111, 334, 289, 5, 130, "Input"],
Cell[8403, 341, 65, 1, 30, "Input"],
Cell[8471, 344, 194, 4, 52, "Text"],
Cell[8668, 350, 65, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8770, 356, 78, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[8873, 361, 72, 1, 63, "Subsection"],
Cell[8948, 364, 61, 1, 30, "Input"],
Cell[9012, 367, 110, 2, 50, "Input"],
Cell[9125, 371, 55, 1, 30, "Input"],
Cell[9183, 374, 55, 1, 30, "Input"],
Cell[9241, 377, 54, 1, 30, "Input"],
Cell[9298, 380, 64, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9399, 386, 72, 1, 63, "Subsection"],
Cell[9474, 389, 61, 1, 30, "Input"],
Cell[9538, 392, 87, 1, 30, "Input"],
Cell[9628, 395, 75, 1, 33, "Text"],
Cell[9706, 398, 62, 1, 30, "Input"],
Cell[9771, 401, 107, 1, 33, "Text"],
Cell[9881, 404, 53, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9983, 411, 80, 1, 69, "Section"],
Cell[10066, 414, 61, 1, 30, "Input"],
Cell[10130, 417, 101, 1, 33, "Text"],
Cell[10234, 420, 108, 2, 70, "Input"],
Cell[10345, 424, 53, 1, 30, "Input"],
Cell[10401, 427, 70, 1, 30, "Input"],
Cell[10474, 430, 119, 2, 30, "Input"],
Cell[10596, 434, 67, 1, 30, "Input"],
Cell[10666, 437, 39, 1, 30, "Input"],
Cell[10708, 440, 71, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

