(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5869,        215]*)
(*NotebookOutlinePosition[      6760,        245]*)
(*  CellTagsIndexPosition[      6716,        241]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["2. General Physics", "Title",
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \($DefaultFont = {"\<Courier\>", 12}; \nOff[General::spell]; \n
    Off[General::spell1]; \nPageWidth -> 70; \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`FourierTransform`\>"]\)], "Input"],

Cell[BoxData[
    \(\(Clear["\<Global'*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.4 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["2.4.4  LRC Circuits", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 2:  Series RL Circuit", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell["Part (a)  Solve for the charge q[t] for an arbitraty V[t].", 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "Note:  Here we solve first for i[t] and then for q[t].  With ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1,\n\tthe one-step solution method suggested in the text produces \
error messages\n\tand leaves unevaluated constants of integraton."
}], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq1 = {V[t] == R\ \ i[t]\  + \ L\ \(i'\)[t], \ i[0] == i0}\)], "Input"],

Cell[BoxData[
    \(dsol1 = DSolve[eq1, i[t], t] // Flatten\)], "Input"],

Cell[BoxData[
    \(i[t_] = i[t] /. dsol1\)], "Input"],

Cell[BoxData[
    \(eq2 = {\(q'\)[t] == i[t], q[0] == q0}\)], "Input"],

Cell[BoxData[
    \(dsol2\  = \ DSolve[eq2, q[t], t] // Flatten\)], "Input"],

Cell[BoxData[
    \(q[t_] = q[t] /. dsol2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  Solve for the charge q[t] and current i[t] when V[t] = V0 Cos[\
\[Omega]t]."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(V[t_] = V0\ Cos[\[Omega]\ t]\)], "Input"],

Cell[BoxData[
    \(q[t_] = q[t] // Simplify\)], "Input"],

Cell[BoxData[
    \(i[t_] = i[t] // Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (c)  Plot the charge q[t] and current i[t] when q0=0", 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(values = {R -> 0.1, L -> 2, V0 -> 1, \[Omega] -> 1, i0 -> 0.1, q0 -> 0}
        \)], "Input"],

Cell[BoxData[
    \(\(Plot[Evaluate[{q[t], i[t]} /. values], {t, 0, 20}\n, 
      PlotStyle -> {{Dashing[{0.06, 0.00}], Thickness[0.008]}\n
          \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , {
            Dashing[{0.03, 0.03}], Thickness[0.008]}}\n, Frame -> True\n, 
      FrameLabel -> {"\<Time\>", "\<Charge & Current\>"}\n, 
      GridLines -> Automatic]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)  Take the Fourier transform of data (with noise) formed
\t  from the charge function q[t] from part (b) above.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(fourierdata\  = \ 
      Table[q[t]\ Random[Real, {0.9, 1.1}] /. values // N\n
        \t\t, {t, 0, 100  \[Pi], 100  \[Pi]/300}]; \)\)], "Input"],

Cell[BoxData[
    \(Short[fourierdata, 3]\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[fourierdata, PlotJoined -> True]; \)\)], "Input"],

Cell[BoxData[
    \(\(ftrans = Fourier[fourierdata]; \)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[Abs[ftrans], PlotJoined -> True, PlotRange -> {0, 5}]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(ftarg = 
      Table[ArcTan[Im[ftrans[\([n]\)]], Re[ftrans[\([n]\)]]], {n, 1, 300}]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(ListPlot[ftarg, PlotJoined -> True]; \)\)], "Input"],

Cell[BoxData[
    \(\(ftri = 
      Table[{Re[ftrans[\([n]\)]], Im[ftrans[\([n]\)]]}, {n, 1, 150}]; \)\)], 
  "Input"],

Cell[BoxData[
    \(\(ListPlot[ftri, PlotJoined -> True]; \)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{582, 688},
WindowMargins->{{Automatic, 12}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 102, 2, 121, "Title"],

Cell[CellGroupData[{
Cell[1858, 57, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[1993, 62, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2089, 69, 58, 1, 69, "Subtitle"],
Cell[2150, 72, 140, 2, 90, "Input"],
Cell[2293, 76, 72, 1, 30, "Input"],
Cell[2368, 79, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2465, 85, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2555, 90, 71, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2651, 95, 84, 1, 63, "Subsection"],

Cell[CellGroupData[{
Cell[2760, 100, 121, 2, 59, "Subsubsection"],
Cell[2884, 104, 323, 7, 71, "Text"],
Cell[3210, 113, 91, 1, 30, "Input"],
Cell[3304, 116, 72, 1, 30, "Input"],
Cell[3379, 119, 54, 1, 30, "Input"],
Cell[3436, 122, 70, 1, 30, "Input"],
Cell[3509, 125, 76, 1, 30, "Input"],
Cell[3588, 128, 54, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3679, 134, 156, 3, 59, "Subsubsection"],
Cell[3838, 139, 61, 1, 30, "Input"],
Cell[3902, 142, 57, 1, 30, "Input"],
Cell[3962, 145, 57, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4056, 151, 120, 2, 59, "Subsubsection"],
Cell[4179, 155, 113, 2, 30, "Input"],
Cell[4295, 159, 392, 6, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4724, 170, 187, 4, 76, "Subsubsection"],
Cell[4914, 176, 167, 3, 50, "Input"],
Cell[5084, 181, 54, 1, 30, "Input"],
Cell[5141, 184, 80, 1, 30, "Input"],
Cell[5224, 187, 68, 1, 30, "Input"],
Cell[5295, 190, 106, 2, 30, "Input"],
Cell[5404, 194, 127, 3, 30, "Input"],
Cell[5534, 199, 74, 1, 30, "Input"],
Cell[5611, 202, 118, 3, 30, "Input"],
Cell[5732, 207, 73, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

