(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11510,        414]*)
(*NotebookOutlinePosition[     12162,        437]*)
(*  CellTagsIndexPosition[     12118,        433]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["3. Oscillating Systems", "Title",
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[{
    \(Clear["\<Global`*`\>"]\), 
    \(Off[General::spell]; \nOff[General::spell1]; \)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["3.3.1  Linear Oscillations", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 1:  Analysis of Linear Oscillator", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(Needs["\<Graphics`FilledPlot`\>"]; \nNeeds["\<Graphics`Graphics3D`\>"]; 
    \)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Reduce the linear equation to a first-order differential equation \
and define its kinetic and potential energies.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Fke\  = \ m\ \(\(x'\)'\)[t]\)], "Input"],

Cell[BoxData[
    \(Fpe\  = \ k\ x[t]\)], "Input"],

Cell[BoxData[
    \(T\  = \ Integrate[\(x'\)[t]\ Fke, t]\)], "Input"],

Cell[BoxData[
    \(V\  = \ Integrate[\(x'\)[t]\ Fpe, t]\)], "Input"],

Cell[BoxData[
    \(energy\  = \ T\  + \ V\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Plot the potential function and describe the system's behavior.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(FilledPlot[V /. {x[t] -> x, k -> 1, m -> 1}, {x, \(-1\), 1}\n, 
      Frame -> True\n, 
      FrameLabel -> {"\<x-axis\>", "\<Potential\>", "\<V\>", "\< \>"}\n, 
      RotateLabel -> False\n]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)   Plot phase diagram using ContourPlot,DensityPlot,  and \
ShadowPlot3D\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(rules = {m -> 1, k -> 1, x[t] -> x, \(x'\)[t] -> v}; \n
    en\  = \ energy /. rules\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[en, {x, \(-1\), 1}, {v, \(-1\), 1}\n\ \ , 
      ColorFunction -> Hue\n\ \ , Axes -> True\n\ \ , 
      AxesLabel -> {"\<x[t]\>", "\<v[t]\>"}]; \)\)], "Input"],

Cell[BoxData[
    \(Options[ContourPlot]\)], "Input"],

Cell[BoxData[
    \(\(DensityPlot[en, {x, \(-1\), 1}, {v, \(-1\), 1}\n\t\t, 
      PlotPoints -> 20\n\ \ \ \ , ColorFunction -> Hue\n\ \ \ \ , 
      Axes -> True\n\ \ \ \ , AxesLabel -> {"\<x[t]\>", "\<v[t]\>"}]; \)\)], 
  "Input"],

Cell[BoxData[
    \(Options[DensityPlot]\)], "Input"],

Cell[BoxData[
    \(\(ShadowPlot3D[en, {x, \(-1\), 1}, {v, \(-1\), 1}\n\t, 
      PlotPoints -> 20\n\t, PlotLabel -> "\<Energy Surface\>"\n\ \ , 
      ColorFunction -> Hue\n\ \ , Axes -> True\n\ \ , 
      AxesLabel -> {"\<x[t]\>", "\<v[t]\>", "\<energy\>"}\n\ \ , 
      ShadowPosition -> 1]; \)\)], "Input"],

Cell[BoxData[
    \(Options[ShadowPlot3D]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 2:  Solution of Linear Oscillator", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Needs["\<Calculus`LaplaceTransform`\>"]; \)\)], "Input"],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch3init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Use DSolve to solve for the motion.   Express the solutions in \
terms of a phase and amplitude and of the initial conditions x[0] and \
x'[0].\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1\  = \ \(\(x'\)'\)[t]\  + \ \[Omega]^2\ x[t]\  == \ 0\)], "Input"],

Cell[BoxData[
    \(dsol1\  = \ DSolve[{eq1}, x[t], t] // Flatten\)], "Input"],

Cell["\<\
Note: Here DSolve gives the solution in a sinusoidal form rather than the \
exponential form given in the book.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(cRule = {C[1] -> \(-A\)\ Sin[\[Delta]], C[2] -> A\ Cos[\[Delta]]}\)], 
  "Input"],

Cell[BoxData[
    \(dsol2\  = \ dsol1 /. cRule // Simplify\)], "Input"],

Cell[BoxData[
    \(initial\  = \ {x[0] == x0, \ \(x'\)[0] == v0}\)], "Input"],

Cell[BoxData[
    \(dsol3\  = \ DSolve[Join[{eq1}, initial], x[t], t] // Flatten\)], "Input"],

Cell["\<\
Note: Here DSolve gives the solution in the desired form immediately.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Solve for the motion by assuming the solution can be expressed as \
a power series in t.   Sum the series to get the solution in a closed form.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(dsol4\  = \ 
      diffSeriesOne[eq1, x, t, 9, {x[0] -> x0, \ \(x'\)[0] -> v0}]\n\t // 
        Collect[#, {x0, v0}]&\)], "Input"],

Cell[BoxData[
    \(termX[n_]\  = \ 
      \((\(-1\))\)^n\ \((t\ \[Omega])\)^\((2\ n)\)/\(\((2\ n)\)!\); \n
    termV[n_]\  = \ 
      \((\(-1\))\)^n\ 
        \((t\ \[Omega])\)^\((2\ n\  + \ 1)\)/
          \((\[Omega]\ \(\((2\ n + 1)\)!\))\); \)], "Input"],

Cell[BoxData[
    \(test\  = \ 
      Sum[x0\ termX[n]\  + \ v0\ termV[n], {n, 0, 4}] // 
        Collect[#, {x0, v0}]&\)], "Input"],

Cell[BoxData[
    \(test == dsol4\)], "Input"],

Cell[BoxData[
    \(exactSum\  = \ \ 
      Sum[x0\ termX[n]\  + \ v0\ termV[n], {n, 0, Infinity}]\)], "Input"],

Cell[BoxData[
    \(exactSum\  = \ \ exactSum // PowerExpand\)], "Input"],

Cell[BoxData[
    \(exactSum\  = \ \ exactSum // Apart\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (c)   Use LaplaceTransform to solve the equation.", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(lapTx\  = \ LaplaceTransform[eq1, t, s]\)], "Input"],

Cell[BoxData[
    \(lapSol\  = \ Solve[lapTx, LaplaceTransform[x[t], t, s]] // Flatten\)], 
  "Input"],

Cell[BoxData[
    \(dsol5\  = \ 
      InverseLaplaceTransform[LaplaceTransform[x[t], t, s] /. lapSol\n\t\t, 
        s, t]\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 3:  Damped Linear Oscillator", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)   Solve the equation with the initial conditions x[0]=x0, x'[0]=v0. \
 Make a plot of the solution as a function of the variables t and \
2\[Omega]=Sqrt[\[Gamma]^2-4\[Omega]0^2]."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1\  = \ 
      \(\(x'\)'\)[t]\  + \ \[Gamma]\ \(x'\)[t]\  + \ \[Omega]0^2\ x[t]\  == \ 
        0\)], "Input"],

Cell[BoxData[
    \(dsol1\  = \ 
      \(DSolve[{eq1, x[0] == x0, \ \(x'\)[0] == v0}, x[t], t] // Flatten\) // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(wRule\  = 
      \ {\((\[Gamma]^2\  - \ 4\ \[Omega]0^2)\)^\((1/2)\)\  -> \ 2  \[Omega], 
        \ 1/\((\[Gamma]^2\  - \ 4\ \[Omega]0^2)\)^\((1/2)\)\  -> 
          1/\((\ 2  \[Omega])\)}\)], "Input"],

Cell[BoxData[
    \(dsol2\  = \ dsol1 //. wRule // Simplify\)], "Input"],

Cell[BoxData[
    \(x[t_] = x[t] /. dsol2\)], "Input"],

Cell[BoxData[
    \(values\  = \ {x0 -> 1, v0 -> 0, \ \[Gamma] -> 1}\)], "Input"],

Cell[BoxData[
    \(\(p0\  = \ 
      Plot3D[Evaluate[\(x[t] //. values\) /. {\[Omega] -> Sqrt[\[Omega]2]}]\n
        \t\ \ , {\[Omega]2, 25, \(-150\)}, {t, 0, 1}\n\t\ \ , 
        PlotPoints -> 25\n\t\t, PlotRange -> {\(-1\), 2}\n\t\t, 
        BoxRatios -> {1, 1, 1}\n\t\t, ViewPoint -> {\(-4\), 3, 2}\n\t\t, 
        AxesLabel -> {"\<\[Omega]2\>", "\<t\>", "\<x[t]\>"}\n\t\t, 
        ColorFunction -> Hue]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Solve for the overdamped case where \[Omega] is real: (\[Gamma]^2 \
> 4 \[Omega]0^2).  Plot the solution."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(p1\  = \ 
      Plot[Evaluate[\(x[t] //. values\) /. {\[Omega] -> \(+0.6\)}], {t, 0, 
          10}]; \)\)], "Input"],

Cell[BoxData[
    \(\(p2\  = \ 
      Plot[Evaluate[\(x[t] //. values\) /. {\[Omega] -> \(+0.4\)}], {t, 0, 
          10}]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)   Solve for the critically damped case where \[Omega] =0: \
(\[Gamma]^2 = 4 \[Omega]0^2).  Plot the solution."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(xlim[t_]\  = \ Limit[x[t], \[Omega] -> 0]\)], "Input"],

Cell[BoxData[
    \(\(p3\  = \ Plot[Evaluate[xlim[t] //. values], {t, 0, 10}]; \)\)], 
  "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (d)   Solve for the underdamped damped case where \[Omega] is \
imaginary: (\[Gamma]^2 < 4 \[Omega]0^2).  Plot the solution."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(xud[t_]\  = 
      \(x[t] /. {\[Omega] -> I\ \[Omega]Re} // ExpToTrig\) // FullSimplify
        \)], "Input"],

Cell[BoxData[
    \(\(p4\  = \ 
      Plot[Evaluate[\(xud[t] //. values\) /. {\[Omega]Re -> 10}], {t, 0, 10}, 
        \n\tPlotRange -> All]; \)\)], "Input"],

Cell[BoxData[
    \(q = \ \(x[t] //. values\) /. {\[Omega] -> 10\ I}; \n
    p\  = \ \(\(x'\)[t] //. values\) /. {\[Omega] -> 10\ I}; \)], "Input"],

Cell[BoxData[
    \(\(doublePlot[p, q, {t, 0.01, 5}]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (e)   Overlay the two-dimensional plots and comment on them.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(Show[p1, p2, p3, p4]; \)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{602, 608},
WindowMargins->{{Automatic, 105}, {Automatic, 12}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 106, 2, 121, "Title"],

Cell[CellGroupData[{
Cell[1862, 57, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[1997, 62, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2093, 69, 58, 1, 69, "Subtitle"],
Cell[2154, 72, 113, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2304, 79, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2394, 84, 78, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2497, 89, 96, 1, 63, "Subsection"],
Cell[2596, 92, 110, 2, 50, "Input"],

Cell[CellGroupData[{
Cell[2731, 98, 193, 4, 76, "Subsubsection"],
Cell[2927, 104, 60, 1, 30, "Input"],
Cell[2990, 107, 50, 1, 30, "Input"],
Cell[3043, 110, 69, 1, 30, "Input"],
Cell[3115, 113, 69, 1, 30, "Input"],
Cell[3187, 116, 55, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3279, 122, 142, 3, 59, "Subsubsection"],
Cell[3424, 127, 230, 4, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3691, 136, 148, 4, 59, "Subsubsection"],
Cell[3842, 142, 117, 2, 50, "Input"],
Cell[3962, 146, 193, 3, 90, "Input"],
Cell[4158, 151, 53, 1, 30, "Input"],
Cell[4214, 154, 232, 4, 110, "Input"],
Cell[4449, 160, 53, 1, 30, "Input"],
Cell[4505, 163, 310, 5, 150, "Input"],
Cell[4818, 170, 54, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4921, 177, 96, 1, 63, "Subsection"],
Cell[5020, 180, 78, 1, 30, "Input"],
Cell[5101, 183, 90, 2, 30, "Input"],
Cell[5194, 187, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[5280, 192, 222, 5, 76, "Subsubsection"],
Cell[5505, 199, 89, 1, 30, "Input"],
Cell[5597, 202, 78, 1, 30, "Input"],
Cell[5678, 205, 167, 4, 33, "Text"],
Cell[5848, 211, 101, 2, 30, "Input"],
Cell[5952, 215, 71, 1, 30, "Input"],
Cell[6026, 218, 78, 1, 30, "Input"],
Cell[6107, 221, 93, 1, 30, "Input"],
Cell[6203, 224, 125, 3, 33, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6365, 232, 222, 4, 76, "Subsubsection"],
Cell[6590, 238, 150, 3, 50, "Input"],
Cell[6743, 243, 258, 6, 50, "Input"],
Cell[7004, 251, 132, 3, 30, "Input"],
Cell[7139, 256, 46, 1, 30, "Input"],
Cell[7188, 259, 111, 2, 30, "Input"],
Cell[7302, 263, 73, 1, 30, "Input"],
Cell[7378, 266, 67, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7482, 272, 114, 1, 59, "Subsubsection"],
Cell[7599, 275, 72, 1, 30, "Input"],
Cell[7674, 278, 102, 2, 30, "Input"],
Cell[7779, 282, 136, 3, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7964, 291, 91, 1, 63, "Subsection"],
Cell[8058, 294, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[8144, 299, 258, 4, 76, "Subsubsection"],
Cell[8405, 305, 132, 3, 30, "Input"],
Cell[8540, 310, 141, 3, 50, "Input"],
Cell[8684, 315, 220, 4, 50, "Input"],
Cell[8907, 321, 72, 1, 30, "Input"],
Cell[8982, 324, 54, 1, 30, "Input"],
Cell[9039, 327, 81, 1, 30, "Input"],
Cell[9123, 330, 426, 7, 170, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9586, 342, 187, 3, 59, "Subsubsection"],
Cell[9776, 347, 139, 3, 30, "Input"],
Cell[9918, 352, 139, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10094, 360, 189, 3, 59, "Subsubsection"],
Cell[10286, 365, 74, 1, 30, "Input"],
Cell[10363, 368, 97, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10497, 375, 203, 4, 76, "Subsubsection"],
Cell[10703, 381, 129, 3, 30, "Input"],
Cell[10835, 386, 157, 3, 50, "Input"],
Cell[10995, 391, 147, 2, 50, "Input"],
Cell[11145, 395, 69, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11251, 401, 133, 3, 59, "Subsubsection"],
Cell[11387, 406, 59, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

