(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7371,        252]*)
(*NotebookOutlinePosition[      8023,        275]*)
(*  CellTagsIndexPosition[      7979,        271]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["3. Oscillating Systems", "Title",
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*`\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["3.3.1  Linear Oscillations", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 4:  Damped Harmonic Oscillator and Driving Force", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch3init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["Part (a)   Solve for the homogeneous (F=0) solution.", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1\  = \ 
      \(\(x'\)'\)[t]\  + \ \[Gamma]\ \(x'\)[t]\  + \ \[Omega]0^2\ x[t]\  == \ 
        Q0\ Cos[\[Omega]d\ t]\)], "Input"],

Cell[BoxData[
    \(dsol0 = 
      DSolve[{eq1 /. {Q0 -> 0}, x[0] == x0, \(x'\)[0] == v0}\n\t, x[t], t] // 
        Flatten\)], "Input"],

Cell[BoxData[
    \(\[Omega]Rule = {
        Sqrt[\[Gamma]^2\  - \ 4\ \[Omega]0^2]\  -> \ 2  \[Omega]\n
        \t\t\ \ \ \ , 
        1/Sqrt[\[Gamma]^2\  - \ 4\ \[Omega]0^2]\  -> \ 1/\((2  \[Omega])\)}
        \)], "Input"],

Cell[BoxData[
    \(dsol = dsol0 /. \[Omega]Rule // Simplify\)], "Input"],

Cell["\<\
Note:  Use FullSimplify instead of Simplify to get rid of hyperbolic \
functions and complex factors.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(homSol = 
      \(\(x[t] /. dsol\) /. {\[Omega] -> I\ \[Omega]Re}\n
          \t\t\ \ \ \ \ \ \ \ \ \ \ \ \  // ExpToTrig\) // FullSimplify\)], 
  "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Assume a particular solution of the form A Cos[\[Omega]d t + \
\[Phi]] and solve for the amplitude A and phase \[Phi].  Write the general \
form of the solution."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(guess\  = \ {x\  -> \ \((A\ Cos[\[Omega]d\ #\  + \ \[Phi]]&)\)}\)], 
  "Input"],

Cell[BoxData[
    \(eq2\  = \ eq1 /. guess\)], "Input"],

Cell["\<\
To isolate amplitude and phase, consider two time \"snapshots\" a quarter of \
a cycle apart.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq3 = 
      \(({eq2 /. {t -> 0}\n\t, eq2 /. {\ t -> \[Pi]/\((2\ \[Omega]d)\)}}
              \n //. {Sin[\[Phi]] -> Tan\[Phi]\ Cos[\[Phi]]})\) // Simplify
        \)], "Input"],

Cell[BoxData[
    \(sol1\  = \ \(Solve[eq3, {A, Tan\[Phi]}] // Flatten\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(\[Phi]Rule\  = \ {\[Phi]\  -> \ ArcTan[Tan\[Phi]]}; \n
    secRule\  = \ {Sec[ArcTan[_x]] :> Sqrt[1\  + \ x^2]}; \)], "Input"],

Cell[BoxData[
    \(answerA\  = A //. Join[sol1, \[Phi]Rule, secRule] // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(answerA = \(\(answerA^2 // Simplify\) // Sqrt\) // PowerExpand\)], 
  "Input"],

Cell[BoxData[
    \(sol = Join[{A -> answerA}, {sol1[\([1]\)]}, \[Phi]Rule]\)], "Input"],

Cell[BoxData[
    \(partSol = \(x[t] /. guess\) //. sol\)], "Input"],

Cell[BoxData[
    \(genSol = 
      partSol + homSol /. {\[Omega]Re -> \[Omega]0^2\  - \ 1/4\ \[Gamma]^2}
          \)], "Input"],

Cell[BoxData[
    \(values = {A -> 3, Q0 -> 1, \[Omega]d -> 1, x0 -> 0, v0 -> 1}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)   Plot the solution as a function of \[Omega]0 and t.  PLot the \
amplitude A as a function of of \[Omega]0 and \[Gamma].  Notice the resonance \
at \[Omega]0 = \[Omega]d."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(Plot3D[\(genSol /. values\) /. {\[Gamma] -> 0.1} // Evaluate\n
      \t, {t, 0, 30}\n\ \ , {\[Omega]0, 0.5, 1.5}\n\ \ , PlotPoints -> 40\n
      \t, AxesLabel -> {"\<Time\>", "\<\[Omega]0\>", "\<x[t]\>"}\n\t, 
      FaceGrids -> {{0, 1, 0}, {0, \(-1\), 0}}\n\t, 
      ViewPoint -> {1,  .4,  .6}\n\t, ColorFunction -> Hue]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[\(A /. sol\) /. values // Evaluate\n\t, {\[Gamma], 0.0001, 4}\n
      \ \ , {\[Omega]0, 0, 2}\n\ \ , PlotPoints -> 40\n\t, 
      PlotRange -> {0, 8}\n\t, 
      AxesLabel -> {"\<\[Gamma]\>", "\<\[Omega]0\>", "\<Amplitude\>"}\n\t, 
      FaceGrids -> {{\(-1\), 0, 0}}\n\t, ViewPoint -> {\(-1\),  .4,  .4}\n\t, 
      ColorFunction -> Hue]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot[
      \(genSol //. values\) //. {\[Gamma] -> 0.1, \[Omega]0 -> 2} // Evaluate
        \n\t, {t, 0, 80}\n, PlotPoints \[Rule] 60]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot[
      \(genSol //. values\) //. {\[Gamma] -> 0.1, \[Omega]0 -> 2} // Evaluate
        \n\t, {t, 0, 10}\n, PlotPoints \[Rule] 60]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)   Pick parameters to illustrate the transcient and steady-state \
behaviors and polt x[t] and its phase trajectory.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(q = \(genSol //. values\) //. {\[Gamma] -> 0.1, \[Omega]0 -> 2}\)], 
  "Input"],

Cell[BoxData[
    \(p = D[q, t]\)], "Input"],

Cell[BoxData[
    \(\(doublePlot[p, q, {t, 0, 80}]; \)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{502, 626},
WindowMargins->{{344, Automatic}, {Automatic, 32}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 106, 2, 121, "Title"],

Cell[CellGroupData[{
Cell[1862, 57, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[1997, 62, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2093, 69, 58, 1, 69, "Subtitle"],
Cell[2154, 72, 109, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2300, 79, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2390, 84, 78, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2493, 89, 111, 1, 63, "Subsection"],
Cell[2607, 92, 90, 2, 30, "Input"],
Cell[2700, 96, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2786, 101, 112, 1, 59, "Subsubsection"],
Cell[2901, 104, 152, 3, 30, "Input"],
Cell[3056, 109, 136, 3, 50, "Input"],
Cell[3195, 114, 224, 5, 50, "Input"],
Cell[3422, 121, 73, 1, 30, "Input"],
Cell[3498, 124, 157, 4, 52, "Text"],
Cell[3658, 130, 175, 4, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3870, 139, 243, 4, 76, "Subsubsection"],
Cell[4116, 145, 99, 2, 30, "Input"],
Cell[4218, 149, 55, 1, 30, "Input"],
Cell[4276, 152, 149, 4, 33, "Text"],
Cell[4428, 158, 197, 4, 70, "Input"],
Cell[4628, 164, 100, 2, 30, "Input"],
Cell[4731, 168, 146, 2, 50, "Input"],
Cell[4880, 172, 97, 2, 30, "Input"],
Cell[4980, 176, 98, 2, 30, "Input"],
Cell[5081, 180, 88, 1, 30, "Input"],
Cell[5172, 183, 68, 1, 30, "Input"],
Cell[5243, 186, 129, 3, 30, "Input"],
Cell[5375, 191, 93, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5505, 197, 251, 4, 76, "Subsubsection"],
Cell[5759, 203, 361, 5, 170, "Input"],
Cell[6123, 210, 384, 6, 190, "Input"],
Cell[6510, 218, 173, 3, 70, "Input"],
Cell[6686, 223, 173, 3, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6896, 231, 192, 4, 76, "Subsubsection"],
Cell[7091, 237, 99, 2, 30, "Input"],
Cell[7193, 241, 44, 1, 30, "Input"],
Cell[7240, 244, 67, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

