(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10851,        369]*)
(*NotebookOutlinePosition[     11503,        392]*)
(*  CellTagsIndexPosition[     11459,        388]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["3. Oscillating Systems", "Title",
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*`\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3.3 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["3.3.2  Nonlinear Oscillations", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 1:  Duffing's Oscillator Equation", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch3init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Illustrate the double-well and single-well behavior of the \
potential by plottingthe potential as a function of a and q.  Pick values of \
a that correspond to the two kinds of behavior and plot the potential as a \
function of q.  Plot the phase diagram for the double-well and single-well \
behavior.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Fke = \(\(q'\)'\)[t]\)], "Input"],

Cell[BoxData[
    \(Fpe = \(-a\)\ q[t]\)], "Input"],

Cell[BoxData[
    \(Fpert\  = \ b\ q[t]^3\)], "Input"],

Cell[BoxData[
    \(force = Fke + Fpe + Fpert\)], "Input"],

Cell[BoxData[
    \(T = Integrate[\(q'\)[t]\ Fke, t]\)], "Input"],

Cell[BoxData[
    \(V0 = Integrate[\(q'\)[t]\ Fpe, t]\)], "Input"],

Cell[BoxData[
    \(V1 = Integrate[\(q'\)[t]\ Fpert, t]\)], "Input"],

Cell[BoxData[
    \(energy = T + V0 + V1\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[V0 + V1 //. {q[t] -> q, b -> 0.05} // Evaluate\n
      \t, {q, \(-15\), 15}\n\ \ , {a, \(-1\), 4}\n\ \ , 
      AxesLabel -> {"\<q\>", "\<a\>", "\<Potential\>"}\n\t, 
      BoxRatios -> {1, 1, 1}\n\t, PlotRange -> {\(-100\), 100}\n\t, 
      ViewPoint -> {0, 3, 2}]; \)\)], "Input"],

Cell[BoxData[
    \(\(plot1 = 
      Plot[V0 + V1 //. {q[t] -> q, b -> 0.05, a -> \(+4\)}\n
        \t, {q, \(-15\), 15}\n\t, PlotLabel -> "\<Two-Well Potential\>"]; 
    \)\)], "Input"],

Cell[BoxData[
    \(values = {q[t] -> q, \(q'\)[t] -> v, b -> 0.05}\)], "Input"],

Cell[BoxData[
    \(\(cplot1 = 
      ContourPlot[\(energy //. values\) //. {a -> \(-1\)} // Evaluate\n
        \t, {q, \(-15\), 15}\n\t, {v, \(-15\), 15}\n\t, Contours -> 8\n\t, 
        PlotPoints -> 20\n\t, ColorFunction -> Hue]; \)\)], "Input"],

Cell[BoxData[
    \(\(cplot2 = 
      ContourPlot[\(energy //. values\) //. {a -> \(+4\)} // Evaluate\n
        \t, {q, \(-15\), 15}\n\t, {v, \(-15\), 15}\n\t, Contours -> 8\n\t, 
        PlotPoints -> 20\n\t, ColorFunction -> Hue]; \)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[{cplot1, cplot2}], 
      DisplayFunction -> $DisplayFunction]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)  Numerically solve for the trajectories and plot q[t] and q'[t].\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1 = {\((force /. {\(\(q'\)'\)[t] -> \(p'\)[t]})\) == 0\n, 
        \(q'\)[t] == p[t]}\)], "Input"],

Cell[BoxData[
    \(initial = {p[0] == 0.001, q[0] == 0}\)], "Input"],

Cell[BoxData[
    \(eq2 = Join[eq1, initial]\)], "Input"],

Cell[BoxData[
    \(ndsol1\  = \ 
      NDSolve[eq2 //. {b -> 0.05, a -> \(-1\)}\n
          \t\t, {q[t], p[t]}, {t, 0, 30}] // Flatten\)], "Input"],

Cell[BoxData[
    \(q1[t_] = q[t] /. ndsol1; \np1[t_] = p[t] /. ndsol1; \)], "Input"],

Cell[BoxData[
    \(ndsol2\  = \ 
      NDSolve[eq2 //. {b -> 0.05, a -> \(+4\)}\n
          \t\t, {q[t], p[t]}, {t, 0, 30}] // Flatten\)], "Input"],

Cell[BoxData[
    \(q2[t_] = q[t] /. ndsol2; \np2[t_] = p[t] /. ndsol2; \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)  Plot phasee trajectories for the double-well and single-well \
behavior.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{
          Plot[q1[t], {t, 0, 30}\n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
            DisplayFunction -> Identity]\n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ , 
          Plot[p1[t], {t, 0, 30}\n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
            DisplayFunction -> Identity]}]\n
      \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
      DisplayFunction -> $DisplayFunction]; \)\)], "Input"],

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{
          Plot[q2[t], {t, 0, 30}\n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
            DisplayFunction -> Identity]\n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ , 
          Plot[p2[t], {t, 0, 30}\n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
            DisplayFunction -> Identity]}]\n
      \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
      DisplayFunction -> $DisplayFunction]; \)\)], "Input"],

Cell[BoxData[
    \(\(doublePlot[q1[t], p1[t], {t, 0, 30}]; \)\)], "Input"],

Cell[BoxData[
    \(\(doublePlot[q2[t], p2[t], {t, 0, 30}]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (d)  Animate one of the solutions..", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(frames = 40; \noscMovie[q2, 30, frames, {\(-15\), 15}]; \)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Problem 2:  Forced Duffing Oscillator for Double-well Potential\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(Needs["\<Calculus`FourierTransform`\>"]\)], "Input"],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Part (a)  Numerically solve the equations for Q0=0 and Q0=0.1.  Plot q[t] and \
p[t].\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1 = 
      \(\(q'\)'\)[t] == 
        a\ q[t]\  - \ b\ q[t]^3\  - \ \[Gamma]\ \(q'\)[t]\  + \ 
          Q0\ Cos[\[Omega]\ t]\)], "Input"],

Cell[BoxData[
    \(eq2 = eq1 //. {\(\(q'\)'\)[t] -> \(p'\)[t], \(q'\)[t] -> p[t]}\)], 
  "Input"],

Cell[BoxData[
    \(eq3 = \(q'\)[t] == p[t]\)], "Input"],

Cell[BoxData[
    \(eq4 = {eq2, eq3}\)], "Input"],

Cell[BoxData[
    \(initial = {p[0] == 0.001, q[0] == 0}\)], "Input"],

Cell[BoxData[
    \(values = {a -> 0.4, b -> 0.5, \[Omega] -> 1/8, \[Gamma] -> 0.02}\)], 
  "Input"],

Cell[BoxData[
    \(ndsol1 = \n\t
      NDSolve[\(Join[eq4, initial] //. values\) //. {Q0 -> 0}\n
          \t\t, {q[t], p[t]}, {t, 0, 120}\n\t, MaxSteps -> 700] // Flatten
        \)], "Input"],

Cell[BoxData[
    \(q1[t_] = q[t] /. ndsol1; \np1[t_] = p[t] /. ndsol1; \)], "Input"],

Cell[BoxData[
    \(ndsol2 = \n\t
      NDSolve[\(Join[eq4, initial] //. values\) //. {Q0 -> 0.1}\n
          \t\t, {q[t], p[t]}, {t, 0, 120}\n\t, MaxSteps -> 700] // Flatten
        \)], "Input"],

Cell[BoxData[
    \(q2[t_] = q[t] /. ndsol2; \np2[t_] = p[t] /. ndsol2; \)], "Input"],

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{
          Plot[q1[t], {t, 0, 120}\n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
            DisplayFunction -> Identity]\n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ , 
          Plot[p1[t], {t, 0, 120}\n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
            DisplayFunction -> Identity]}]\n
      \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
      DisplayFunction -> $DisplayFunction]; \)\)], "Input"],

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{
          Plot[q2[t], {t, 0, 120}\n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
            DisplayFunction -> Identity]\n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ , 
          Plot[p2[t], {t, 0, 120}\n\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
            DisplayFunction -> Identity]}]\n
      \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
      DisplayFunction -> $DisplayFunction]; \)\)], "Input"],

Cell[BoxData[
    \(Part\ \((b)\)\ \ Graph\ the\ phase\ trajectory\ and\ spectrum\ for\ the
      \ two\ cases\)], "Input",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(doublePlot[q1[t], p1[t], {t, 0, 120}]; \)\)], "Input"],

Cell[BoxData[
    \(\(doublePlot[q2[t], p2[t], {t, 0, 120}]; \)\)], "Input"],

Cell[BoxData[
    \(\(plot1 = 
      Show[fftSpectrum[q1[t], t, 120]\n\t, PlotRange -> {{0, 50}, All}\n
        \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , DisplayFunction -> Identity]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(plot2 = 
      Show[fftSpectrum[q2[t], t, 120]\n\t, PlotRange -> {{0, 50}, All}\n
        \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , DisplayFunction -> Identity]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[{plot1, plot2}]\n
      \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
      DisplayFunction -> $DisplayFunction]; \)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{459, 546},
WindowMargins->{{251, Automatic}, {Automatic, 13}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 106, 2, 121, "Title"],

Cell[CellGroupData[{
Cell[1862, 57, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[1997, 62, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2093, 69, 58, 1, 69, "Subtitle"],
Cell[2154, 72, 109, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2300, 79, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2390, 84, 81, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2496, 89, 96, 1, 63, "Subsection"],
Cell[2595, 92, 90, 2, 30, "Input"],
Cell[2688, 96, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2774, 101, 382, 7, 127, "Subsubsection"],
Cell[3159, 110, 53, 1, 30, "Input"],
Cell[3215, 113, 51, 1, 30, "Input"],
Cell[3269, 116, 54, 1, 30, "Input"],
Cell[3326, 119, 58, 1, 30, "Input"],
Cell[3387, 122, 65, 1, 30, "Input"],
Cell[3455, 125, 66, 1, 30, "Input"],
Cell[3524, 128, 68, 1, 30, "Input"],
Cell[3595, 131, 53, 1, 30, "Input"],
Cell[3651, 134, 311, 5, 150, "Input"],
Cell[3965, 141, 186, 4, 90, "Input"],
Cell[4154, 147, 80, 1, 30, "Input"],
Cell[4237, 150, 248, 4, 150, "Input"],
Cell[4488, 156, 248, 4, 150, "Input"],
Cell[4739, 162, 120, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4896, 169, 141, 3, 59, "Subsubsection"],
Cell[5040, 174, 120, 2, 50, "Input"],
Cell[5163, 178, 69, 1, 30, "Input"],
Cell[5235, 181, 57, 1, 30, "Input"],
Cell[5295, 184, 148, 3, 50, "Input"],
Cell[5446, 189, 85, 1, 50, "Input"],
Cell[5534, 192, 148, 3, 50, "Input"],
Cell[5685, 197, 85, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5807, 203, 150, 4, 76, "Subsubsection"],
Cell[5960, 209, 481, 10, 110, "Input"],
Cell[6444, 221, 481, 10, 110, "Input"],
Cell[6928, 233, 75, 1, 30, "Input"],
Cell[7006, 236, 75, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7118, 242, 100, 1, 59, "Subsubsection"],
Cell[7221, 245, 89, 1, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7359, 252, 126, 3, 47, "Subsection"],
Cell[7488, 257, 72, 1, 30, "Input"],
Cell[7563, 260, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[7649, 265, 153, 4, 76, "Subsubsection"],
Cell[7805, 271, 160, 4, 50, "Input"],
Cell[7968, 277, 98, 2, 30, "Input"],
Cell[8069, 281, 56, 1, 30, "Input"],
Cell[8128, 284, 49, 1, 30, "Input"],
Cell[8180, 287, 69, 1, 30, "Input"],
Cell[8252, 290, 100, 2, 30, "Input"],
Cell[8355, 294, 194, 4, 90, "Input"],
Cell[8552, 300, 85, 1, 50, "Input"],
Cell[8640, 303, 196, 4, 110, "Input"],
Cell[8839, 309, 85, 1, 50, "Input"],
Cell[8927, 312, 483, 10, 110, "Input"],
Cell[9413, 324, 483, 10, 110, "Input"],
Cell[9899, 336, 158, 3, 66, "Input"],
Cell[10060, 341, 76, 1, 30, "Input"],
Cell[10139, 344, 76, 1, 30, "Input"],
Cell[10218, 347, 200, 4, 70, "Input"],
Cell[10421, 353, 200, 4, 70, "Input"],
Cell[10624, 359, 163, 3, 50, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

