(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14554,        553]*)
(*NotebookOutlinePosition[     15445,        583]*)
(*  CellTagsIndexPosition[     15401,        579]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*`\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.1 Introduction", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[TextData[{
  "4.1.3 ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Commands"
}], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Example L1:  Lagrange's equation for a particle in a potential V[x]\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(L1 = m/2\ \(x'\)[t]^2\  - \ V[x[t]]\)], "Input"],

Cell[BoxData[
    \(leq1\  = {\ Lag[x, L1]}\)], "Input"],

Cell[BoxData[
    \(L2 = m/2\ \((\(x'\)[t]^2\  + \ \(y'\)[t]^2)\)\  - \ V[x[t], y[t]]\)], 
  "Input"],

Cell[BoxData[
    \(leq2\  = Lag[{x, y}, L2]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example H1:  Hamilton's equations of motion in one dimension.\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(L = m/2\ \(x'\)[t]^2\  - \ V[x[t]]\)], "Input"],

Cell[BoxData[
    \(\({pRule, ham, eqMotion} = Hamilton[L, {x}, {px}]; \)\)], "Input"],

Cell[BoxData[
    \(pRule\)], "Input"],

Cell[BoxData[
    \(ham\)], "Input"],

Cell[BoxData[
    \(eqMotion\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example H2:  Hamilton's equations of motion in two dimensions.\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(L = m/2\ \((\(x'\)[t]^2\  + \ \(y'\)[t]^2)\)\  - \ V[x[t], y[t]]\)], 
  "Input"],

Cell[BoxData[
    \(\({pRule, ham, eqMotion} = Hamilton[L, {x, y}, {px, py}]; \)\)], "Input"],

Cell[BoxData[
    \(pRule\)], "Input"],

Cell[BoxData[
    \(ham\)], "Input"],

Cell[BoxData[
    \(eqMotion\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "How ",
  StyleBox["Hamilton",
    FontFamily->"Terminal",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  " works."
}], "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["Version of Hamilton with no local variables:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(\(xHamilton[L_, xList_List, pList_List, t_:  t] := \ \n\ \ 
      Module[{}, \n\ \ \ \ xx\  = \ Map[\ #[t]&, xList]; \n\ \ \ \ 
        vv\  = \ Map[\(#'\)[t]&, xList]; \n\ \ \ \ 
        pp\  = \ Map[\ #[t]&, pList]; \n\ \ \ \ 
        sol = \ Solve[\ \((\(D[L, #]&\)\ /@\ vv)\)\  == \ pp, vv]\  // 
            Flatten; \n\ \ \ \ 
        ham = \ \(pp . vv - L\  //. sol\  // Simplify\)\  // Expand; \n
        \ \ \ \ eqp = \ D[pp, t] == \(-Map[D[ham, #]&, xx]\)\  // Thread; \n
        \ \ \ \ eqx = \ D[xx, t] == \(+Map[D[ham, #]&, pp]\)\  // Thread; \n
        \ \ \ \ eqs = \ Join[eqp, eqx]; \n\ \ \ \ Return[{sol, ham, eqs}]\n
        \ \ \ ]\n\)\)], "Input"],

Cell["1-D Lagrangian:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(L = m/2\ \(x'\)[t]^2\  - \ V[x[t]]\)], "Input"],

Cell["Hamilton results:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(xHamilton[L, {x}, {px}]\)], "Input"],

Cell["Representation of position, velocity, and momentum:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \({xx, vv, pp}\)], "Input"],

Cell["Equation relating velocity and momentum:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(\((\(D[L, #]&\)\ /@\ vv)\)\  == \ pp\)], "Input"],

Cell["Solution of this converts velocity to momentum:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(sol\)], "Input"],

Cell[TextData["Hamiltonian defined by H = mom \[Times] vel  -  L :"], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(ham\)], "Input"],

Cell["\<\
Equations of motion given by dp/dt = -dH/dx and dx/dt = +dH/dp:\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \({eqp, eqx}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example HJ1:  One-dimensional particle in a potential V[x].", 
  "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(L = m/2\ \(x'\)[t]^2\  - \ V[x[t]]; \)\)], "Input"],

Cell[BoxData[
    \(\({pRule, hamPrincFunc, eqHamJac} = \n\t\ \ 
      HamiltonJacobi[L, {x}, {p}, {W[x]}, a]; \)\)], "Input"],

Cell[BoxData[
    \(pRule\)], "Input"],

Cell[BoxData[
    \(hamPrincFunc\)], "Input"],

Cell[BoxData[
    \(eqHamJac\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example HJ2:  Two-dimensional particle in a potential V[x].", 
  "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(L = m/2\ \((\(x'\)[t]^2\  + \ \(y'\)[t]^2)\)\  - \ V[x[t], y[t]]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\({pRule, hamPrincFunc, eqHamJac} = \n\t\ \ 
      HamiltonJacobi[L, {x, y}, {px, py}, {W1[x], W2[y]}, a]; \)\)], "Input"],

Cell[BoxData[
    \(pRule\)], "Input"],

Cell[BoxData[
    \(hamPrincFunc\)], "Input"],

Cell[BoxData[
    \(eqHamJac\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "How ",
  StyleBox["HamiltonJacobi",
    FontFamily->"Terminal",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  " works."
}], "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["Version of HamiltonJacobi with no local variables:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(xHamiltonJacobi[L_, xList_List, pList__List, wList_List, a_, t_:  t] := 
      \ \n\ \ Module[{}, \n\ \ \ \ xx\  = \ Map[\ #[t]&, xList]; \n\ \ \ \ 
        vv\  = \ Map[\(#'\)[t]&, xList]; \n\ \ \ \ 
        pp\  = \ Map[\ #[t]&, pList]; \n\ \ \ \ 
        sol = \ Solve[\ \((\(D[L, #]&\)\ /@\ vv)\)\  == \ pp, vv]\  // 
            Flatten; \n\ \ \ \ 
        ham = \ \(\((pp . vv - L)\)\  //. sol\  // Simplify\)\  // Expand; \n
        \n\ \ \ \ ww\  = \ Map[\ #[t]&, wList, {2}]; \n\ \ \ \ 
        hamPrincFunc\  = \ \((Plus\ @@\ ww)\)\  - \ a\ t; \n\ \ \ \ 
        pNewRule\  = \ \n
          \ \ \ \ \ \ {
              pp\  -> \ \((\(D[hamPrincFunc, #]&\)\ /@\ xx)\)\  // Thread
                \ } // Flatten; \n\ \ \ \ 
        HJeq\  = \ \((ham //. pNewRule\ )\)\  - \ a\  == 0; \ \ \ \ \ \ \ \n
        \ \ \ \ \n\ \ \ \ Return[{sol, hamPrincFunc, HJeq}]\n\ \ \ ]\)], 
  "Input"],

Cell["1-D Lagrangian:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(L = m/2\ \(x'\)[t]^2\  - \ V[x[t]]\)], "Input"],

Cell["Hamilton results:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(xHamiltonJacobi[L, {x}, {p}, {W[x]}, a]\)], "Input"],

Cell["\<\
Representation of position, velocity, and momentum are the same as in \
Hamilton.  The W list is:\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(ww\)], "Input"],

Cell["The Hamilton's Principle function is:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(hamPrincFunc\)], "Input"],

Cell["Rule to eliminate momentum in terms of W'[x[t]]", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(pNewRule\)], "Input"],

Cell["\<\
The Hamilton-Jacobi equation given by H - a with this momentum \
substitution:\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(HJeq\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example DS1:  Expansion of harmonic oscillator using a series expansion of \
two first-order equations.\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(eq1\  = \ {\(p'\)[t]\  + w^2\ x[t]\  == \ 0, \ p[t] == \(x'\)[t]}\)], 
  "Input"],

Cell[BoxData[
    \(\({xser, pser} = 
      firstDiffSeries[eq1, {x, p}, {x[0] -> x0, p[0] -> p0}, 4, t]; \)\)], 
  "Input"],

Cell[BoxData[
    \(xser\)], "Input"],

Cell[BoxData[
    \(pser\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "How ",
  StyleBox["firstDiffSeries",
    FontFamily->"Terminal",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  " works."
}], "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["Version of firstDiffSeries with no local variables:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(xfirstDiffSeries[eqin_, {z_, p_}, initRule_List, order_, t_:  t] := \ \n
      \ Module[{}, \n\ \ \ 
        eq = Table[eqin[\([i, 1]\)] - eqin[\([i, 2]\)] == 0, {i, 2}]; \n\ \ \ 
        zSer = \ Series[z[t], {t, 0, order}]; \n\ \ \ 
        pSer = \ Series[p[t], {t, 0, order}]; \n\ \ \ 
        eSer = \ eq //. \(({z[t] -> zSer, p[t] -> pSer})\) // ExpandAll; \n
        \ \ \ vars = 
          \((Table[{D[z[t], {t, j}], \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
                    D[p[t], {t, j}]}, {j, 1, order + 1}] /. t -> 0)\) // 
            Flatten; \ \ \ \ \ \n\ \ \ 
        sol\  = \ Solve[eSer, vars]\  // Flatten; \n\ \ \ 
        zpSol = \ \({zSer, pSer}\  //. sol\)\  //. initRule; \n\ \ \ 
        Return[\ zpSol]\ \ \n\ ]\)], "Input"],

Cell[BoxData[
    \(\(eq1\  = \ {\(p'\)[t]\  + w^2\ x[t]\  == \ 0, \ p[t] == \(x'\)[t]}; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(xfirstDiffSeries[eq1, {x, p}, {x[0] -> x0, p[0] -> p0}, 4, t]; \)\)], 
  "Input"],

Cell["Rearranged input equations with right side == 0 .", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq\)], "Input"],

Cell["Perturbative expansion of position:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(zSer\)], "Input"],

Cell["Perturbative expansion of momentum:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eSer\)], "Input"],

Cell["List of unknown terms to be solved for:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(vars\)], "Input"],

Cell["Solutions for these unknown terms:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(sol\)], "Input"],

Cell["zSer and eSer with substitutions made:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(zpSol\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example P1:  Perturbed harmonic oscillator.", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(eq1\  = \ 
      \(\(x'\)'\)[t] == \(-\[Omega]^2\)\ x[t]\  + \ \[Epsilon]\ x[t]^2\)], 
  "Input"],

Cell[BoxData[
    \(firstOrderPert[eq1, x, {x0, 0}, \[Epsilon], t]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "How ",
  StyleBox["firstOrderPert",
    FontFamily->"Terminal",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  " works."
}], "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(xfirstOrderPert[eq1_, x_, {x0_, v0_}, eps_:  eps, t_:  t] := \n\ \ 
      Module[{}, \n\ \ \ \ \ 
        xRule = {x -> \((\(x[0]\)[#]\  + \ eps\ \(x[1]\)[#]&)\)}; \n\ \ \ \ \ 
        eq2 = eq1[\([1]\)] - eq1[\([2]\)]\  /. xRule; \n\ \ \ \ \ 
        eqEps = \ CoefficientList[eq2, eps] == 0\  // Thread; \n\ \ \ \ \ 
        initCon0 = {\(x[0]\)[0] == x0, \ \(\((x[0])\)'\)[0] == v0}; \n
        \ \ \ \ \ 
        initCon1 = {\(x[1]\)[0] == 0\ , \ \(\((x[1])\)'\)[0] == 0\ }; \n
        \ \ \ \ \ 
        dsol1 = \((\ 
            DSolve[Join[{eqEps[\([1]\)]}, initCon0], {\(x[0]\)[t]}, t]\ \n
              \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  // Flatten\ )\); \n\ \ \ \ \ 
        dsol2 = \((\ 
            DSolve[Join[{eqEps[\([2]\)]}, initCon1]\  //. dsol1, {
                  \(x[1]\)[t]}, t]\ \n\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  // 
              Flatten\ )\); \n\ \ \ \ \ 
        Return[\ \(x[t]\  /. xRule\)\  //. Join[dsol1, dsol2]\ ]\n\ \ \ ]\)], 
  "Input"],

Cell[BoxData[
    \(eq1\  = \ 
      \(\(x'\)'\)[t] == \(-\[Omega]^2\)\ x[t]\  + \ \[Epsilon]\ x[t]^2\)], 
  "Input"],

Cell[BoxData[
    \(xfirstOrderPert[eq1, x, {x0, 0}, \[Epsilon], t]\)], "Input"],

Cell["Expand the position variable:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(x[t] /. xRule\)], "Input"],

Cell["Substitute this into modified input equation:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq2\)], "Input"],

Cell[TextData["Group in powers of \[Epsilon] and set each == 0 ."], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eqEps\)], "Input"],

Cell["Unperturbed solution for position:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(dsol1\)], "Input"],

Cell["Perturbed solution for position:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(dsol2\)], "Input"],

Cell["Substitute these into perturbed expression for position:", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(\(x[t] /. xRule\) //. Join[dsol1, dsol2]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{588, 701},
WindowMargins->{{72, Automatic}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 115, 2, 166, "Title"],

Cell[CellGroupData[{
Cell[1871, 57, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2006, 62, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2102, 69, 58, 1, 69, "Subtitle"],
Cell[2163, 72, 109, 2, 70, "Input"],
Cell[2275, 76, 90, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2402, 83, 69, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2496, 88, 141, 6, 69, "Section"],

Cell[CellGroupData[{
Cell[2662, 98, 130, 3, 63, "Subsection"],
Cell[2795, 103, 68, 1, 30, "Input"],
Cell[2866, 106, 56, 1, 30, "Input"],
Cell[2925, 109, 101, 2, 30, "Input"],
Cell[3029, 113, 57, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3123, 119, 124, 3, 63, "Subsection"],
Cell[3250, 124, 67, 1, 30, "Input"],
Cell[3320, 127, 86, 1, 30, "Input"],
Cell[3409, 130, 38, 1, 30, "Input"],
Cell[3450, 133, 36, 1, 30, "Input"],
Cell[3489, 136, 41, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3567, 142, 125, 3, 63, "Subsection"],
Cell[3695, 147, 100, 2, 30, "Input"],
Cell[3798, 151, 93, 1, 30, "Input"],
Cell[3894, 154, 38, 1, 30, "Input"],
Cell[3935, 157, 36, 1, 30, "Input"],
Cell[3974, 160, 41, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4052, 166, 192, 8, 67, "Subsection"],
Cell[4247, 176, 92, 1, 33, "Text"],
Cell[4342, 179, 687, 11, 270, "Input"],
Cell[5032, 192, 63, 1, 33, "Text"],
Cell[5098, 195, 67, 1, 30, "Input"],
Cell[5168, 198, 65, 1, 33, "Text"],
Cell[5236, 201, 56, 1, 30, "Input"],
Cell[5295, 204, 99, 1, 33, "Text"],
Cell[5397, 207, 45, 1, 30, "Input"],
Cell[5445, 210, 88, 1, 33, "Text"],
Cell[5536, 213, 69, 1, 30, "Input"],
Cell[5608, 216, 95, 1, 33, "Text"],
Cell[5706, 219, 36, 1, 30, "Input"],
Cell[5745, 222, 109, 1, 33, "Text"],
Cell[5857, 225, 36, 1, 30, "Input"],
Cell[5896, 228, 119, 3, 33, "Text"],
Cell[6018, 233, 43, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6098, 239, 117, 2, 63, "Subsection"],
Cell[6218, 243, 73, 1, 30, "Input"],
Cell[6294, 246, 126, 2, 50, "Input"],
Cell[6423, 250, 38, 1, 30, "Input"],
Cell[6464, 253, 45, 1, 30, "Input"],
Cell[6512, 256, 41, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6590, 262, 117, 2, 63, "Subsection"],
Cell[6710, 266, 108, 2, 30, "Input"],
Cell[6821, 270, 142, 2, 50, "Input"],
Cell[6966, 274, 38, 1, 30, "Input"],
Cell[7007, 277, 45, 1, 30, "Input"],
Cell[7055, 280, 41, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7133, 286, 198, 8, 67, "Subsection"],
Cell[7334, 296, 98, 1, 33, "Text"],
Cell[7435, 299, 913, 16, 330, "Input"],
Cell[8351, 317, 63, 1, 33, "Text"],
Cell[8417, 320, 67, 1, 30, "Input"],
Cell[8487, 323, 65, 1, 33, "Text"],
Cell[8555, 326, 72, 1, 30, "Input"],
Cell[8630, 329, 153, 4, 33, "Text"],
Cell[8786, 335, 35, 1, 30, "Input"],
Cell[8824, 338, 85, 1, 33, "Text"],
Cell[8912, 341, 45, 1, 30, "Input"],
Cell[8960, 344, 95, 1, 33, "Text"],
Cell[9058, 347, 41, 1, 30, "Input"],
Cell[9102, 350, 134, 4, 33, "Text"],
Cell[9239, 356, 37, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9313, 362, 166, 4, 82, "Subsection"],
Cell[9482, 368, 101, 2, 30, "Input"],
Cell[9586, 372, 124, 3, 30, "Input"],
Cell[9713, 377, 37, 1, 30, "Input"],
Cell[9753, 380, 37, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9827, 386, 199, 8, 67, "Subsection"],
Cell[10029, 396, 99, 1, 33, "Text"],
Cell[10131, 399, 768, 13, 250, "Input"],
Cell[10902, 414, 109, 2, 30, "Input"],
Cell[11014, 418, 103, 2, 30, "Input"],
Cell[11120, 422, 97, 1, 33, "Text"],
Cell[11220, 425, 35, 1, 30, "Input"],
Cell[11258, 428, 83, 1, 33, "Text"],
Cell[11344, 431, 37, 1, 30, "Input"],
Cell[11384, 434, 83, 1, 33, "Text"],
Cell[11470, 437, 37, 1, 30, "Input"],
Cell[11510, 440, 87, 1, 33, "Text"],
Cell[11600, 443, 37, 1, 30, "Input"],
Cell[11640, 446, 82, 1, 33, "Text"],
Cell[11725, 449, 36, 1, 30, "Input"],
Cell[11764, 452, 86, 1, 33, "Text"],
Cell[11853, 455, 38, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11928, 461, 98, 1, 63, "Subsection"],
Cell[12029, 464, 117, 3, 30, "Input"],
Cell[12149, 469, 79, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12265, 475, 198, 8, 67, "Subsection"],
Cell[12466, 485, 985, 18, 270, "Input"],
Cell[13454, 505, 117, 3, 30, "Input"],
Cell[13574, 510, 80, 1, 30, "Input"],
Cell[13657, 513, 77, 1, 33, "Text"],
Cell[13737, 516, 46, 1, 30, "Input"],
Cell[13786, 519, 93, 1, 33, "Text"],
Cell[13882, 522, 36, 1, 30, "Input"],
Cell[13921, 525, 107, 1, 33, "Text"],
Cell[14031, 528, 38, 1, 30, "Input"],
Cell[14072, 531, 82, 1, 33, "Text"],
Cell[14157, 534, 38, 1, 30, "Input"],
Cell[14198, 537, 80, 1, 33, "Text"],
Cell[14281, 540, 38, 1, 30, "Input"],
Cell[14322, 543, 104, 1, 33, "Text"],
Cell[14429, 546, 73, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

