(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7854,        278]*)
(*NotebookOutlinePosition[      8505,        301]*)
(*  CellTagsIndexPosition[      8461,        297]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*`\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.1  Lagrangian Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 1:  Atwood's Machine", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Express the Lagrangian in terms only of x[1].  Find the equations \
of motion and solve.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(lenRule = x[2] -> \((\((Len - \(x[1]\)[#])\)&)\)\)], "Input"],

Cell[BoxData[
    \(T = 1/2\ Sum[m[i]\ D[\(x[i]\)[t], t]^2, {i, 1, 2}]\)], "Input"],

Cell[BoxData[
    \(V = \(-g\)\ Sum[m[i]\ \(x[i]\)[t], {i, 1, 2}]\)], "Input"],

Cell[BoxData[
    \(L = T - V /. lenRule // Simplify\)], "Input"],

Cell[BoxData[
    \(eq1 = Lag[x[1], L]\)], "Input"],

Cell[BoxData[
    \(initial = {\(x[1]\)[0] == x0, \ \(x[1]'\)[0] == v0}\)], "Input"],

Cell[BoxData[
    \(sol = 
      \(DSolve[Join[{eq1}, initial], \(x[1]\)[t], t] // Flatten\) // Simplify
        \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Express the Lagrangian in terms of x[1] and x[2]. Find the \
Larangian multipliers from the constraint that the cord does not stretch.   \
Find the equations of motion for x[1] and x[2] using Lagrange multipliers.  \
Solve for the motion.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(L = T - V\)], "Input"],

Cell[BoxData[
    \(f[1] = \ \(x[1]\)[t]\  + \ \(x[2]\)[t]\  - \ Len\)], "Input"],

Cell[BoxData[
    \(Q[i_] := Sum[D[f[j], \(x[i]\)[t]] \[Lambda][j], {j, 1, 1}]\)], "Input"],

Cell[BoxData[
    \(Array[Q, 2]\)], "Input"],

Cell[BoxData[
    \(eq2 = Table[Lag[x[i], L, Q[i]], {i, 1, 2}]\)], "Input"],

Cell[BoxData[
    \(f[1] == 0\)], "Input"],

Cell[BoxData[
    \(eq3 = D[f[1] == 0, {t, 2}]\)], "Input"],

Cell[BoxData[
    \(eq4 = 
      \((Solve[Join[eq2, {eq3}], \n
              \t\t{\[Lambda][1], \(\(x[2]'\)'\)[t], \(\(x[1]'\)'\)[t]}, t] // 
            Flatten)\)\n /. {Rule -> Equal}\)], "Input"],

Cell[BoxData[
    \(\(initial = {\(x[1]\)[0] == x0, \ \(x[1]'\)[0] == v0}; \)\)], "Input"],

Cell[BoxData[
    \(sol1 = 
      \(DSolve[eq4[\([{3}]\)]~Join~initial\n\t\t\t\t, {\(x[1]\)[t]}, t] // 
          Flatten\) // FullSimplify\)], "Input"],

Cell[BoxData[
    \(sol2 = {\(x[2]\)[t] -> Len - \(x[1]\)[t] /. sol1}\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 2:  Bead Sliding on a Rotating Wire", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Solve for the motion of the bead assuming r[0]=r0 amd r'[0]=v0.  \
Express the results in terms of hyperbolic functions.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(x2rRule = {x, y, z} -> {\((r[#]\ Sin[\[Theta]] Cos[\[Omega]\ #])\)&, \n
            \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \((r[#]\ Sin[\[Theta]] Sin[\[Omega]\ #])\)&, \n
            \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ 
            \((\(-r[#]\)\ Cos[\[Theta]]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ )
                \)&}\n\t\t\t\t\t // Thread\)], "Input"],

Cell[BoxData[
    \(T = 
      m/2\ \((\(x'\)[t]^2\  + \ \(y'\)[t]^2\  + \(z'\)[t]^2)\) //. x2rRule // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(V = m\ g\ z[t] //. x2rRule\)], "Input"],

Cell[BoxData[
    \(L = \(T - V // TrigReduce\) // Collect[#, {m}]&\)], "Input"],

Cell[BoxData[
    \(eq1 = Lag[r, L]\)], "Input"],

Cell[BoxData[
    \(rSol = 
      \((\(Solve[eq1, \(\(r'\)'\)[t]]\n\t\t\t\t\t // Flatten\)\n\t\t\t\t\t // 
            Simplify\n\t\t\ \ \ \ \ )\) /. {Rule -> Equal}\)], "Input"],

Cell[BoxData[
    \(initial = {r[0] == r0, \(r'\)[0] == v0}\)], "Input"],

Cell[BoxData[
    \(rRule = 
      \(\(DSolve[Join[rSol, initial], r[t], t]\n\t\t\t\t // Flatten\) // 
          ExpToTrig\) // Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Let r0 and v0 be 0 at t=0 and find the time it takes for the bead \
to move a distance Len.  Evaluate the time for the special case \[Theta]=0. \
"], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(tRule = 
      \(Solve[\(Len == r[t] /. rRule\) /. {v0 -> 0, r0 -> 0}, t]\)[
          \([2]\)] // Simplify\)], "Input"],

Cell[BoxData[
    \(Limit[t //. tRule, \[Theta] -> 0] // PowerExpand\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)   Let r0 and v0 be 0 at t=0 and graph the motion of the bead as a \
function of time.. \
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(values = {\[Theta] -> \[Pi]/13, g -> 1, \[Omega] -> 2, v0 -> 0, r0 -> 0}
        \)], "Input"],

Cell[BoxData[
    \(\(position = 
      \((\(\({x[t], y[t], z[t]} //. x2rRule\) //. rRule\) //. values // N)\); 
    \)\)], "Input"],

Cell[BoxData[
    \(\(p1 = 
      ParametricPlot3D[position // Evaluate, {t, 0, 6}\n\t\ \ , 
        Boxed -> True\n\t\t, Axes -> False\n\t\ \ , BoxRatios -> {1, 1, 1}\n
        \t]; \)\)], "Input"],

Cell[BoxData[
    \(\(disPoints = Table[position, {t, 0, 6, 0.5}]; \)\)], "Input"],

Cell[BoxData[
    \(\(disGraphics\  = \ 
      Graphics3D[{PointSize[0.03]\n\t\t\t, Point/@disPoints}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Show[disGraphics, p1\n\t\ , BoxRatios -> {1, 1, 1}]; \)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{528, 624},
WindowMargins->{{10, Automatic}, {Automatic, 15}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],
Cell[1872, 56, 58, 1, 80, "Subtitle"],
Cell[1933, 59, 109, 2, 70, "Input"],
Cell[2045, 63, 90, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[2160, 69, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2250, 74, 78, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2353, 79, 83, 1, 63, "Subsection"],
Cell[2439, 82, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2525, 87, 167, 4, 76, "Subsubsection"],
Cell[2695, 93, 81, 1, 30, "Input"],
Cell[2779, 96, 83, 1, 30, "Input"],
Cell[2865, 99, 78, 1, 30, "Input"],
Cell[2946, 102, 65, 1, 30, "Input"],
Cell[3014, 105, 51, 1, 30, "Input"],
Cell[3068, 108, 84, 1, 30, "Input"],
Cell[3155, 111, 126, 3, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3318, 119, 317, 6, 93, "Subsubsection"],
Cell[3638, 127, 42, 1, 30, "Input"],
Cell[3683, 130, 81, 1, 30, "Input"],
Cell[3767, 133, 91, 1, 30, "Input"],
Cell[3861, 136, 44, 1, 30, "Input"],
Cell[3908, 139, 75, 1, 30, "Input"],
Cell[3986, 142, 42, 1, 30, "Input"],
Cell[4031, 145, 59, 1, 30, "Input"],
Cell[4093, 148, 198, 4, 70, "Input"],
Cell[4294, 154, 90, 1, 30, "Input"],
Cell[4387, 157, 152, 3, 50, "Input"],
Cell[4542, 162, 82, 1, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4673, 169, 98, 1, 63, "Subsection"],
Cell[4774, 172, 61, 1, 30, "Input"],
Cell[4838, 175, 70, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[4933, 180, 199, 4, 76, "Subsubsection"],
Cell[5135, 186, 469, 7, 90, "Input"],
Cell[5607, 195, 133, 3, 30, "Input"],
Cell[5743, 200, 59, 1, 30, "Input"],
Cell[5805, 203, 80, 1, 30, "Input"],
Cell[5888, 206, 48, 1, 30, "Input"],
Cell[5939, 209, 178, 3, 90, "Input"],
Cell[6120, 214, 72, 1, 30, "Input"],
Cell[6195, 217, 149, 3, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6381, 225, 228, 4, 76, "Subsubsection"],
Cell[6612, 231, 140, 3, 50, "Input"],
Cell[6755, 236, 81, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6873, 242, 164, 4, 59, "Subsubsection"],
Cell[7040, 248, 114, 2, 30, "Input"],
Cell[7157, 252, 132, 3, 50, "Input"],
Cell[7292, 257, 198, 4, 110, "Input"],
Cell[7493, 263, 82, 1, 30, "Input"],
Cell[7578, 266, 119, 2, 50, "Input"],
Cell[7700, 270, 90, 1, 50, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

