(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10904,        368]*)
(*NotebookOutlinePosition[     11796,        398]*)
(*  CellTagsIndexPosition[     11752,        394]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*`\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.1  Lagrangian Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 3:  Bead on a Rotating Hoop", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Construct the Lagrangian and derive the equations of motion.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(x2rRule = 
      Thread[{x, y, z} 
          \[Rule] {r\ Sin[\[Theta][#1]]\ Cos[\[Omega]\ #1]&, 
            r\ Sin[\[Theta][#1]]\ Sin[\[Omega]\ #1]&, 
            r\ Cos[\[Theta][#1]]&}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    RowBox[{
      RowBox[{"T", "=", 
        RowBox[{\(1\/2\), " ", "m", " ", 
          RowBox[{"(", 
            RowBox[{
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["x", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["z", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], 
            ")"}]}]}], ";"}], \(V = m\ g\ z[t]; \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(L = 
      ExpandAll[
        TrigReduce[Simplify[T - V //. x2rRule]] //. {
            Cos[x_]\^2 \[Rule] 1 - Sin[x]\^2}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Lag[\[Theta], L]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"\[Theta]Sol", "=", 
      RowBox[{"ExpandAll", "[", 
        RowBox[{\((Flatten //. {g \[Rule] \[Omega]c\^2\ r})\), "[", 
          RowBox[{"Solve", "[", 
            RowBox[{\(Lag[\[Theta], L]\), ",", 
              RowBox[{
                SuperscriptBox["\[Theta]", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "]"}], "]"}], 
        "]"}]}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"energy", "=", 
      RowBox[{"ExpandAll", "[", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{
                  SuperscriptBox["\[Theta]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                RowBox[{
                  SubscriptBox["\[PartialD]", 
                    RowBox[{
                      SuperscriptBox["\[Theta]", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}]], "L"}]}], 
              "-", "L"}], "//.", \({g \[Rule] \[Omega]c\^2\ r}\)}], "//.", 
          \({Cos[x_]\^2 \[Rule] 1 - Sin[x]\^2}\)}], "]"}]}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\({pRule, hamiltonian, eqMotion} = 
      Hamilton[L, {\[Theta]}, {p\[Theta]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(energy == hamiltonian //. {g \[Rule] \[Omega]c\^2\ r}\) //. pRule\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Expand[
      \(\[PartialD]\_t energy //. \[Theta]Sol\) //. {
          g \[Rule] \[Omega]c\^2\ r}]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Construct the conserved energy and verify that it is conserved.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    RowBox[{"Veff", "=", 
      RowBox[{"energy", "//.", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["\[Theta]", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], 
          "}"}]}]}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(dVeff = Factor[\[PartialD]\_\(\[Theta][t]\)Veff]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Solve[dVeff\/Sin[\[Theta][t]] == 0, \[Theta][t]]
        \)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eqRule = 
      \[Theta][t] 
        \[Rule] {0, \[Pi], ArcCos[\(-\(\[Omega]c\^2\/\[Omega]\^2\)\)], 
          ArcCos[\(+\[Omega]c\^2\)\/\[Omega]\^2] + \[Pi]}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Thread[dVeff == 0 /. eqRule]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)   Define a potential for the system and find the equilibrium \
points.  Show that the characteristics of the potential change at \[Omega]=\
\[Omega]c, where \[Omega]c^2 =g/r.  Graph the potential for the two \
characteristic types of potentials."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(values1 = {r \[Rule] 1, \[Omega]c \[Rule] 1, m \[Rule] 1, 
        \[Theta][t] \[Rule] \[Theta]}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Plot3D[
      Evaluate[Veff //. values1], {\[Theta], \(-\[Pi]\), \[Pi]}, {\[Omega], 
        1, 3}, AxesLabel 
        \[Rule] {"\<\[Theta]\>", "\<\[Omega]\>", "\<Potential\>"}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(p1 = 
      Plot[Evaluate[\(Veff //. values1\) /. {\[Omega] \[Rule] 0.2}], {
          \[Theta], \(-\[Pi]\), \[Pi]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(p2 = 
      Plot[Evaluate[\(Veff //. values1\) /. {\[Omega] \[Rule] 2.0}], {
          \[Theta], \(-\[Pi]\), \[Pi]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[p1, p2]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (d)   Numerically solve for \[Theta][t] and \[Theta]'[t] and plot the \
data."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1 = 
      \(\[Theta]Sol //. {g \[Rule] \[Omega]c\^2\ r}\) /. 
        Rule \[Rule] Equal\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"eq2", "=", 
      RowBox[{"Flatten", "[", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"eq1", "/.", 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["\[Theta]", "\[DoublePrime]",
                      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
                  RowBox[{
                    SuperscriptBox["d\[Theta]", "\[Prime]",
                      MultilineFunction->None], "[", "t", "]"}]}], "}"}]}], 
            ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "==", 
              \(d\[Theta][t]\)}]}], "}"}], "]"}]}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values2 = {\[Omega] \[Rule] 2, \[Omega]c \[Rule] 1}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(initial = {\[Theta][0] == \[Pi], d\[Theta][0] == 0.01}; \)\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(ndsol1 = 
      \(NDSolve[
          Flatten[{eq2 //. values2, initial}], {\[Theta][t], d\[Theta][t]}, {
            t, 0, 30}]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(\[Theta]1[t_] = 
      \[Theta][t] /. ndsol1\[LeftDoubleBracket]1\[RightDoubleBracket]; \n
    d\[Theta]1[t_] = 
      d\[Theta][t] /. ndsol1\[LeftDoubleBracket]2\[RightDoubleBracket]; \)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Plot[\[Theta]1[t], {t, 0, 30}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Plot[d\[Theta]1[t], {t, 0, 30}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (e)   Animate the numerical results.", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(bead[t_] := 
      Graphics[{PointSize[0.03], 
          Point[{Sin[\[Theta]1[t]], Cos[\[Theta]1[t]]}]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(frames = 20; \n
    Do[Show[bead[t], 
        Graphics[{Hue[ .08], Circle[{0, 0}, 1]}, 
          AspectRatio \[Rule] Automatic], 
        PlotRange \[Rule] {{\(-2\), 2}, {\(-2\), 2}}], {t, 0, 18, 
        18\/\(frames - 1\)}]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{634, 702},
WindowMargins->{{20, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 85, 3, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2151, 71, 58, 1, 69, "Subtitle"],
Cell[2212, 74, 109, 2, 70, "Input"],
Cell[2324, 78, 90, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2451, 85, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2541, 90, 78, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2644, 95, 90, 1, 63, "Subsection"],
Cell[2737, 98, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2823, 103, 139, 3, 59, "Subsubsection"],
Cell[2965, 108, 252, 6, 50, "Input"],
Cell[3220, 116, 765, 19, 63, "Input"],
Cell[3988, 137, 181, 5, 51, "Input"],
Cell[4172, 144, 75, 2, 30, "Input"],
Cell[4250, 148, 444, 10, 31, "Input"],
Cell[4697, 160, 718, 17, 31, "Input"],
Cell[5418, 179, 141, 3, 30, "Input"],
Cell[5562, 184, 129, 3, 31, "Input"],
Cell[5694, 189, 158, 4, 31, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5889, 198, 142, 3, 59, "Subsubsection"],
Cell[6034, 203, 321, 9, 30, "Input"],
Cell[6358, 214, 107, 2, 30, "Input"],
Cell[6468, 218, 162, 3, 44, "Input"],
Cell[6633, 223, 223, 5, 44, "Input"],
Cell[6859, 230, 87, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6983, 237, 325, 5, 93, "Subsubsection"],
Cell[7311, 244, 161, 3, 30, "Input"],
Cell[7475, 249, 245, 6, 50, "Input"],
Cell[7723, 257, 181, 4, 30, "Input"],
Cell[7907, 263, 181, 4, 30, "Input"],
Cell[8091, 269, 77, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8205, 276, 153, 3, 59, "Subsubsection"],
Cell[8361, 281, 150, 4, 31, "Input"],
Cell[8514, 287, 803, 20, 30, "Input"],
Cell[9320, 309, 116, 2, 30, "Input"],
Cell[9439, 313, 121, 3, 30, "Input"],
Cell[9563, 318, 232, 6, 50, "Input"],
Cell[9798, 326, 247, 6, 50, "Input"],
Cell[10048, 334, 95, 2, 30, "Input"],
Cell[10146, 338, 96, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10279, 345, 101, 1, 59, "Subsubsection"],
Cell[10383, 348, 169, 4, 30, "Input"],
Cell[10555, 354, 285, 7, 104, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

