(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12612,        459]*)
(*NotebookOutlinePosition[     13503,        489]*)
(*  CellTagsIndexPosition[     13459,        485]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.1  Lagrangian Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell[TextData[
"Problem 4:  Hoop Rolling on an Incline of Angle \[Phi]"], "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)   Assume that x and \[Theta] are generalized coordinates and \
construct the Lagrangian.  Write the slippage constraint and use Lagrangian \
multipliers to obtain the equations of motion for the variables x and \
\[Theta]."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(T\  = \ m/2\ \((\(x'\)[t]^2\  + \ r^2\ \(\[Theta]'\)[t]^2)\)\)], "Input"],

Cell[BoxData[
    \(V\  = \ m\ g\ \((Len\  - \ x[t])\)\ Sin[\[Phi]]\)], "Input"],

Cell[BoxData[
    \(L\  = \ T - V\)], "Input"],

Cell[BoxData[
    \(eq1\  = \ r\ \[Theta][t]\  - \ x[t]\  == \ 0\)], "Input"],

Cell[BoxData[
    \(constraintForce\  = 
      \ {Q[1] -> \[Lambda]\ D[eq1[\([1]\)], x[t]]\n
        \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ , Q[2] -> \[Lambda]\ D[eq1[\([1]\)], \[Theta][t]]}\)], "Input"],

Cell[BoxData[
    \(eqX\  = \ Lag[x, L, Q[1]] /. constraintForce\)], "Input"],

Cell[BoxData[
    \(eq\[Theta]\  = \ \ Lag[\[Theta], L, Q[2]] /. constraintForce\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Solve the equarions of motion for x[t] and \[Theta][t]."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(initial\  = 
      \ {x[0] == x0, \(x'\)[0] == v0, \[Theta][0] == x0/r, \ 
        \(\[Theta]'\)[0] == v0/r}\)], "Input"],

Cell[BoxData[
    \(\(eq2\  = \ Join[{eqX, eq\[Theta]}, initial]; \)\)], "Input"],

Cell[BoxData[
    \(xtSol = DSolve[eq2, {x, \[Theta]}, t] // Flatten\)], "Input"],

Cell[BoxData[
    \(\[Lambda]Sol\  = \ Solve[eq1 //. xtSol, {\[Lambda]}] // Flatten\)], 
  "Input"],

Cell[BoxData[
    \(xtSol2\  = \ xtSol //. \[Lambda]Sol\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (c)   Plot the results.", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(values = {x0 -> 0, v0 -> 0, g -> \(-0.1\), \[Phi] -> \[Pi]/4, r -> 2}
        \)], "Input"],

Cell[BoxData[
    \(posx = x[t] Sin[\[Phi]]\  + \ r\ Sin[\[Theta][t]]\)], "Input"],

Cell[BoxData[
    \(posy = x[t] Cos[\[Phi]]\  + \ r\ Cos[\[Theta][t]]\)], "Input"],

Cell[BoxData[
    \(point = \({posx, posy} /. xtSol2\) //. values // N\)], "Input"],

Cell[BoxData[
    \(\(ParametricPlot[point // Evaluate, {t, 0, 70}\n, AspectRatio -> 1]; 
    \)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 5:  Sphere Rolling on an Fixed Sphere", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)   Spheres have radii a and b.  Assume the generalized coordinates \
are {r[t], \[Theta]1[t], and \[Theta]2[t]} and construct the Lagrangian.  \
Write the  constraint that there is no slippage.  Use Lagrangian multipliers \
to obtain the equations of motion for the variables x and \[Theta]."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
Take the origin at the center of the fixed sphere.  Let r be the distance to \
the center of the rolling sphere and I1 be its moment of inertia.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(Tcm\  = \ m/2\ \((\(r'\)[t]^2\  + \ r[t]^2\ \(\[Theta]1'\)[t]^2)\)\)], 
  "Input"],

Cell[BoxData[
    \(Trot\  = \ I1/2\ \((\(\[Theta]1'\)[t]\  + \ \(\[Theta]2'\)[t])\)^2\)], 
  "Input"],

Cell[BoxData[
    \(T\  = \ Tcm\  + \ Trot\)], "Input"],

Cell[BoxData[
    \(V = m\ g\ r[t]\ Cos[\[Theta]1[t]]\)], "Input"],

Cell[BoxData[
    \(L\  = \ T - V\)], "Input"],

Cell[BoxData[
    \(constraints = {b\ \[Theta]1[t] - a\ \[Theta]2[t] == 0\n
        \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
        r[t] - a - b == 0}\)], "Input"],

Cell[BoxData[
    \(conRule = {DSolve[constraints[\([1]\)], {\[Theta]2}, t]\n
          \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ , 
          DSolve[constraints[\([2]\)], {r}, t]} // Flatten\)], "Input"],

Cell[BoxData[
    \(\(coordinates = {r, \[Theta]1, \[Theta]2}; \)\)], "Input"],

Cell[BoxData[
    \(coordinatesT = coordinates // Map[\(Composition[#]\)[t]&, #]&\)], 
  "Input"],

Cell[BoxData[
    \(Clear[Q]; \n
    Q[i_] := \n\t
      Sum[\[Lambda][j]*
          D[constraints[\([j, 1]\)]\n\t\t\t, coordinatesT[\([i]\)]\ ], {j, 1, 
          2}]\)], "Input"],

Cell[BoxData[
    \(Array[Q, 3]\)], "Input"],

Cell[BoxData[
    \(eqMotion = Table[Lag[coordinates[\([i]\)], L, Q[i]], {i, 3}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Show that the equation for \[Theta]1[t] can be reduced to a first \
integral."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(sol1 = 
      \((Solve[eqMotion //. conRule, {\(\(\[Theta]1'\)'\)[t], \[Lambda][1], 
              \[Lambda][2]}]\n\t // Flatten)\)\)], "Input"],

Cell[BoxData[
    \(eq\[Theta]\  = \ 
      \((\(\(\[Theta]1'\)'\)[t] //. sol1)\) - \(\(\[Theta]1'\)'\)[t] == 0\)], 
  "Input"],

Cell[BoxData[
    \(SetOptions[Limit, Analytic -> True]\)], "Input"],

Cell[BoxData[
    \(int\[Theta]\  = \ 
      \((Integrate[eq\[Theta][\([1]\)]\ \(\[Theta]1'\)[t], {t, 0, t}]\n
            \t //. {\[Theta]1[0] -> 0, \(\[Theta]1'\)[0] -> 0} // Simplify)
        \)\)], "Input"],

Cell[BoxData[
    \(sol\[Theta] = 
      \(Solve[int\[Theta] == 0, {\(\[Theta]1'\)[t]}]\)[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(\(\[Theta]1'\)[t]^2 //. sol\[Theta] // Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (c)   Find the angle at which the sphere falls off.", 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1 = \(0 == \[Lambda][2] //. sol1\) //. sol\[Theta] // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(sol2\  = \ Solve[eq1, Cos[\[Theta]1[t]]] // Flatten\)], "Input"],

Cell[BoxData[
    \(sol3\  = \ 
      \(Solve[sol2 //. {Rule -> Equal}, \[Theta]1[t]]\)[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(\(\((\[Theta]1[t]/Degree)\) //. sol3\) //. {I1 -> \((2/5)\) m\ a^2} // N
      \)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem 6:  Mass Falling Through a Hole in a Table", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)   Find the equations of motion for the variables r[t] and \
\[Phi][t]."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(T1 = m1/2\ \((\(r'\)[t]^2\  + \ \((r[t] \(\[Phi]'\)[t])\)^2)\)\)], 
  "Input"],

Cell[BoxData[
    \(\(V1 = 0; \)\)], "Input"],

Cell[BoxData[
    \(T2 = m2/2\ \(r'\)[t]^2\)], "Input"],

Cell[BoxData[
    \(V2 = \(-m2\)\ g \((len - r[t])\)\)], "Input"],

Cell[BoxData[
    \(L = \((T1 + T2)\) - \((V1 + V2)\)\)], "Input"],

Cell[BoxData[
    \(Lag[r, L]\)], "Input"],

Cell[BoxData[
    \(eqR = 
      \((\((Solve[Lag[r, L], \(\(r'\)'\)[t]] // Flatten)\) //. {
            Rule -> Equal})\)\)], "Input"],

Cell[BoxData[
    \(eq\[CapitalPhi] = 
      \((\((Solve[Lag[\[Phi], L], \(\(\[Phi]'\)'\)[t]] // Flatten)\) //. {
            Rule -> Equal})\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Find the two constants of motion that correspond to angular \
momentum and energy conservation.  Express the constants in therms if \
{r[0]=r0, r'[0]=0, \[Phi][0]=0, \[Phi]'[0]=0}."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1 = D[L, \(\[Phi]'\)[t]] == m1\ r0^2\ d\[Phi]0\)], "Input"],

Cell[BoxData[
    \(eq\[CapitalPhi] //. Solve[D[eq1, t], \(\(\[Phi]'\)'\)[t]]\)], "Input"],

Cell[BoxData[
    \(sol\[CapitalPhi] = DSolve[eq1, \[Phi]', t] // Flatten\)], "Input"],

Cell[BoxData[
    \(energy = 
      \((T1 + T2)\) + \((V1 + V2)\) //. sol\[CapitalPhi] // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(eqMotion = {eqR, eq\[CapitalPhi]} /. {Equal -> Rule} // Flatten\)], 
  "Input"],

Cell[BoxData[
    \(\(D[energy, t] //. eqMotion\) //. sol\[CapitalPhi] // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(initial = {r[0] -> r0, \ \(r'\)[0] -> 0, \ \[Phi][0] -> 0, \ 
        \(\[Phi]'\)[0] -> d\[Phi]0}\)], "Input"],

Cell[BoxData[
    \(energy0 = \(energy //. {t -> 0}\) //. initial\)], "Input"],

Cell[BoxData[
    \(rSol = \(Solve[energy == energy0, \(r'\)[t]]\)[\([2]\)]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)   Solve the limiting case where m1 describes a circle, r[t]=r0.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(sol1 = 
      \(Solve[eqR //. {\(\(r'\)'\)[t] -> 0, r[t] -> r0}, \(\[Phi]'\)[t]]\)[
        \([2]\)]\)], "Input"],

Cell[BoxData[
    \(dsol1 = 
      DSolve[\((sol1 /. {Rule -> Equal})\), \[Phi][t], t] // Flatten\)], 
  "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (d)   If the circular orbit is displaced by \[Delta]r[t], find the \
angular frequence \[Omega] with which \[Delta]r[t] oscillates about a \
circular orbit."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(radiusRule = {r -> \((r0 + dr[#]&)\)}\)], "Input"],

Cell[BoxData[
    \(eq2 = \(eqR //. sol\[CapitalPhi]\) //. radiusRule\)], "Input"],

Cell[BoxData[
    \(rhs = 
      \((\(\((Series[eq2[\([1, 2]\)], {dr[t], 0, 1}] // Normal)\)\n
            \t //. {d\[Phi]0 -> \(\[Phi]'\)[t]}\)\n\t //. sol1)\)\)], "Input"],

Cell[BoxData[
    \(displacement = \(\(dr'\)'\)[t] == rhs\)], "Input"],

Cell[BoxData[
    \(dsol9\  = \ 
      DSolve[{displacement, dr[0] == dr0, \(dr'\)[0] == 0}, {dr[t]}, t]\n
        \t\ \ \  // Flatten\)], "Input"],

Cell[BoxData[
    \(\((Solve[\((dr[t] /. dsol9)\) == dr0\ Cos[\[Omega]\ t], \[Omega]] //. {
            ArcCos[Cos[x_]] :> x})\)\ [\([2]\)]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{618, 686},
WindowMargins->{{Automatic, 36}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 85, 3, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2151, 71, 58, 1, 69, "Subtitle"],
Cell[2212, 74, 108, 2, 70, "Input"],
Cell[2323, 78, 96, 2, 30, "Input"],
Cell[2422, 82, 90, 2, 30, "Input"],
Cell[2515, 86, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2612, 92, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2702, 97, 78, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2805, 102, 120, 2, 63, "Subsection"],

Cell[CellGroupData[{
Cell[2950, 108, 302, 5, 93, "Subsubsection"],
Cell[3255, 115, 93, 1, 30, "Input"],
Cell[3351, 118, 80, 1, 30, "Input"],
Cell[3434, 121, 46, 1, 30, "Input"],
Cell[3483, 124, 77, 1, 30, "Input"],
Cell[3563, 127, 238, 4, 50, "Input"],
Cell[3804, 133, 77, 1, 30, "Input"],
Cell[3884, 136, 93, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4014, 142, 140, 3, 59, "Subsubsection"],
Cell[4157, 147, 141, 3, 30, "Input"],
Cell[4301, 152, 81, 1, 30, "Input"],
Cell[4385, 155, 81, 1, 30, "Input"],
Cell[4469, 158, 99, 2, 30, "Input"],
Cell[4571, 162, 68, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4676, 168, 88, 1, 59, "Subsubsection"],
Cell[4767, 171, 111, 2, 30, "Input"],
Cell[4881, 175, 82, 1, 30, "Input"],
Cell[4966, 178, 82, 1, 30, "Input"],
Cell[5051, 181, 83, 1, 30, "Input"],
Cell[5137, 184, 109, 2, 50, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5295, 192, 100, 1, 63, "Subsection"],
Cell[5398, 195, 54, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[5477, 200, 373, 6, 93, "Subsubsection"],
Cell[5853, 208, 200, 4, 52, "Text"],
Cell[6056, 214, 102, 2, 30, "Input"],
Cell[6161, 218, 102, 2, 30, "Input"],
Cell[6266, 222, 55, 1, 30, "Input"],
Cell[6324, 225, 66, 1, 30, "Input"],
Cell[6393, 228, 46, 1, 30, "Input"],
Cell[6442, 231, 180, 3, 50, "Input"],
Cell[6625, 236, 198, 3, 50, "Input"],
Cell[6826, 241, 78, 1, 30, "Input"],
Cell[6907, 244, 97, 2, 30, "Input"],
Cell[7007, 248, 180, 5, 90, "Input"],
Cell[7190, 255, 44, 1, 30, "Input"],
Cell[7237, 258, 93, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7367, 264, 159, 3, 59, "Subsubsection"],
Cell[7529, 269, 164, 3, 50, "Input"],
Cell[7696, 274, 127, 3, 30, "Input"],
Cell[7826, 279, 68, 1, 30, "Input"],
Cell[7897, 282, 210, 4, 50, "Input"],
Cell[8110, 288, 111, 2, 30, "Input"],
Cell[8224, 292, 80, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8341, 298, 119, 2, 59, "Subsubsection"],
Cell[8463, 302, 100, 2, 30, "Input"],
Cell[8566, 306, 84, 1, 30, "Input"],
Cell[8653, 309, 109, 2, 30, "Input"],
Cell[8765, 313, 112, 2, 30, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8926, 321, 105, 1, 63, "Subsection"],
Cell[9034, 324, 54, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[9113, 329, 150, 3, 59, "Subsubsection"],
Cell[9266, 334, 98, 2, 30, "Input"],
Cell[9367, 338, 45, 1, 30, "Input"],
Cell[9415, 341, 55, 1, 30, "Input"],
Cell[9473, 344, 65, 1, 30, "Input"],
Cell[9541, 347, 66, 1, 30, "Input"],
Cell[9610, 350, 42, 1, 30, "Input"],
Cell[9655, 353, 134, 3, 30, "Input"],
Cell[9792, 358, 156, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9985, 366, 262, 4, 76, "Subsubsection"],
Cell[10250, 372, 81, 1, 30, "Input"],
Cell[10334, 375, 90, 1, 30, "Input"],
Cell[10427, 378, 86, 1, 30, "Input"],
Cell[10516, 381, 114, 3, 30, "Input"],
Cell[10633, 386, 99, 2, 30, "Input"],
Cell[10735, 390, 98, 2, 30, "Input"],
Cell[10836, 394, 130, 2, 30, "Input"],
Cell[10969, 398, 78, 1, 30, "Input"],
Cell[11050, 401, 88, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11175, 407, 140, 3, 59, "Subsubsection"],
Cell[11318, 412, 133, 3, 30, "Input"],
Cell[11454, 417, 113, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11604, 425, 232, 4, 76, "Subsubsection"],
Cell[11839, 431, 70, 1, 30, "Input"],
Cell[11912, 434, 82, 1, 30, "Input"],
Cell[11997, 437, 173, 3, 70, "Input"],
Cell[12173, 442, 70, 1, 30, "Input"],
Cell[12246, 445, 147, 3, 50, "Input"],
Cell[12396, 450, 152, 2, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

