(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6191,        226]*)
(*NotebookOutlinePosition[      6842,        249]*)
(*  CellTagsIndexPosition[      6798,        245]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`Graphics`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.2  Orbiting Bodies", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 3:  Precessing Ellipse and the Generalized Kepler Problem\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (a)   Define u[\[Phi]] = 1/r[\[Phi]] and assume \[Theta]=\[Pi]/2.  \
Solve for u[\[Phi]] when the  potential is given by V = -k/r - b/",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ".  Express the solution in the form ",
  Cell[BoxData[
      \(TraditionalForm\`u\_0\)]],
  "(1 + \[Epsilon] Cos[\[Phi](1 - \[Delta])]) where ",
  Cell[BoxData[
      \(TraditionalForm\`u\_0\)]],
  "= k m/(",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptL]\^2\)]],
  " - 2 b m)"
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eq1 = 
      \(\(u'\)'\)[\[Phi]] == 
        \(-u[\[Phi]]\) - m\ f[1/u[\[Phi]]]/\((\[ScriptL]\ u[\[Phi]])\)^2\)], 
  "Input"],

Cell[BoxData[
    \(forceRule = {V -> \((\(-\((k/#)\)\)\  - \ \((b/#^2)\)&)\)\n\t\t, 
        f[1/u[\[Phi]]] -> \(-\(V'\)[r]\)\n\t\t\t, r -> 1/u[\[Phi]]}\)], 
  "Input"],

Cell[BoxData[
    \(eq2 = eq1 //. forceRule // ExpandAll\)], "Input"],

Cell[BoxData[
    \(initial = {\(u'\)[0] == 0, u[0] == u0 \((1 + \[Epsilon])\)}\)], "Input"],

Cell[BoxData[
    \(uRule = 
      \((\(\((\((DSolve[Join[{eq2}, initial]\n\t, {u[\[Phi]]}, \[Phi]] // 
                    Flatten)\)\n\t\t /. {Sqrt[x_] -> I\ Sqrt[\(-x\)]})\)\n
            \t // ExpToTrig\) // Simplify)\)\)], "Input"],

Cell[BoxData[
    \(\(shiftRule = {Sqrt[1 - \((2\ b\ m)\)/\[ScriptL]^2] -> 1 - shift}; 
    \)\)], "Input"],

Cell[BoxData[
    \(rhs = \(u[\[Phi]] //. uRule\) //. shiftRule\)], "Input"],

Cell[BoxData[
    \(\(u1Rule = {
        u[\[Phi]] -> 
          u0 \((1\  + \ \[Epsilon]\ Cos[\((1\  - \ shift)\) \[Phi]])\)}; 
    \)\)], "Input"],

Cell[BoxData[
    \(lhs = u[\[Phi]] //. u1Rule\)], "Input"],

Cell[BoxData[
    \(u0Rule = Solve[lhs == rhs, u0] // Flatten\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)  Plot the resuts using the command ",
  StyleBox["PolarPlot",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Clear[plotOrbit]; \n
    plotOrbit[start_, finish_, values_List] := \n\t
      PolarPlot[
        \(u[\[Phi]] //. u1Rule\) //. values\n\t\t\t // Evaluate, {\[Phi], 
          start, finish}]\)], "Input"],

Cell[BoxData[
    \(\(p1 = 
      plotOrbit[0, 6  \[Pi], {u0 -> 1, \[Epsilon] -> 0.5, shift -> 0.1}]; 
    \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)   Use the user-defined function firstOrderPert tofins the \
first-order perturbative solution in the parameter b.  Show that the result \
agrees wiht the expansion of the solution derived in Part (a).\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(pert = 
      \((firstOrderPert[eq2, u, {u0 \((1 + \[Epsilon])\), 0}, b, \[Phi]]\n
            \t //. u0Rule // Simplify)\)\)], "Input"],

Cell[BoxData[
    \(pertSer = \(Series[pert, {b, 0, 1}] // Normal\) // ExpandAll\)], "Input"],

Cell[BoxData[
    \(exactSer = 
      \(Series[\(u[\[Phi]] //. uRule\) //. u0Rule, {b, 0, 1}]\n\t\t\t // 
          Normal\) // Expand\)], "Input"],

Cell[BoxData[
    \(pertSer == exactSer\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{448, 691},
WindowMargins->{{30, Automatic}, {Automatic, 45}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 90, 2, 30, "Input"],
Cell[2489, 85, 90, 2, 30, "Input"],
Cell[2582, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2679, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2769, 100, 74, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2868, 105, 128, 3, 82, "Subsection"],

Cell[CellGroupData[{
Cell[3021, 112, 553, 16, 93, "Subsubsection"],
Cell[3577, 130, 145, 4, 30, "Input"],
Cell[3725, 136, 169, 3, 70, "Input"],
Cell[3897, 141, 69, 1, 30, "Input"],
Cell[3969, 144, 92, 1, 30, "Input"],
Cell[4064, 147, 236, 4, 90, "Input"],
Cell[4303, 153, 107, 2, 30, "Input"],
Cell[4413, 157, 76, 1, 30, "Input"],
Cell[4492, 160, 148, 4, 30, "Input"],
Cell[4643, 166, 59, 1, 30, "Input"],
Cell[4705, 169, 74, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4816, 175, 186, 6, 59, "Subsubsection"],
Cell[5005, 183, 223, 5, 90, "Input"],
Cell[5231, 190, 122, 3, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5390, 198, 277, 5, 93, "Subsubsection"],
Cell[5670, 205, 156, 3, 70, "Input"],
Cell[5829, 210, 93, 1, 50, "Input"],
Cell[5925, 213, 147, 3, 70, "Input"],
Cell[6075, 218, 52, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

