(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7470,        252]*)
(*NotebookOutlinePosition[      8363,        282]*)
(*  CellTagsIndexPosition[      8319,        278]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*`\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.2  Orbit Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
 Problem 4:  Numerical Solution for Orbits with Central Forces\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*`\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell["Part (a)   ", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    RowBox[{
      RowBox[{"eq1", "=", 
        RowBox[{
          RowBox[{
            SuperscriptBox["u", "\[DoublePrime]",
              MultilineFunction->None], "[", "\[Phi]", "]"}], "==", 
          \(\(-u[\[Phi]]\) - 
            \(m\ f[1\/u[\[Phi]]]\)\/\(el\^2\ u[\[Phi]]\^2\)\)}]}], ";"}]], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"forceRule", "=", 
        RowBox[{"{", 
          RowBox[{\(V \[Rule] \((\(-\(k\/#1\)\)&)\)\), ",", 
            RowBox[{\(f[1\/u[\[Phi]]]\), "\[Rule]", 
              RowBox[{"-", 
                RowBox[{
                  SuperscriptBox["V", "\[Prime]",
                    MultilineFunction->None], "[", "r", "]"}]}]}], ",", 
            \(r \[Rule] 1\/u[\[Phi]]\)}], "}"}]}], ";"}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq2 = eq1 //. forceRule\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {k \[Rule] 1, el \[Rule] 1, m \[Rule] 1}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"initial1", "=", 
        RowBox[{"{", 
          RowBox[{\(u[0] == 1.6\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["u", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], 
          "}"}]}], ";"}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ndsol1 = 
      Flatten[NDSolve[Flatten[{eq2 /. values, initial1}], 
          u[\[Phi]], {\[Phi], 0, 2\ \[Pi]}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(u1[\[Phi]_] = u[\[Phi]] //. ndsol1; u1[1.1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PolarPlot[Evaluate[1\/u1[\[Phi]]], {\[Phi], 0, 2\ \[Pi]}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"initial2", "=", 
        RowBox[{"{", 
          RowBox[{\(u[0] == 3\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["u", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], 
          "}"}]}], ";"}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ndsol2 = 
      Flatten[NDSolve[Flatten[{eq2 /. values, initial2}], 
          u[\[Phi]], {\[Phi], 0, 2\ \[Pi]}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(u2[\[Phi]_] = u[\[Phi]] //. ndsol2; u2[1.1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(PolarPlot[Evaluate[1\/u2[\[Phi]]], {\[Phi], 0, 2\ \[Pi]}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[{\(Clear[numOrbit]; \), 
    RowBox[{
    \(numOrbit[V_, r_, r0_:  1, dr0_:  0, el_:  1, m_:  1, 
        angle_: \( 6\ \[Pi]\)]\), ":=", 
      RowBox[{"Module", "[", 
        RowBox[{\({u, \[Phi], uforce, eq1, initial, eqs, ndsol}\), ",", 
          RowBox[{
          \(uforce = \(-\[PartialD]\_r V\) /. r \[Rule] 1\/u[\[Phi]]\), ";", 
            RowBox[{"eq1", "=", 
              RowBox[{"ExpandAll", "[", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["u", "\[DoublePrime]",
                      MultilineFunction->None], "[", "\[Phi]", "]"}], "==", 
                  \(\(-u[\[Phi]]\) - 
                    \(m\ uforce\)\/\(el\^2\ u[\[Phi]]\^2\)\)}], "]"}]}], 
            ";", 
            RowBox[{"initial", "=", 
              RowBox[{"{", 
                RowBox[{\(u[0] == 1\/r0\), ",", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["u", "\[Prime]",
                        MultilineFunction->None], "[", "0", "]"}], "==", 
                    \(-\(dr0\/r0\^2\)\)}]}], "}"}]}], ";", 
            \(eqs = Join[{eq1}, initial]\), ";", 
            \(ndsol = Flatten[NDSolve[eqs, u[\[Phi]], {\[Phi], 0, angle}]]\), 
            ";", \(PolarPlot[
              Evaluate[1\/u[\[Phi]] /. ndsol], {\[Phi], 0, angle}]\)}]}], 
        "]"}]}]}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(numOrbit[\(-\(1\/r\)\), r, 0.6]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(numOrbit[\(-\(1\/r\^1.1\)\), r, 0.6]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(numOrbit[\(-\(1\/r\^0.9\)\), r, 0.6]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(numOrbit[\(-\(1\/r\)\) - 0.02\/r\^3, r, 0.6]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(numOrbit[\(-\(1\/r\)\) + 0.02\/r\^3, r, 0.6]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{444, 692},
WindowMargins->{{Automatic, 105}, {Automatic, 46}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 85, 3, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2151, 71, 58, 1, 69, "Subtitle"],
Cell[2212, 74, 109, 2, 70, "Input"],
Cell[2324, 78, 90, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2451, 85, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2541, 90, 73, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2639, 95, 125, 3, 82, "Subsection"],
Cell[2767, 100, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2853, 105, 71, 1, 59, "Subsubsection"],
Cell[2927, 108, 351, 10, 53, "Input"],
Cell[3281, 120, 465, 11, 65, "Input"],
Cell[3749, 133, 82, 2, 30, "Input"],
Cell[3834, 137, 114, 2, 30, "Input"],
Cell[3951, 141, 352, 10, 30, "Input"],
Cell[4306, 153, 178, 4, 70, "Input"],
Cell[4487, 159, 102, 2, 30, "Input"],
Cell[4592, 163, 125, 3, 44, "Input"],
Cell[4720, 168, 350, 10, 30, "Input"],
Cell[5073, 180, 178, 4, 70, "Input"],
Cell[5254, 186, 102, 2, 30, "Input"],
Cell[5359, 190, 125, 3, 44, "Input"],
Cell[5487, 195, 1388, 30, 273, "Input"],
Cell[6878, 227, 96, 2, 42, "Input"],
Cell[6977, 231, 101, 2, 42, "Input"],
Cell[7081, 235, 101, 2, 42, "Input"],
Cell[7185, 239, 109, 2, 42, "Input"],
Cell[7297, 243, 109, 2, 42, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

