(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10370,        364]*)
(*NotebookOutlinePosition[     11021,        387]*)
(*  CellTagsIndexPosition[     10977,        383]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.2  Orbiting Bodies", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 5:  Quadrupole Problem and Perturbative Solutions", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(TextForm
    \`Consider\ the\ orbit\ of\ a\ satellite\ in\ the\ equitorial\ plane\ of\ 
        an\ oblate\ solid\ of\ revolution . \n\t\tThe\ gravitational\ 
        potential\ is\ V\  = \ 
      \(-G\)\ M/r\ 
        \((1\  + \ J\_2/2  r\^2\ \((1 - 3  Cos[\[Theta]]\^2)\))\)\)], "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)   Assume a satellite is in the equitorial orbit plane \
\[Theta]=\[Pi]/2 and write the equations of motion.  Eliminate the variable \
\[Phi] and get a radial equation for the orbit."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(rRule = 
      r -> \((Evaluate[\n\t\t\t\t\t
              CoordinatesToCartesian[\n
                \t\t\t\t\t\t{r0[#], \[Theta][#], \[Phi][#]}, Spherical]]&)\); 
    \)\)], "Input"],

Cell[BoxData[
    \(V = 
      \(-\((G\ m/r0[t])\)\) 
        \((1 + \((J2/\((2\ r0[t]^2)\))\) \((1 - 3\ Cos[\[Theta][t]]^2)\))
          \)\)], "Input"],

Cell[BoxData[
    \(T = 1/2\ \ \(r'\)[t] . \(r'\)[t]\)], "Input"],

Cell[BoxData[
    \(L0 = T - V\)], "Input"],

Cell[BoxData[
    \(L = 
      \((L0 //. rRule // TrigExpand)\)\n //. {Cos[x_]^2 -> 1 - Sin[x]^2} // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(\[Theta]Rule = {\[Theta] -> \((\((\[Pi]/2)\)&)\)}; \)\)], "Input"],

Cell[BoxData[
    \(eqMotion = 
      Lag[{r0, \[Theta], \[Phi]}, L] //. \[Theta]Rule // Simplify\)], "Input"],

Cell[BoxData[
    \(\[Phi]Rule = {\[Phi] -> \((Integrate[d\[Phi][#], #]&)\)}\)], "Input"],

Cell[BoxData[
    \(\[Phi]Eq = eqMotion[\([3]\)] //. \[Phi]Rule\)], "Input"],

Cell[BoxData[
    \(d\[Phi]Sol = 
      DSolve[{\[Phi]Eq, d\[Phi][0] == \[Epsilon]1/\((m\ r0[0]^2)\)}, d\[Phi], 
          t]\n // Flatten\)], "Input"],

Cell[BoxData[
    \(\[Phi]Rule2 = {\(\[Phi]'\)[t] -> d\[Phi][t], 
          \(\(\[Phi]'\)'\)[t] -> \(d\[Phi]'\)[t]}\n //. d\[Phi]Sol\)], "Input"],

Cell[BoxData[
    \(eqMotion2 = eqMotion //. \[Phi]Rule2\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (b)  Let u=1/r and derive an equation for u.", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(uRule = {r0 -> \((1/u[\[Phi][#]]&)\)}\)], "Input"],

Cell[BoxData[
    \(eq1 = 
      \((eqMotion2[\([1]\)] //. Join[\[Phi]Rule2, uRule]\n\t\t // ExpandAll)
        \)\)], "Input"],

Cell[BoxData[
    \(eq2 = 
      \((\((Solve[eq1, \(\(u'\)'\)[\[Phi][t]]] // Flatten)\)\n
              \t\t //. {Rule -> Equal} // ExpandAll)\)\n //. {
          \[Phi][t] -> \[Phi]}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (c)   Consider the elliptical solution that follows from the equation \
with ",
  Cell[BoxData[
      \(TraditionalForm\`J\_2\)]],
  "=0.  Find the first order perturbation correction due to the quadrupole \
term ",
  Cell[BoxData[
      \(TraditionalForm\`J\_2\)]],
  " by expanding the equations of motion about ",
  Cell[BoxData[
      \(TraditionalForm\`J\_2\)]],
  " and solving.  Keep only the lowest-order terms in \[Epsilon].  Show that \
the results can be expressed as a precessing ellipse."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(initial = {\(u'\)[0] == 0, u[0] == u0 \((1 + \[Epsilon])\)}\)], "Input"],

Cell[BoxData[
    \(dsol = 
      \((DSolve[{\((eq2 /. {J2 -> 0})\), initial} // Flatten\n
              \t\t\t, {u[\[Phi]]}, \[Phi]] // Flatten)\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(uSol = 
      Solve[\((\(u[\[Phi]] /. dsol\) /. {Cos[\[Phi]] -> 0})\) == u0, u0]\n // 
        Flatten\)], "Input"],

Cell[BoxData[
    \(pertRule = {
        u -> \((\((u0 \((1 + \[Epsilon]\ Cos[#])\) + J2\ u1[#])\)&)\)}\)], 
  "Input"],

Cell[BoxData[
    \(eq3 = eq2 /. pertRule\)], "Input"],

Cell[BoxData[
    \(eq4 = 
      \((\((\(Solve[eq3, \(\(u1'\)'\)[\[Phi]]]\)[\([1]\)]\n\t\t //. uSol // 
                    ExpandAll)\)\n\t //. {J2 -> 0, \[Epsilon]^2 -> 0} // 
              Simplify)\)\n //. {Rule -> Equal} // ExpandAll\)], "Input"],

Cell[BoxData[
    \(init1 = {\(u1'\)[0] == 0, u1[0] == 0}\)], "Input"],

Cell[BoxData[
    \(dsol4 = 
      \(DSolve[Join[eq4, init1]\n\t\t\t, u1[\[Phi]], \[Phi]] // Flatten\) // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    \(seq5 = \(u[\[Phi]] /. pertRule\) /. dsol4\)], "Input"],

Cell[BoxData[
    \(eq5 = u01 \((1 + \[Epsilon]1\ Cos[\((1 - J2\ \[Alpha])\) \[Phi]])\)\)], 
  "Input"],

Cell[BoxData[
    \(seq6 = Series[eq5, {J2, 0, 1}] // Normal\)], "Input"],

Cell[BoxData[
    \(u01Rule = 
      \(Solve[seq5 == seq6 //. {Cos[__] -> 0, Sin[__] -> 0}, u01] // Flatten
          \) // ExpandAll\)], "Input"],

Cell[BoxData[
    \(eq\[Epsilon]1 = \ 
      \(seq5\ \[Epsilon]1^6 == seq6\ \[Epsilon]1^6 //. {Sin[__] -> 0}\) //. 
          u01Rule // Simplify\)], "Input"],

Cell[TextData[
"Note:  The polynomial eq\[Epsilon]1 has 7 roots.  Take the 1st one."], "Text",\

  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    RowBox[{"\[Epsilon]1Rule", "=", 
      RowBox[{\(Solve[eq\[Epsilon]1, \[Epsilon]1]\), 
        StyleBox["[",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[\([1]\),
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox["]",
          FontColor->RGBColor[1, 0, 0]]}]}]], "Input"],

Cell[BoxData[
    \(eq\[Alpha] = 
      seq5\ \[Epsilon]1^6 == seq6\ \[Epsilon]1^6 //. {Cos[__] -> 0} // 
        \(Simplify //. u01Rule\) //. \[Epsilon]1Rule\)], "Input"],

Cell[BoxData[
    \(\[Alpha]Rule = 
      \((Solve[eq\[Alpha], \[Alpha]] // Flatten)\) //. uSol // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(\((\({u01, \[Epsilon]1, J2\ \[Alpha]}\n //. 
          Join[u01Rule, \[Epsilon]1Rule, \[Alpha]Rule]\)\n\t //. {J2 -> 0})
      \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)  Use the user-defined function firstOrderPert to find the \
perturbative solution and show that it agrees with the solution found in Part \
(c).\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
Note:  This operation takes about 15 minutes on a 200 MHz Pentium.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(test1a = 
      firstOrderPert[eq2[\([1]\)], u, {u0 \((1 + \[Epsilon])\), 0}, J2, 
            \[Phi]]\n\t\ \ \  //. uSol // Timing\)], "Input"],

Cell[BoxData[
    \(test1b = test1a[\([2]\)] // Simplify\)], "Input"],

Cell[TextData["Note:  Get rid of the high order terms in \[Epsilon]."], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    RowBox[{"test1c", "=", 
      RowBox[{"test1b", 
        StyleBox["//.",
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[\({\[Epsilon]^2 -> 0}\),
          FontColor->RGBColor[1, 0, 0]]}]}]], "Input"],

Cell[BoxData[
    \(test1 = test1c // ExpandAll\)], "Input"],

Cell[BoxData[
    \(test1 = test1d // ExpandAll\)], "Input"],

Cell["\<\
Note:  The parentheses are important.  Otherwise the uSol substitution \
doesn't work.\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    RowBox[{"test2", "=", 
      RowBox[{
        RowBox[{
          RowBox[{
            StyleBox["(",
              FontColor->RGBColor[1, 0, 0]], 
            \(Series[seq5, {J2, 0, 1}] // Normal\), 
            StyleBox[")",
              FontColor->RGBColor[1, 0, 0]]}], 
          StyleBox["//.",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["uSol",
            FontColor->RGBColor[1, 0, 0]]}], "//", "ExpandAll"}]}]], "Input"],

Cell[BoxData[
    \(test1 == test2\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{711, 549},
WindowMargins->{{30, Automatic}, {Automatic, 45}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 90, 2, 30, "Input"],
Cell[2489, 85, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2586, 91, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2676, 96, 74, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2775, 101, 112, 1, 63, "Subsection"],
Cell[2890, 104, 308, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[3223, 114, 261, 4, 76, "Subsubsection"],
Cell[3487, 120, 205, 5, 70, "Input"],
Cell[3695, 127, 153, 4, 30, "Input"],
Cell[3851, 133, 65, 1, 30, "Input"],
Cell[3919, 136, 43, 1, 30, "Input"],
Cell[3965, 139, 131, 3, 50, "Input"],
Cell[4099, 144, 88, 1, 30, "Input"],
Cell[4190, 147, 110, 2, 30, "Input"],
Cell[4303, 151, 89, 1, 30, "Input"],
Cell[4395, 154, 76, 1, 30, "Input"],
Cell[4474, 157, 151, 3, 50, "Input"],
Cell[4628, 162, 145, 2, 50, "Input"],
Cell[4776, 166, 69, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4882, 172, 109, 1, 59, "Subsubsection"],
Cell[4994, 175, 70, 1, 30, "Input"],
Cell[5067, 178, 127, 3, 50, "Input"],
Cell[5197, 183, 196, 4, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5430, 192, 581, 15, 93, "Subsubsection"],
Cell[6014, 209, 92, 1, 30, "Input"],
Cell[6109, 212, 175, 4, 50, "Input"],
Cell[6287, 218, 135, 3, 50, "Input"],
Cell[6425, 223, 119, 3, 30, "Input"],
Cell[6547, 228, 54, 1, 30, "Input"],
Cell[6604, 231, 251, 4, 90, "Input"],
Cell[6858, 237, 70, 1, 30, "Input"],
Cell[6931, 240, 137, 3, 50, "Input"],
Cell[7071, 245, 74, 1, 30, "Input"],
Cell[7148, 248, 103, 2, 30, "Input"],
Cell[7254, 252, 73, 1, 30, "Input"],
Cell[7330, 255, 146, 3, 30, "Input"],
Cell[7479, 260, 158, 3, 30, "Input"],
Cell[7640, 265, 128, 3, 33, "Text"],
Cell[7771, 270, 313, 8, 30, "Input"],
Cell[8087, 280, 171, 3, 30, "Input"],
Cell[8261, 285, 123, 3, 30, "Input"],
Cell[8387, 290, 162, 3, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8586, 298, 221, 5, 76, "Subsubsection"],
Cell[8810, 305, 122, 3, 33, "Text"],
Cell[8935, 310, 164, 3, 50, "Input"],
Cell[9102, 315, 69, 1, 30, "Input"],
Cell[9174, 318, 111, 1, 33, "Text"],
Cell[9288, 321, 229, 6, 30, "Input"],
Cell[9520, 329, 60, 1, 30, "Input"],
Cell[9583, 332, 60, 1, 30, "Input"],
Cell[9646, 335, 142, 4, 33, "Text"],
Cell[9791, 341, 465, 13, 30, "Input"],
Cell[10259, 356, 47, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

