(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6151,        232]*)
(*NotebookOutlinePosition[      6802,        255]*)
(*  CellTagsIndexPosition[      6758,        251]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.3  Hamilton and Hamilton-Jacobi Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 1:  Harmonic Oscillator and Hamilton's Equation", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(TextForm
    \`Consider\ \ a\ particle\ of\ mass\ m\ moving\ in\ a\ harmonic\ 
        oscillator\ potential\ V\  = \ \((1/2)\) \(kx\^2 . \)\)], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Find the Hamiltonian for the system and solve Hamilton's \
Equation\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(T = \((m/2)\) \(x'\)[t]^2\)], "Input"],

Cell[BoxData[
    \(V = \((k/2)\)\ x[t]^2\)], "Input"],

Cell[BoxData[
    \(L = T - V\)], "Input"],

Cell[BoxData[
    \(eq1 = p[t] == D[L, \(x'\)[t]]\)], "Input"],

Cell[BoxData[
    \(xpRule = Solve[eq1, \(x'\)[t]] // Flatten\)], "Input"],

Cell[BoxData[
    \(H = \((p[t] \(x'\)[t] - L)\) //. xpRule\)], "Input"],

Cell[BoxData[
    \(eq2 = {\(p'\)[t] == \(-D[H, x[t]]\)\n\t\t\t\ \ \ \ , 
        \(x'\)[t] == \(+D[H, p[t]]\)}\)], "Input"],

Cell[BoxData[
    \(\(initial = {p[0] == 0, x[0] == x0}; \)\)], "Input"],

Cell[BoxData[
    \(dsol = DSolve[eq2~Join~initial, {p[t], x[t]}, t] // Flatten\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)   Use the user-defined ",
  StyleBox["Hamilton",
    FontColor->RGBColor[0, 0, 1]],
  " procedure to obtain the Hamiltonain and the equations of motion."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(dsolH = Hamilton[L, {x}, {p}]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (c)   Consider the non-linear oscillator described by ",
  Cell[BoxData[
      \(TextForm\`V\  = \ \((1/2)\) kx\^2\)]],
  " + \[Epsilon]",
  Cell[BoxData[
      \(TraditionalForm\`x\^5\)]],
  " . Write hamilton's equations.  Assume the solution can be written as a \
power series in t and use the used-defined ",
  StyleBox["firstDiffSeries",
    FontColor->RGBColor[0, 0, 1]],
  " procedure to find the power series solution.  Find the first-order \
perturbation solution in the parameter \[Epsilon] using the user-defined \
procedure ",
  StyleBox["firstOrderPert",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(V1 = \[Epsilon]\ x[t]^5\)], "Input"],

Cell[BoxData[
    \(L1 = T - \((V + V1)\)\)], "Input"],

Cell[BoxData[
    \({xprule, hamiltonian, eqMotion} = Hamilton[L1, {x}, {p}]\)], "Input"],

Cell[BoxData[
    \(sol1 = 
      firstDiffSeries[eqMotion, {x, p}, {x[0] -> x0, p[0] -> 0}, 3]\)], 
  "Input"],

Cell[BoxData[
    \(sol2 = {x[t], p[t]} -> sol1 // Thread\)], "Input"],

Cell[BoxData[
    \(sol3 = sol2 // Map[\((D[#, t]&)\), #, {2}]&\)], "Input"],

Cell[BoxData[
    \(eqM2 = \(eqMotion //. Join[sol2, sol3] // Normal\) // ExpandAll\)], 
  "Input"],

Cell[BoxData[
    \(\((eqM2 //. {t^3 -> 0})\)\)], "Input"],

Cell[BoxData[
    \(eq3 = \((eqMotion // First)\) /. {\(p'\)[t] -> m\ \(\(x'\)'\)[t]}\)], 
  "Input"],

Cell[BoxData[
    \(pert3 = 
      \((\((firstOrderPert[eq3, x, {x0, 0}, \[Epsilon]])\))\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(sPert3 = \(Series[pert3, {t, 0, 3}] // Normal\) // ExpandAll\)], "Input"],

Cell[BoxData[
    \(test1 = \(x[t] //. sol2 // Normal\) // ExpandAll\)], "Input"],

Cell[BoxData[
    \(test1 == sPert3\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{679, 517},
WindowMargins->{{30, Automatic}, {Automatic, 45}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 90, 2, 30, "Input"],
Cell[2489, 85, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2586, 91, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2676, 96, 96, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2797, 101, 110, 1, 63, "Subsection"],
Cell[2910, 104, 172, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[3107, 111, 146, 4, 59, "Subsubsection"],
Cell[3256, 117, 58, 1, 30, "Input"],
Cell[3317, 120, 54, 1, 30, "Input"],
Cell[3374, 123, 42, 1, 30, "Input"],
Cell[3419, 126, 62, 1, 30, "Input"],
Cell[3484, 129, 74, 1, 30, "Input"],
Cell[3561, 132, 72, 1, 30, "Input"],
Cell[3636, 135, 124, 2, 50, "Input"],
Cell[3763, 139, 72, 1, 30, "Input"],
Cell[3838, 142, 92, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3967, 148, 237, 6, 59, "Subsubsection"],
Cell[4207, 156, 62, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4306, 162, 688, 18, 110, "Subsubsection"],
Cell[4997, 182, 56, 1, 30, "Input"],
Cell[5056, 185, 54, 1, 30, "Input"],
Cell[5113, 188, 89, 1, 30, "Input"],
Cell[5205, 191, 111, 3, 30, "Input"],
Cell[5319, 196, 70, 1, 30, "Input"],
Cell[5392, 199, 76, 1, 30, "Input"],
Cell[5471, 202, 99, 2, 30, "Input"],
Cell[5573, 206, 58, 1, 30, "Input"],
Cell[5634, 209, 101, 2, 30, "Input"],
Cell[5738, 213, 118, 3, 30, "Input"],
Cell[5859, 218, 93, 1, 30, "Input"],
Cell[5955, 221, 81, 1, 30, "Input"],
Cell[6039, 224, 48, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

