(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8526,        275]*)
(*NotebookOutlinePosition[      9418,        305]*)
(*  CellTagsIndexPosition[      9374,        301]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.3  Hamiltonian Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 3:  Spherical Pendulum  and Hamilton's Equations ", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)   Find Hamilton's equations for the variables {\[Theta],\[Phi]}.  \
Eliminate the \[Phi] variableand reduce Hamilton's equations to a non-linear \
equation for \[Theta].  Restrict the pendulum motion to a plane and show that \
the solution resuces to a standard pendulum equation."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    RowBox[{"T", "=", 
      RowBox[{\(1\/2\), " ", "m", " ", \(Len\^2\), " ", 
        RowBox[{"(", 
          RowBox[{
            SuperscriptBox[
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "2"], "+", 
            RowBox[{\(Sin[\[Theta][t]]\^2\), " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}], 
          ")"}]}]}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(V = m\ g\ Len\ \((1 - Cos[\[Theta][t]])\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(L = T - V\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({prule, ham, eqMotion} = 
      Hamilton[L, {\[Theta], \[Phi]}, {p\[Theta], p\[Phi]}, t]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eqMotion\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eqMotion = eqMotion //. {p\[Phi] \[Rule] \((p\[Phi]0&)\)}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eqMotion\[LeftDoubleBracket]{1, 3}\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(p\[Theta]Rule = 
      ToRules[eqMotion\[LeftDoubleBracket]1\[RightDoubleBracket]]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = 
      Simplify[ExpandAll[
          \((\((\[PartialD]\_t #1&)\)/@#1&)\)[
              eqMotion\[LeftDoubleBracket]3\[RightDoubleBracket]] //. 
            p\[Theta]Rule]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Normal[
      \((\((Series[#1, {\[Theta][t], 0, 1}]&)\)/@#1&)\)[eq1] //. {
          p\[Phi]0 \[Rule] 0}]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Assume the pendulum equation can be expanded in a power series \
and solve for the first few terms.  Assume g=1, m=1, and Len=1, and intial \
conditions {\[Theta][0]=\[Pi]/4,`q`'[0]=0}.  Find numerical solutions for \
\[Theta] when p\[Phi][0]=0 (planar pendulum) and for p\[Phi][0]=0.2."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    RowBox[{
      RowBox[{"pert", "=", 
        RowBox[{"Simplify", "[", 
          RowBox[{"diffSeriesOne", "[", 
            RowBox[{"eq1", ",", "\[Theta]", ",", "t", ",", "6", ",", 
              RowBox[{"{", 
                RowBox[{\(\[Theta][0] \[Rule] \[Theta]0\), ",", 
                  RowBox[{
                    RowBox[{
                      SuperscriptBox["\[Theta]", "\[Prime]",
                        MultilineFunction->None], "[", "0", "]"}], "\[Rule]", 
                    "0"}]}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(pert + O[t]\^3\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(values = {g \[Rule] 1, m \[Rule] 1, Len \[Rule] 1}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{
      RowBox[{"initial", "=", 
        RowBox[{"{", 
          RowBox[{\(\[Theta][0] == \[Pi]\/4\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], 
          "}"}]}], ";"}]], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ndsol1 = 
      \(NDSolve[
          \(Join[{eq1}, initial] //. values\) //. {p\[Phi]0 \[Rule] 0}, {
            \[Theta]}, {t, 0, 8}]\)\[LeftDoubleBracket]1
        \[RightDoubleBracket]; \n\[Theta]1[t_] = \[Theta][t] //. ndsol1; \n
    \[Theta]1[3.4]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ndsol2 = 
      \(NDSolve[
          \(Join[{eq1}, initial] //. values\) //. {p\[Phi]0 \[Rule] 0.2}, {
            \[Theta]}, {t, 0, 8}]\)\[LeftDoubleBracket]1
        \[RightDoubleBracket]; \n\[Theta]2[t_] = \[Theta][t] //. ndsol2; \n
    \[Theta]2[3.4]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)   On the same graph, plot the following solutions:\n\t1. The power \
series solution for the parameters in Part (b) with p\[Phi][0]=0.2\n\t2.  The \
numerical solution found in Part (b) with p\[Phi][0]=0\n\t3.  The numerical \
solution found in Part (b) with p\[Phi][0]=0.2\n\t4.  The linear pendulum \
solution iven by the function \[Theta]0 Cos[t]"], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\[Theta]3[t_] = 
      Normal[N[\(pert //. values\) //. {\[Theta]0 \[Rule] \[Pi]\/4, 
              p\[Phi]0 \[Rule] 0.2}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\[Theta]4[t_] = \[Theta]0\ Cos[t] //. {\[Theta]0 \[Rule] \[Pi]\/4}\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Plot[
      Evaluate[{\[Theta]1[t], \[Theta]2[t], \[Theta]3[t], \[Theta]4[t]}], {t, 
        0, 8}, PlotStyle 
        \[Rule] {{Dashing[{1.00, 0.00}], Thickness[0.010]}, {
            Dashing[{0.08, 0.010}], Thickness[0.008]}, {
            Dashing[{0.06, 0.02}], Thickness[0.006]}, {Dashing[{1, 0}], 
            Thickness[0.002]}}, Frame \[Rule] True, 
      GridLines \[Rule] Automatic, PlotRange \[Rule] {\(-1\), 1}]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{576, 738},
WindowMargins->{{188, Automatic}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 85, 3, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2151, 71, 58, 1, 69, "Subtitle"],
Cell[2212, 74, 108, 2, 70, "Input"],
Cell[2323, 78, 90, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2450, 85, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2540, 90, 79, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2644, 95, 112, 1, 63, "Subsection"],
Cell[2759, 98, 60, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2844, 103, 360, 5, 93, "Subsubsection"],
Cell[3207, 110, 605, 15, 42, "Input"],
Cell[3815, 127, 100, 2, 30, "Input"],
Cell[3918, 131, 68, 2, 30, "Input"],
Cell[3989, 135, 147, 3, 30, "Input"],
Cell[4139, 140, 67, 2, 30, "Input"],
Cell[4209, 144, 116, 2, 30, "Input"],
Cell[4328, 148, 114, 2, 30, "Input"],
Cell[4445, 152, 143, 4, 30, "Input"],
Cell[4591, 158, 237, 6, 30, "Input"],
Cell[4831, 166, 164, 4, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5032, 175, 371, 6, 93, "Subsubsection"],
Cell[5406, 183, 585, 13, 30, "Input"],
Cell[5994, 198, 73, 2, 30, "Input"],
Cell[6070, 202, 115, 2, 30, "Input"],
Cell[6188, 206, 370, 10, 40, "Input"],
Cell[6561, 218, 311, 7, 90, "Input"],
Cell[6875, 227, 313, 7, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7225, 239, 429, 6, 127, "Subsubsection"],
Cell[7657, 247, 182, 4, 40, "Input"],
Cell[7842, 253, 128, 3, 40, "Input"],
Cell[7973, 258, 489, 10, 130, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

