(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7437,        258]*)
(*NotebookOutlinePosition[      8089,        281]*)
(*  CellTagsIndexPosition[      8045,        277]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch1init.m\>"\)], "Input"],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch4init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["4.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["4.2.3  Hamilton and Hamilton-Jacobi Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 5:  Kepler's Problem and Hamilton-Jacobi Equations", 
  "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(TextForm
    \`Consider\ \ a\ \ bound\ particle\ moving\ in\ a\ Keplerian\ 
        potential . \ \ Use\ {r, \[Theta], z}\ with\ z = 0. \)], "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)   Derive an expression for Hamilton's characteristic functions, \
Wr[r] and W\[Theta][\[Theta]]."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(rRule = {
        rVec -> \((
            Evaluate[
                CoordinatesToCartesian[{r[#], \[Theta][#], z[#]}, 
                  Cylindrical]]&)\)}\)], "Input"],

Cell[BoxData[
    \(T = 
      \((\(\((m/2\ \(rVec'\)[t] . \(rVec'\)[t])\) //. rRule\) //. {
              \(z'\)[t] -> 0})\) // Simplify\)], "Input"],

Cell[BoxData[
    \(V = \(-k\)/r[t]\)], "Input"],

Cell[BoxData[
    \(L = T - V\)], "Input"],

Cell[BoxData[
    \({momRule, hamPF, eqMotion} = 
      HamiltonJacobi[
        L, {r, \[Theta]}, {pr, p\[Theta]}, {Wr[r], W\[Theta][\[Theta]]}, En]
        \)], "Input"],

Cell[BoxData[
    \(w\[Theta]Rule = 
      DSolve[{\(W\[Theta]'\)[\[Theta]1] == \(+\[ScriptL]\), 
            W\[Theta][0] == 0}, {W\[Theta]}, \[Theta]1] // Flatten\)], "Input"],

Cell[BoxData[
    \(eq1 = 
      \(\(Solve[eqMotion //. w\[Theta]Rule, \(Wr'\)[r[t]]]\)[\([2]\)] // 
          ExpandAll\) // PowerExpand\)], "Input"],

Cell[BoxData[
    \(wrRule = 
      Wr[r[t]] -> 
        \((\((Integrate[\((\(Wr'\)[r[t]] //. eq1)\), r[t]])\) // Hold)\)\)], 
  "Input"],

Cell[BoxData[
    \(Unprotect[Hold]; \n
    D[Hold[Integrate[a_, x_]], b_] ^:= Integrate[D[a, b], x]; \n
    Protect[Hold]; \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Solve for the elliptical orbits using Hamilton's Principle \
functions S[t,r,\[Theta]].  Show that the expression for r can be written as \
r = a (1 - \[Epsilon]^2) / (1 + \[Epsilon] Cos[\[Phi]])."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(S = \(hamPF //. wrRule\) //. w\[Theta]Rule\)], "Input"],

Cell[TextData[{
  "Note: Up to this point all results have been OK.  However, the result \
below differs from that given on P. 223 of the book, because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.2x gives an ArcTan function of real arguments while ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v.3.0.1 gives I times a Log of complex arguments. This leads to many \
problems in what follows.  Attempts to fix the problem by declaration of the \
variables as real and positive does not work."
}], "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(\[ScriptL] /: Sign[\[ScriptL]] = 1; k /: Sign[k] = 1; m /: Sign[m] = 1; 
    En /: Sign[En] = 1; r /: Sign[r] = 1; \)], "Input"],

Cell[BoxData[
    \(\[ScriptL] /: Im[\[ScriptL]] = 0; k /: Im[k] = 0; m /: Im[m] = 0; 
    En /: Im[En] = 0; r /: Im[r] = 0; \)], "Input"],

Cell[BoxData[
    \(eq4a = Q == D[S, \[ScriptL]]\)], "Input"],

Cell["\<\
We fix this problem  by using  I Log[ ReArg + I ImArg] = \
ArcTan[-ImArg/ReArg], where ReArg and ImArg are the real and imaginary parts \
of the argument of the logarithm.
First extract the argument:\
\>", "Text",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \(eq4a // ExpToTrig\)], "Input"],

Cell[BoxData[
    \(\(arg\  = \ eq4a[\([2, 1, 2, 1]\)]\n\)\)], "Input"],

Cell[BoxData[
    \(den\  = \ \((arg\  + \ conjugate[arg])\)/2\)], "Input"],

Cell[BoxData[
    \(num\  = \ \((arg\  - \ conjugate[arg])\)/\((2\ I)\)\)], "Input"],

Cell[TextData["eq4 = Q == \[Theta][t] + ArcTan[-num/den]"], "Input"],

Cell[BoxData[
    \(sol4 = 
      \(Solve[\((eq4 /. {r[t] -> 1/u} // Simplify)\), u]\)[\([1]\)]\)], 
  "Input"],

Cell[BoxData[
    \(sol5 = 
      \((\((\(\((\(sol4 //. {Tan[Q - \[Theta][t]] -> tan}\)\n
                      \t\t\t\t\t\t //. {tan -> sin/Sqrt[1 - sin^2]})\) // 
                  Simplify\) // PowerExpand)\)\n\t\ \ \ \ \ \ \ \ \ \ \  // 
            Simplify)\)\n
        \ \ \ \ \ \ \ \ \ \ \ \ \  /. {sin -> Sin[Q - \[Theta][t]]}\)], 
  "Input"],

Cell[BoxData[
    \(eq2 = 
      \((\(u /. sol5\) /. {Q -> \[Pi]/2})\) == 
        \((1 + \[Epsilon]\ Cos[\[Theta][t]])\)/
          \((a \((1 - \[Epsilon]^2)\))\)\)], "Input"],

Cell[BoxData[
    \(eq3a = eq2 /. {Cos[__] -> 0}\)], "Input"],

Cell[BoxData[
    \(eq3b = eq2 /. {Cos[__] -> 1}\)], "Input"],

Cell[BoxData[
    \(Solve[{eq3a, eq3b}, {a, \[Epsilon]}] // Flatten\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{927, 446},
WindowMargins->{{110, Automatic}, {Automatic, 49}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 64, 1, 30, "Input"],
Cell[2463, 84, 90, 2, 30, "Input"],
Cell[2556, 88, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2653, 94, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2743, 99, 96, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2864, 104, 116, 2, 63, "Subsection"],
Cell[2983, 108, 168, 3, 31, "Text"],

Cell[CellGroupData[{
Cell[3176, 115, 176, 3, 59, "Subsubsection"],
Cell[3355, 120, 188, 5, 30, "Input"],
Cell[3546, 127, 150, 3, 30, "Input"],
Cell[3699, 132, 48, 1, 30, "Input"],
Cell[3750, 135, 42, 1, 30, "Input"],
Cell[3795, 138, 170, 4, 30, "Input"],
Cell[3968, 144, 177, 3, 30, "Input"],
Cell[4148, 149, 150, 3, 30, "Input"],
Cell[4301, 154, 137, 4, 30, "Input"],
Cell[4441, 160, 137, 3, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4615, 168, 278, 4, 59, "Subsubsection"],
Cell[4896, 174, 75, 1, 30, "Input"],
Cell[4974, 177, 564, 12, 71, "Text"],
Cell[5541, 191, 148, 2, 30, "Input"],
Cell[5692, 195, 138, 2, 30, "Input"],
Cell[5833, 199, 61, 1, 30, "Input"],
Cell[5897, 202, 255, 6, 52, "Text"],
Cell[6155, 210, 50, 1, 30, "Input"],
Cell[6208, 213, 71, 1, 50, "Input"],
Cell[6282, 216, 75, 1, 30, "Input"],
Cell[6360, 219, 84, 1, 30, "Input"],
Cell[6447, 222, 68, 0, 30, "Input"],
Cell[6518, 224, 111, 3, 30, "Input"],
Cell[6632, 229, 351, 7, 90, "Input"],
Cell[6986, 238, 176, 4, 30, "Input"],
Cell[7165, 244, 61, 1, 30, "Input"],
Cell[7229, 247, 61, 1, 30, "Input"],
Cell[7293, 250, 80, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

