(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5413,        215]*)
(*NotebookOutlinePosition[      6064,        238]*)
(*  CellTagsIndexPosition[      6020,        234]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.1  Point Charges, Multipoles, and Image Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 1:  Superposition of Point Charges", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Consider the following charge distributions: (1) a linear quadrupole, (2) a \
square quadrupole, and (3) three charges {-q,-q,+2q) located at the vertices \
of a triangle.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Compute the potential fields for these charge distributions.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
quad=(Monopole[2q,{0,0,   0}]
    + Monopole[-q,{0,0, d/2}]
    + Monopole[-q,{0,0,-d/2}])\
\>", "Input"],

Cell["\<\
square=(Monopole[+q,{+d/2,0,+d/2}]
      + Monopole[-q,{+d/2,0,-d/2}]
      + Monopole[+q,{-d/2,0,-d/2}]
      + Monopole[-q,{-d/2,0,+d/2}])\
\>", "Input"],

Cell["\<\
triangle=(Monopole[2q,{   0,0,   0}]
        + Monopole[-q,{+d/2,0,-d/2}]
        + Monopole[-q,{-d/2,0,-d/2}])\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Graph the equipotentials and field lines in two dimensions.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["val1={q->1,d->1,y->0};", "Input"],

Cell["\<\
VEPlot[quad//.val1,{x,-1,1.1},{z,-1,1}
,ColorFunction->Hue];\
\>", "Input"],

Cell["VEPlot[triangle//.val1,{x,-1,1.1},{z,-1,1}];", "Input"],

Cell["VEPlot[square//.val1,{x,-1,1.1},{z,-1,1}];", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)   find the potential to lowest order in the expansion of 1/r..\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["seriesQ=quad//PotentialExpansion", "Input"],

Cell["seriesQ//TrigToP//Simplify", "Input"],

Cell["??TrigToP", "Input"],

Cell["seriesS=square//PotentialExpansion", "Input"],

Cell["??TrigToY", "Input"],

Cell["seriesS//TrigToY", "Input"],

Cell["seriesT=triangle//PotentialExpansion", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)   Make a three-dimensional plot of the electric field for the linear \
quadrupole distribution.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["val2={q->1,d->1};", "Input"],

Cell["\<\
p1 = PlotGradientField3D[
quad//.val2//Evaluate
,{x,-1,1.1},{y,-1,1.1},{z,-1,1.1}
,Graphics`Common`GraphicsCommon`ScaleFunction->(1&)
,VectorHeads->True
,PlotPoints->6
,ColorFunction->Hue];\
\>", "Input"],

Cell["Show[p1,ViewPoint->{0,-4,0}];", "Input"],

Cell["Show[p1,ViewPoint->{0,0,-4}];", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{400, 644},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 91, 2, 30, "Input"],
Cell[2490, 85, 93, 2, 30, "Input"],
Cell[2586, 89, 90, 2, 30, "Input"],
Cell[2679, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2776, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2866, 104, 104, 1, 90, "Section"],

Cell[CellGroupData[{
Cell[2995, 109, 97, 1, 63, "Subsection"],
Cell[3095, 112, 195, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[3315, 120, 139, 3, 76, "Subsubsection"],
Cell[3457, 125, 115, 4, 66, "Input"],
Cell[3575, 131, 165, 5, 84, "Input"],
Cell[3743, 138, 136, 4, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3916, 147, 138, 3, 76, "Subsubsection"],
Cell[4057, 152, 39, 0, 30, "Input"],
Cell[4099, 154, 85, 3, 48, "Input"],
Cell[4187, 159, 61, 0, 48, "Input"],
Cell[4251, 161, 59, 0, 48, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4347, 166, 139, 3, 76, "Subsubsection"],
Cell[4489, 171, 49, 0, 30, "Input"],
Cell[4541, 173, 43, 0, 30, "Input"],
Cell[4587, 175, 26, 0, 30, "Input"],
Cell[4616, 177, 51, 0, 30, "Input"],
Cell[4670, 179, 26, 0, 30, "Input"],
Cell[4699, 181, 33, 0, 30, "Input"],
Cell[4735, 183, 53, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4825, 188, 172, 4, 76, "Subsubsection"],
Cell[5000, 194, 34, 0, 30, "Input"],
Cell[5037, 196, 214, 8, 156, "Input"],
Cell[5254, 206, 46, 0, 30, "Input"],
Cell[5303, 208, 46, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

