(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4848,        191]*)
(*NotebookOutlinePosition[      5499,        214]*)
(*  CellTagsIndexPosition[      5455,        210]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.1  Point Charges, Multipoles, and Image Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 2:  Point Charges and a Grounded Plane", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "Consider a point charge ",
  StyleBox["q",
    FontWeight->"Bold"],
  " a distance ",
  StyleBox["d",
    FontWeight->"Bold"],
  " from an infinite conducting plane that is grounded."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Find the potential.  Expand it in powers of 1/r and find the \
leading-order term.  Find the electric field to the same order.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
dipole= (Monopole[+q,{0,0, d}]
        + Monopole[-q,{0,0,-d}])\
\>", "Input"],

Cell["dipole/.z->0", "Input"],

Cell["dipoleR = dipole//PotentialExpansion", "Input"],

Cell["dipoleR//TrigToP", "Input"],

Cell[TextData["efieldR=Grad[dipoleR,Spherical[r,\[Theta],\[Phi]]]"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Find the induced charge density on the plane and verify that the \
total induced charge is -q.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["charge=-1/(4\[Pi]) D[dipole,z]//.z->0"], "Input"],

Cell["int1= Integrate[charge,{y,-Infinity,Infinity}]//PowerExpand", "Input"],

Cell["int1[[2]]", "Input"],

Cell["int2= Integrate[int1[[2]],{x,-Infinity,Infinity}]", "Input"],

Cell["qnet=int2[[2]]//PowerExpand", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (c)   Plot the induced charge density on the plane using ",
  StyleBox["ContourPlot",
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["vals={d->1,q->1}", "Input"],

Cell["\<\
ContourPlot[charge/.vals
,{y,-1,1},{x,-1,1}];\
\>", "Input"],

Cell["\<\
ContourPlot[charge/.vals
,{y,-1,1},{x,-1,1}
,ColorFunction->Hue];\
\>", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{400, 644},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 91, 2, 30, "Input"],
Cell[2490, 85, 93, 2, 30, "Input"],
Cell[2586, 89, 90, 2, 30, "Input"],
Cell[2679, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2776, 99, 65, 1, 69, "Subtitle"],

Cell[CellGroupData[{
Cell[2866, 104, 104, 1, 90, "Section"],

Cell[CellGroupData[{
Cell[2995, 109, 101, 1, 63, "Subsection"],
Cell[3099, 112, 214, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[3338, 124, 205, 4, 93, "Subsubsection"],
Cell[3546, 130, 88, 3, 48, "Input"],
Cell[3637, 135, 29, 0, 30, "Input"],
Cell[3669, 137, 53, 0, 30, "Input"],
Cell[3725, 139, 33, 0, 30, "Input"],
Cell[3761, 141, 77, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3875, 146, 173, 4, 76, "Subsubsection"],
Cell[4051, 152, 64, 0, 30, "Input"],
Cell[4118, 154, 76, 0, 66, "Input"],
Cell[4197, 156, 26, 0, 30, "Input"],
Cell[4226, 158, 66, 0, 66, "Input"],
Cell[4295, 160, 44, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4376, 165, 206, 6, 76, "Subsubsection"],
Cell[4585, 173, 33, 0, 30, "Input"],
Cell[4621, 175, 70, 3, 48, "Input"],
Cell[4694, 180, 90, 4, 66, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

