(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6024,        212]*)
(*NotebookOutlinePosition[      6675,        235]*)
(*  CellTagsIndexPosition[      6631,        231]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.1  Point Charges, Multipoles, and Image Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 4:  Line Charge and a Grounded Plane", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"The potential of a single charged line parallel to the z-axis and located at \
x=x0 and y=y0 is:\nV[x,y]=-\[Lambda]Log[(x-x0)^2 + (y-y0)^2], where \[Lambda] \
is the charge per unit length.  Consider such a line of charge located a \
distance y0 above an infinite plane grounded conductor in the {x,z} plane"], 
  "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Find the potential and plot the equipotential surfaces in the \
plane of symmetry.  Show that the Laplacian of the potential is zero.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(pot0 = \ 
      \(-\((\(+\[Lambda]\))\)\)\ Log[x^2\  + \ \((y - \((\(+y0\))\))\)^2]\n
        \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  - 
        \((\(-\[Lambda]\))\)\ Log[x^2\  + \ \((y - \((\(-y0\))\))\)^2]\)], 
  "Input"],

Cell[BoxData[
    \(potential = 
      pot0 //. {a_. \ Log[b_] - a_. \ Log[c_] :> \ a\ Log[b/c]}\)], "Input"],

Cell[BoxData[
    \(potential /. {y -> 0}\)], "Input"],

Cell[BoxData[
    \(vals = {\[Lambda] -> 1, y0 -> 1}\)], "Input"],

Cell[BoxData[
    \(\(VEPlot[\((potential //. vals)\), {x, \(-1\), 1}, {y, 0, 2.1}]; \)\)], 
  "Input"],

Cell[BoxData[
    \(Laplacian[potential, Cartesian[x, y, z]] // Together\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Find the induced charge.  Plot the induced charge density on the \
plane.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(charge = \(-1\)/\((4\ \[Pi])\)\ \ D[potential, y] /. {y -> 0}\)], 
  "Input"],

Cell[BoxData[
    \(\(ContourPlot[charge /. vals // Evaluate\n
      \t, {x, \(-2\), 2}, {y, \(-2\), 2}\n, ContourSmoothing -> Automatic]; 
    \)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[charge /. vals // Evaluate\n
      \t, {x, \(-2\), 2}, {y, \(-2\), 2}\n\t, ColorFunction -> Hue\n\t, 
      ContourLines -> False\n, ContourSmoothing -> Automatic]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)  Show that integrating over the charge density gives a charge per \
unit length that equals the image charge per unit length.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Integrate[charge, {x, \(-Infinity\), Infinity}\n, 
        GenerateConditions\  -> \ False] // PowerExpand\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)   Find the electric field and use PlotVectorField to plot the \
electric field lines.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eField = \(-Grad[potential, Cartesian[x, y, z]]\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(\(PlotVectorField[eField[\([{1, 2}]\)] //. vals\n
      \t, {x, \(-5\), 5}, {y, 0, 3}\n\ \ , PlotPoints -> 16\n\t, 
      ColorFunction -> Hue\n\t, 
      Graphics`Common`GraphicsCommon`ScaleFunction -> \((1&)\)]; \)\)], 
  "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{567, 550},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 91, 2, 30, "Input"],
Cell[2490, 85, 93, 2, 30, "Input"],
Cell[2586, 89, 90, 2, 30, "Input"],
Cell[2679, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2776, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2866, 104, 104, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2995, 109, 99, 1, 63, "Subsection"],
Cell[3097, 112, 337, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[3459, 121, 212, 4, 76, "Subsubsection"],
Cell[3674, 127, 252, 5, 50, "Input"],
Cell[3929, 134, 109, 2, 30, "Input"],
Cell[4041, 138, 54, 1, 30, "Input"],
Cell[4098, 141, 65, 1, 30, "Input"],
Cell[4166, 144, 103, 2, 30, "Input"],
Cell[4272, 148, 85, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4394, 154, 152, 4, 59, "Subsubsection"],
Cell[4549, 160, 97, 2, 30, "Input"],
Cell[4649, 164, 159, 3, 70, "Input"],
Cell[4811, 169, 214, 3, 110, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5062, 177, 202, 4, 76, "Subsubsection"],
Cell[5267, 183, 139, 2, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5443, 190, 162, 4, 59, "Subsubsection"],
Cell[5608, 196, 97, 2, 30, "Input"],
Cell[5708, 200, 252, 5, 110, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

