(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7263,        258]*)
(*NotebookOutlinePosition[      7914,        281]*)
(*  CellTagsIndexPosition[      7870,        277]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.1  Point Charges, Multipoles, and Image Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 5:  Multiopole Expansions of Charge Distributions", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider the charge densities:\n\t\t\[Rho]1 = q0 (a - r) / a^4  \
(Sin[\[Theta]] - \[Pi]/4)\n\t\t\[Rho]2 = q0 (a - r) / a^4  Exp[(a - r)/a] \
Cos[\[Theta]]\n\t\t\[Rho]3 = q0 (a - r)^2 / a^5  Sin[\[Theta]]^2 Sin[2 \
\[Phi]]\n\tfor r \[Precedes] a snd \[Rho]i = 0 for r \[GreaterEqual] a."], 
  "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)  Use ContourPlot to make a two dimensional plot of the charge \
densities.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\[Rho]1\  = \ 
      q0\ \((a\  - \ r)\)\ /\ a^4\ \ \((Sin[\[Theta]]\  - \ \[Pi]/4)\)\)], 
  "Input"],

Cell[BoxData[
    \(\[Rho]2\  = \ 
      q0\ \((a\  - \ r)\)\ /\ a^4\ \ Exp[\((a\  - \ r)\)/a]\ 
        Cos[\[Theta]]\)], "Input"],

Cell[BoxData[
    \(\[Rho]3\  = \ 
      q0\ \((a\  - \ r)\)^2\ /\ a^5\ \ Sin[\[Theta]]^2\ Sin[2\ \[Phi]]\)], 
  "Input"],

Cell[BoxData[
    \(r2xRule = 
      Thread[{r, \[Theta], \[Phi]} -> \n\t\t\t
          CoordinatesFromCartesian[{x, y, z}, Spherical]]\)], "Input"],

Cell[BoxData[
    \(values = {q0 -> 1, a -> 1}\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[\(\(\[Rho]1 /. r2xRule\) //. values\) /. {y -> 0}\n
      \t, {x, \(-1\), 1}, {z, \(-1\), 1}\n\ \ , PlotPoints -> 20\n\t, 
      ColorFunction -> Hue]; \)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[\(\(\[Rho]2 /. r2xRule\) //. values\) /. {y -> 0}\n
      \t, {x, \(-1\), 1}, {z, \(-1\), 1}\n\ \ , PlotPoints -> 20\n\t, 
      ColorFunction -> Hue]; \)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[\(\(\[Rho]3 /. r2xRule\) //. values\) /. {z -> 0}\n
      \t, {x, \(-1\), 1}, {y, \(-1\), 1}\n\ \ , PlotPoints -> 20\n\t, 
      ColorFunction -> Hue]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (b)   Find the multipole expansion for the potentials.", 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(multi1 = MultipoleP[\[Rho]1, a, 2]\)], "Input"],

Cell[BoxData[
    \(multiCheck = MultipoleSH[\[Rho]1, a, 2]\)], "Input"],

Cell[BoxData[
    \(multi1 == multiCheck //. {P -> LegendreP, Y -> SphericalHarmonicY} // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(multi2 = MultipoleP[\[Rho]2, a, 2]\)], "Input"],

Cell[BoxData[
    \(multi3 = MultipoleSH[\[Rho]3, a, 2] // Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)  Find the electric fields for the multipole expansion for the \
potentials.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(eField1 = \(-Grad[multi1, Spherical[r, \[Theta], \[Phi]]]\)\)], "Input"],

Cell[BoxData[
    \(eField1 //. {P -> LegendreP} // Simplify\)], "Input"],

Cell[BoxData[
    \(eField2 = 
      \(-Grad[multi2, Spherical[r, \[Theta], \[Phi]]]\) //. {
            P -> LegendreP} // Simplify\)], "Input"],

Cell[BoxData[
    \(eField3 = 
      \(\(-Grad[multi3 //. {Y -> SphericalHarmonicY, P -> LegendreP}, 
              Spherical[r, \[Theta], \[Phi]]]\) // ExpToTrig\) // Simplify
        \)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)   Plot the potential contours and electric field lines of the \
multipole expansions using VEPlot.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(pot1 = 
      \((\(\(\(multi1 /. r2xRule\)\n
                \t\t\t\t //. {Y -> SphericalHarmonicY, P -> LegendreP}\)\n
              \t\t\t\t //. values\) /. {y -> 0, z -> y})\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(\(VEPlot[pot1]; \)\)], "Input"],

Cell[BoxData[
    \(pot2 = 
      \((\(\(\(multi2 /. r2xRule\)\n
                \t\t\t\t //. {Y -> SphericalHarmonicY, P -> LegendreP}\)\n
              \t\t\t\t //. values\) /. {y -> 0, z -> y})\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(\(VEPlot[pot2]; \)\)], "Input"],

Cell[BoxData[
    \(pot3 = 
      \(\(\((\(\(\(multi3 /. r2xRule\)\n
                    \t\t\t\t //. {Y -> SphericalHarmonicY, P -> LegendreP}\)\n
                  \t\t\t\t //. values\) /. {z -> 0})\) // ExpToTrig\) // 
          ExpandAll\) // Simplify\)], "Input"],

Cell[BoxData[
    \(\(VEPlot[pot3]; \)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{567, 550},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 91, 2, 30, "Input"],
Cell[2490, 85, 93, 2, 30, "Input"],
Cell[2586, 89, 90, 2, 30, "Input"],
Cell[2679, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2776, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2866, 104, 104, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2995, 109, 112, 1, 63, "Subsection"],
Cell[3110, 112, 316, 5, 109, "Text"],

Cell[CellGroupData[{
Cell[3451, 121, 151, 4, 59, "Subsubsection"],
Cell[3605, 127, 121, 3, 30, "Input"],
Cell[3729, 132, 131, 3, 30, "Input"],
Cell[3863, 137, 121, 3, 30, "Input"],
Cell[3987, 142, 148, 3, 50, "Input"],
Cell[4138, 147, 59, 1, 30, "Input"],
Cell[4200, 150, 201, 3, 90, "Input"],
Cell[4404, 155, 201, 3, 90, "Input"],
Cell[4608, 160, 201, 3, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4846, 168, 122, 2, 59, "Subsubsection"],
Cell[4971, 172, 67, 1, 30, "Input"],
Cell[5041, 175, 72, 1, 30, "Input"],
Cell[5116, 178, 118, 2, 50, "Input"],
Cell[5237, 182, 67, 1, 30, "Input"],
Cell[5307, 185, 80, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5424, 191, 152, 4, 59, "Subsubsection"],
Cell[5579, 197, 92, 1, 30, "Input"],
Cell[5674, 200, 73, 1, 30, "Input"],
Cell[5750, 203, 145, 3, 50, "Input"],
Cell[5898, 208, 198, 4, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6133, 217, 175, 4, 76, "Subsubsection"],
Cell[6311, 223, 226, 5, 70, "Input"],
Cell[6540, 230, 51, 1, 30, "Input"],
Cell[6594, 233, 226, 5, 70, "Input"],
Cell[6823, 240, 51, 1, 30, "Input"],
Cell[6877, 243, 268, 5, 70, "Input"],
Cell[7148, 250, 51, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

