(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6097,        229]*)
(*NotebookOutlinePosition[      6748,        252]*)
(*  CellTagsIndexPosition[      6704,        248]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.2  Cartesian and Cylindrical Coordinates", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 1:  Separation of Variables in Cartesian and Cylindrical \
Coordinates\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["Consider Laplace's Equation for the electric potential.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   For Cartesian coordinates, assume a potential of the form V[x,y,z] \
= vx[x] vy[y] vz[z] and apply the Laplacian to this product.  Solve the \
ordinary differential equation for each function.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(potCart = vx[x] vy[y] vz[z]\)], "Input"],

Cell[BoxData[
    \(SetCoordinates[Cartesian[x, y, z]]\)], "Input"],

Cell[BoxData[
    \(lapEqn = Laplacian[potCart]\)], "Input"],

Cell[BoxData[
    \(eq1 = lapEqn/potCart // Expand\)], "Input"],

Cell[BoxData[
    \(select[eq_, var_] := Select[eq, \((\(! FreeQ[#, var]\))\)&]\)], "Input"],

Cell[BoxData[
    \(xEq = select[eq1, x] == \(-cx^2\)\)], "Input"],

Cell[BoxData[
    \(yEq = select[eq1, y] == \(-cy^2\)\)], "Input"],

Cell[BoxData[
    \(zEq = select[eq1, z] == cz^2\)], "Input"],

Cell[BoxData[
    \(xEq2 = Solve[xEq, {vx[x]}] /. {Rule -> Equal} // Flatten\)], "Input"],

Cell[BoxData[
    \(xEquations = {xEq2, vx[0] == vx0, \(vx'\)[0] == vx0p} // Flatten\)], 
  "Input"],

Cell[BoxData[
    \(dSolX = DSolve[xEquations, {vx[x]}, x] // Flatten\)], "Input"],

Cell[BoxData[
    \(yEq2 = Solve[yEq, {vy[y]}] /. {Rule -> Equal} // Flatten\)], "Input"],

Cell[BoxData[
    \(yEquations = {yEq2, vy[0] == vy0, \(vy'\)[0] == vy0p} // Flatten\)], 
  "Input"],

Cell[BoxData[
    \(dSolY = DSolve[yEquations, {vy[y]}, y] // Flatten\)], "Input"],

Cell[BoxData[
    \(zEq2 = Solve[zEq, {vz[z]}] /. {Rule -> Equal} // Flatten\)], "Input"],

Cell[BoxData[
    \(zEquations = {zEq2, vz[0] == vz0, \(vz'\)[0] == vz0p} // Flatten\)], 
  "Input"],

Cell[BoxData[
    \(dSolZ = DSolve[zEquations, {vz[z]}, z] // Flatten\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)   For czlindrical coordinates, assume a potential of the form \
V[r,\[Phi],z] = R[r] \[CapitalPhi][\[Phi]] Z[z] and applz the Laplacian to \
this product.  Solve the ordinar",
  "z",
  " differential equation for each function."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(potCyl = R[r] \[CapitalPhi][\[Phi]] Z[z]\)], "Input"],

Cell[BoxData[
    \(SetCoordinates[Cylindrical[r, \[Phi], z]]\)], "Input"],

Cell[BoxData[
    \(lapEqn = Laplacian[potCyl]\)], "Input"],

Cell[BoxData[
    \(eq1 = lapEqn/potCyl // Expand\)], "Input"],

Cell[BoxData[
    \(zEq = select[eq1, z] == \(+cz^2\)\)], "Input"],

Cell[BoxData[
    \(eq2 = eq1 - select[eq1, z] + \ cz^2\)], "Input"],

Cell[BoxData[
    \(eq3 = r^2\ eq2 // Expand\)], "Input"],

Cell[BoxData[
    \(\[Phi]Eq = select[eq3, \[Phi]] == \(-c\[Phi]^2\)\)], "Input"],

Cell[BoxData[
    \(rEq = \((eq3\  - select[eq3, \[Phi]] - c\[Phi]^2)\) R[r] // Expand\)], 
  "Input"],

Cell[BoxData[
    \(rEquations = {rEq == 0, R[0] == r0, \(R'\)[0] == 0}\)], "Input"],

Cell[BoxData[
    \(rSol = 
      \(DSolve[rEquations[\([1]\)], {R[r]}, r] // PowerExpand\) // Flatten
        \)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{528, 650},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 91, 2, 30, "Input"],
Cell[2490, 85, 90, 2, 30, "Input"],
Cell[2583, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2680, 95, 65, 1, 69, "Subtitle"],

Cell[CellGroupData[{
Cell[2770, 100, 96, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2891, 105, 141, 4, 82, "Subsection"],
Cell[3035, 111, 71, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[3131, 115, 271, 5, 93, "Subsubsection"],
Cell[3405, 122, 60, 1, 30, "Input"],
Cell[3468, 125, 67, 1, 30, "Input"],
Cell[3538, 128, 60, 1, 30, "Input"],
Cell[3601, 131, 63, 1, 30, "Input"],
Cell[3667, 134, 92, 1, 30, "Input"],
Cell[3762, 137, 66, 1, 30, "Input"],
Cell[3831, 140, 66, 1, 30, "Input"],
Cell[3900, 143, 61, 1, 30, "Input"],
Cell[3964, 146, 89, 1, 30, "Input"],
Cell[4056, 149, 100, 2, 30, "Input"],
Cell[4159, 153, 82, 1, 30, "Input"],
Cell[4244, 156, 89, 1, 30, "Input"],
Cell[4336, 159, 100, 2, 30, "Input"],
Cell[4439, 163, 82, 1, 30, "Input"],
Cell[4524, 166, 89, 1, 30, "Input"],
Cell[4616, 169, 100, 2, 30, "Input"],
Cell[4719, 173, 82, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4838, 179, 312, 7, 93, "Subsubsection"],
Cell[5153, 188, 73, 1, 30, "Input"],
Cell[5229, 191, 74, 1, 30, "Input"],
Cell[5306, 194, 59, 1, 30, "Input"],
Cell[5368, 197, 62, 1, 30, "Input"],
Cell[5433, 200, 66, 1, 30, "Input"],
Cell[5502, 203, 68, 1, 30, "Input"],
Cell[5573, 206, 57, 1, 30, "Input"],
Cell[5633, 209, 81, 1, 30, "Input"],
Cell[5717, 212, 102, 2, 30, "Input"],
Cell[5822, 216, 84, 1, 30, "Input"],
Cell[5909, 219, 124, 3, 50, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

