(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4971,        176]*)
(*NotebookOutlinePosition[      5622,        199]*)
(*  CellTagsIndexPosition[      5578,        195]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.2  Cartesian and Cylindrical Coordinates", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 2:  Potential with a Rectangular Groove", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider a rectangular groove that runs from z=+\[Infinity] to -\[Infinity] \
and is open in the positive y direction.  The groove is bounded by three \
walls: y=0, x=0, and x=a.  The walls at x=0 and x=a are at zero potential and \
the wall at y=0 is at a specified potential V[x,0] (independent of the z \
coordinate)."], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Find a series expansion for the potential inside the groove for an \
arbitrary V[x,0].\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"pot[f_,n_]:=Sum[A[f,m] Sin[\[Pi] m x/a] Exp[-\[Pi] m y/b],{m,1,n}]"], "Input"],

Cell[TextData["A[f_,m_]:=2/a Integrate[f Sin[\[Pi] m x/a],{x,0,a}]"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Write thr first few terms for the potential if V[x,0]=Sin[x] and \
separately, if V[x,0]==1.  Plot the potentials and use VEPlot to plot the \
equipotentials and electric field lines.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["pot1 = pot[Sin[x],6]//Expand//Simplify", "Input"],

Cell["values={a->1,b->1,V0->1}", "Input"],

Cell["Plot3D[pot1//.values//Evaluate,{x,0,1},{y,0,0.5}];", "Input"],

Cell["VEPlot[pot1//.values,{x,0,1},{y,0,0.5}];", "Input"],

Cell["pot2=pot[1,4]//.values", "Input"],

Cell["Plot3D[pot2,{x,0,1},{y,0,0.5}];", "Input"],

Cell["Plot3D[pot[1,15]//.values//Evaluate,{x,0,1},{y,0,0.5}];", "Input"],

Cell["VEPlot[pot[1,15]//.values//Evaluate,{x,0,1},{y,0,0.5}];", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)   Sum the series for V[x,0]=V0 and get a closed form for the \
solution.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["pot3=pot[V0,Infinity]//TrigToExp//Simplify", "Input"],

Cell["Plot3D[pot3//.values//Evaluate,{x,0.001,0.999},{y,0,0.5}];", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{583, 566},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 91, 2, 30, "Input"],
Cell[2490, 85, 93, 2, 30, "Input"],
Cell[2586, 89, 90, 2, 30, "Input"],
Cell[2679, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2776, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2866, 104, 96, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2987, 109, 102, 1, 63, "Subsection"],
Cell[3092, 112, 347, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[3464, 121, 165, 4, 59, "Subsubsection"],
Cell[3632, 127, 94, 1, 30, "Input"],
Cell[3729, 130, 78, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3844, 135, 262, 5, 76, "Subsubsection"],
Cell[4109, 142, 55, 0, 30, "Input"],
Cell[4167, 144, 41, 0, 30, "Input"],
Cell[4211, 146, 67, 0, 30, "Input"],
Cell[4281, 148, 57, 0, 30, "Input"],
Cell[4341, 150, 39, 0, 30, "Input"],
Cell[4383, 152, 48, 0, 30, "Input"],
Cell[4434, 154, 72, 0, 30, "Input"],
Cell[4509, 156, 72, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4618, 161, 149, 4, 59, "Subsubsection"],
Cell[4770, 167, 59, 0, 30, "Input"],
Cell[4832, 169, 75, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

