(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6480,        229]*)
(*NotebookOutlinePosition[      7131,        252]*)
(*  CellTagsIndexPosition[      7087,        248]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Lagrangians and Hamiltonians", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.2  Cartesian and Cylindrical Coordinates", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 3:  Potential with a Rectangular Conduit", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider a rectangular conduit that runs from z=+\[Infinity] to -\[Infinity] \
and is  bounded by four located at: x=0, x=a, y=0, and y=b.  The potential is \
 zero on the sides y=0, and y=b.  On the side x=a the potential is V[a,y]=V0 \
and on the side x=0 the potential satisfies the equation v'[x]=0."], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Express the potewntial as an expansion in Cartesian coordinates.  \
Determine the expansion coefficients.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(term[m_] = A[m]\ Cosh[m\ \[Pi]\ x/b]\ Sin[m\ \[Pi]\ y/b]\)], "Input"],

Cell["pot[n_]:=Sum[term[m]//Evaluate,{m,1,n}]", "Input"],

Cell[BoxData[
    \(pot[n]\)], "Input"],

Cell[BoxData[
    \(D[pot[n], x] //. {x -> 0}\)], "Input"],

Cell[BoxData[
    \(D[pot[100], x] //. {x -> 0}\)], "Input"],

Cell[BoxData[
    \(pot[n] //. {x -> a}\)], "Input"],

Cell[BoxData[
    \(eq1 = V0 == term[m] /. {x -> a}\)], "Input"],

Cell[BoxData[
    \(rhs = 
      \((\((Integrate[eq1[\([2]\)]\ Sin[m\ \[Pi]\ y/b], {y, 0, b}]\n\t\t\t // 
              Simplify\n\t\t)\) //. {Sin[2\ m\ \[Pi]] -> 0}\n\t\t)\)\)], 
  "Input"],

Cell[BoxData[
    \(lhs = 
      \((\((Integrate[eq1[\([1]\)]\ Sin[m\ \[Pi]\ y/b], {y, 0, b}]\n\t\t)
              \) //. {Cos[m\ \[Pi]] -> \((\(-1\))\)^m}\n\t\t)\) // Simplify
        \)], "Input"],

Cell[BoxData[
    \(aSol = \(Solve[rhs == lhs, A[m]] // Flatten\) // Simplify; \n
    A[m_] = A[m] /. aSol\)], "Input"],

Cell[BoxData[
    \(pot[n]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Plot the potential on wall x=a and compare the results with the \
boundary condition potential.  Experiment by keeping more terms in the \
expression for the potential.  Make a three dimensional plot of the \
potential.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(vals = {b -> 1, V0 -> 1, a -> 1}\)], "Input"],

Cell[BoxData[
    \(\(Plot[
      \(Table[pot[n], {n, 2, 8, 2}]\n\t //. {x -> a}\) //. vals // Evaluate\n
      \t, {y, 0, 1}\n, PlotRange -> {0, 2}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot[
      \(Table[pot[n], {n, 10, 20, 2}]\n\t //. {x -> a}\) //. vals // Evaluate
        \n\t, {y, 0, 1}\n, PlotRange -> {0, 2}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot[
      \(Table[pot[n], {n, 20, 100, 20}]\n\t //. {x -> a}\) //. vals // 
        Evaluate\n\t, {y, 0, 1}\n, PlotRange -> {0, 2}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[pot[4] //. vals // Evaluate\n\t, {y, 0, 1}, {x, 0, 1}\n, 
      ViewPoint -> {2, 2, 1}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[pot[10] //. vals // Evaluate\n\t, {y, 0, 1}, {x, 0, 1}\n, 
      ViewPoint -> {2, 2, 1}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[pot[100] //. vals // Evaluate\n\t, {y, 0, 1}, {x, 0, 1}\n, 
      ViewPoint -> {2, 2, 1}]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)   Plot the equipotential surfaces and the electric field in the \
{x,y} plane.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(VEPlot[pot[4] //. vals, {x, 0, 1}, {y, 0, 1}]; \)\)], "Input"],

Cell[BoxData[
    \(\(VEPlot[pot[10] //. vals, {x, 0, 1}, {y, 0, 1}]; \)\)], "Input"],

Cell[BoxData[
    \(\(VEPlot[pot[100] //. vals, {x, 0, 1}, {y, 0, 1}]; \)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{583, 566},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 138, 3, 166, "Title"],

Cell[CellGroupData[{
Cell[1894, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2029, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2125, 70, 58, 1, 69, "Subtitle"],
Cell[2186, 73, 108, 2, 70, "Input"],
Cell[2297, 77, 96, 2, 30, "Input"],
Cell[2396, 81, 91, 2, 30, "Input"],
Cell[2490, 85, 93, 2, 30, "Input"],
Cell[2586, 89, 90, 2, 30, "Input"],
Cell[2679, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2776, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2866, 104, 96, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2987, 109, 103, 1, 63, "Subsection"],
Cell[3093, 112, 330, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[3448, 120, 184, 4, 76, "Subsubsection"],
Cell[3635, 126, 89, 1, 30, "Input"],
Cell[3727, 129, 56, 0, 30, "Input"],
Cell[3786, 131, 39, 1, 30, "Input"],
Cell[3828, 134, 58, 1, 30, "Input"],
Cell[3889, 137, 60, 1, 30, "Input"],
Cell[3952, 140, 52, 1, 30, "Input"],
Cell[4007, 143, 64, 1, 30, "Input"],
Cell[4074, 146, 190, 4, 90, "Input"],
Cell[4267, 152, 198, 4, 70, "Input"],
Cell[4468, 158, 119, 2, 50, "Input"],
Cell[4590, 162, 39, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4666, 168, 298, 6, 93, "Subsubsection"],
Cell[4967, 176, 65, 1, 30, "Input"],
Cell[5035, 179, 166, 3, 90, "Input"],
Cell[5204, 184, 170, 3, 90, "Input"],
Cell[5377, 189, 172, 3, 90, "Input"],
Cell[5552, 194, 133, 2, 70, "Input"],
Cell[5688, 198, 134, 2, 70, "Input"],
Cell[5825, 202, 135, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5997, 209, 155, 4, 59, "Subsubsection"],
Cell[6155, 215, 84, 1, 30, "Input"],
Cell[6242, 218, 85, 1, 30, "Input"],
Cell[6330, 221, 86, 1, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

