(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7900,        263]*)
(*NotebookOutlinePosition[      8551,        286]*)
(*  CellTagsIndexPosition[      8507,        282]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Electrostatics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.2  Cartesian and Cylindrical Coordinates", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 4:  Potential inside a Rectangular Box with Five Sides at zero \
potential\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Consider a rectangular enclosure with sides at: x=0, x=a, y=0,  y=b, z=0 and \
z=c.  The side at z=c has the potential V[x,y,c]=V0 and the other five sides \
have zero potential.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Express the potential for general V[x,y,z] as an expansion of \
functions expresses in Cartesian coordinates.  Find the expansion \
coefficients.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Clear[A, pot, term, mz, \ val1, val2]\)], "Input"],

Cell[BoxData[
    \(term[mx_, my_] := 
      \((A[mx, my]\ Sin[mx\ \[Pi]\ x/a]\n
          \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *\ Sin[my\ \[Pi]\ y/b]\n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ *\ Sinh[mz\ \[Pi]\ z/c])\)\)], "Input"],

Cell["pot[nx_,ny_]:=Sum[term[mx,my]//Evaluate,{mx,1,nx},{my,1,ny}]", "Input"],

Cell[BoxData[
    \(pot[nx, ny]\)], "Input"],

Cell[BoxData[
    \(val1 = {{x -> 0}, {y -> 0}, {z -> 0}, {x -> a}, {y -> b}}\)], "Input"],

Cell[BoxData[
    \(val2 = {Sin[mx\ \[Pi]] -> 0, Sin[my\ \[Pi]] -> 0}\)], "Input"],

Cell[BoxData[
    \(\((pot[nx, xy] //. val1)\) //. val2\)], "Input"],

Cell[BoxData[
    \(mzSol = 
      \(Solve[\((\[Pi]\ mx/a)\)^2\  + \ \((\[Pi]\ my/b)\)^2\  + 
              \((\[Pi]\ I\ mz/c)\)^2\  == 0, mz]\)[\([2]\)]\)], "Input"],

Cell[BoxData[
    \(eq1 = V0 == term[mx, my] //. {z -> c}\)], "Input"],

Cell[BoxData[
    \(trigRules = {Sin[2\ mx\ \[Pi]] -> 0, \ Sin[2\ my\ \[Pi]] -> 0, \n
        \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        Sin[mx\ \[Pi]] -> 0, Cos[mx\ \[Pi]] -> \((\(-1\))\)^mx, \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        Sin[my\ \[Pi]] -> 0, Cos[my\ \[Pi]] -> \((\(-1\))\)^my, \n
        \t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        Sin[mx\ \[Pi]/2] -> \((1 - \((\(-1\))\)^mx)\)/2, \n
        \t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ 
        Sin[my\ \[Pi]/2] -> \((1 - \((\(-1\))\)^my)\)/2}\)], "Input"],

Cell[BoxData[
    \(rhs = 
      \((Integrate[eq1[\([2]\)]\ Sin[mx\ \[Pi]\ x/a]\ Sin[my\ \[Pi]\ y/b]\n
            \t\t\t, {x, 0, a}, {y, 0, b}])\) //. trigRules\)], "Input"],

Cell[BoxData[
    \(lhs = 
      \((\((Integrate[eq1[\([1]\)]\ Sin[mx\ \[Pi]\ x/a]\ Sin[my\ \[Pi]\ y/b]\n
                \t\t\t, {x, 0, a}, {y, 0, b}])\) //. trigRules)\) // Simplify
        \)], "Input"],

Cell[BoxData[
    \(aSol = \(Solve[rhs == lhs, A[mx, my]] // Flatten\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(A[mx_, my_] = A[mx, my] /. aSol\)], "Input"],

Cell[BoxData[
    \(pot[nx, ny]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Find the first few terms of the potential expansion when V[x,y,c] \
\[Congruent] V0 = 1.  Illustrate the accuracy of the solutionby comparing the \
results with the boundary potential on the wall z=c."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(vals = {a -> 1, b -> 1, c -> 1, V0 -> 1}\)], "Input"],

Cell[BoxData[
    \(mz = mz /. mzSol\)], "Input"],

Cell[BoxData[
    \(pot[3, 3] /. vals\)], "Input"],

Cell[BoxData[
    \(\(Plot[
      Table[\(pot[n, n] //. vals\) //. {x -> 1/2, z -> 1}\n
          \t\t, {n, 2, 8, 2}] // Evaluate\n\t, {y, 0, 1}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[\(pot[8, 8] //. vals\) //. {z -> 1} // Evaluate\n
      \t, {y, 0, 1}, {x, 0, 1}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[\(pot[4, 4] //. vals\) //. {z -> 1} // Evaluate\n
      \t, {y, 0, 1}, {x, 0, 1}\n\t, ColorFunction -> Hue]; \)\)], "Input"],

Cell[BoxData[
    \(\(ContourPlot[\(pot[8, 8] //. vals\) //. {z -> 1} // Evaluate\n
      \t, {x, 0, 1}, {y, 0, 1}\n\ \ , ContourSmoothing -> True]; \)\)], 
  "Input"],

Cell[BoxData[
    \(\(ContourPlot[\(pot[4, 4] //. vals\) //. {z -> 1} // Evaluate\n
      \t, {x, 0, 1}, {y, 0, 1}\n\ \ , ContourSmoothing -> True\n\ \ , 
      ColorFunction -> Hue]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)   Let x=1/2 and plot the potential in the {y,z} plane.  Let x=1/2 \
and use VEPlot to plot the equipotential surfaces and the electric field in \
the {y,z} plane.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(Plot3D[\(pot[4, 4] //. vals\) //. {x -> 1/2} // Evaluate\n
      \t, {y, 0, 1}, {z, 0, 1}]; \)\)], "Input"],

Cell[BoxData[
    \(\(Plot3D[\(pot[60, 60] //. vals\) //. {x -> 1/2} // Evaluate\n
      \t, {y, 0, 1}, {z, 0, 1}]; \)\)], "Input"],

Cell[BoxData[
    \(\(VEPlot[\(pot[8, 8] //. vals\) //. {x -> 1/2} // Evaluate\n
      \t, {y, 0, 1}, {z, 0, 1}]; \)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{535, 518},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 124, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1880, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2015, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2111, 70, 58, 1, 69, "Subtitle"],
Cell[2172, 73, 108, 2, 70, "Input"],
Cell[2283, 77, 96, 2, 30, "Input"],
Cell[2382, 81, 91, 2, 30, "Input"],
Cell[2476, 85, 93, 2, 30, "Input"],
Cell[2572, 89, 90, 2, 30, "Input"],
Cell[2665, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2762, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2852, 104, 96, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2973, 109, 145, 4, 82, "Subsection"],
Cell[3121, 115, 202, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[3348, 123, 224, 5, 76, "Subsubsection"],
Cell[3575, 130, 70, 1, 30, "Input"],
Cell[3648, 133, 383, 6, 70, "Input"],
Cell[4034, 141, 77, 0, 30, "Input"],
Cell[4114, 143, 44, 1, 30, "Input"],
Cell[4161, 146, 90, 1, 30, "Input"],
Cell[4254, 149, 82, 1, 30, "Input"],
Cell[4339, 152, 68, 1, 30, "Input"],
Cell[4410, 155, 166, 3, 50, "Input"],
Cell[4579, 160, 70, 1, 30, "Input"],
Cell[4652, 163, 587, 9, 110, "Input"],
Cell[5242, 174, 174, 3, 50, "Input"],
Cell[5419, 179, 205, 4, 50, "Input"],
Cell[5627, 185, 98, 2, 30, "Input"],
Cell[5728, 189, 64, 1, 30, "Input"],
Cell[5795, 192, 44, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5876, 198, 282, 4, 93, "Subsubsection"],
Cell[6161, 204, 73, 1, 30, "Input"],
Cell[6237, 207, 49, 1, 30, "Input"],
Cell[6289, 210, 50, 1, 30, "Input"],
Cell[6342, 213, 162, 3, 70, "Input"],
Cell[6507, 218, 127, 2, 50, "Input"],
Cell[6637, 222, 153, 2, 70, "Input"],
Cell[6793, 226, 167, 3, 70, "Input"],
Cell[6963, 231, 199, 3, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7199, 239, 239, 5, 76, "Subsubsection"],
Cell[7441, 246, 129, 2, 50, "Input"],
Cell[7573, 250, 131, 2, 50, "Input"],
Cell[7707, 254, 129, 2, 50, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

