(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6520,        231]*)
(*NotebookOutlinePosition[      7413,        261]*)
(*  CellTagsIndexPosition[      7369,        257]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Electrostatics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.2  Cartesian and Cylindrical Coordinates", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 5:  Conducting Cylinder with a Potential on the Surface \
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider a long cylinder of radius r0 that is separated by a long lengthwise \
gap on each side.  Use cylindrical coordinates {r,\[Phi],z} amd let the \
length of the cylinder be along the z-axis.  One half of the cylinder (0 < \
\[Phi] < \[Pi]) is kept at potential V0 and the other half at potential \
-V0."], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Express the potential inside and outside the cylinder as a power \
series in r and 1/r, respectively.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(termIn[m_] = A[m]\ \((r\/r0)\)\^m\ Sin[m\ \[Phi]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(potIn[n_] := \[Sum]\+\(m = 1\)\%n termIn[m]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(eq1 = V[\[Phi]] == termIn[m] /. {r \[Rule] r0}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(rhs = 
      \[Integral]\_0
            \%\(2\ \[Pi]\)eq1\[LeftDoubleBracket]2\[RightDoubleBracket]\ 
            Sin[m\ \[Phi]] \[DifferentialD]\[Phi] //. {
          Sin[4\ m\ \[Pi]] \[Rule] 0}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(lhs = 
      Simplify[\[Integral]\_0\%\(1\ \[Pi]\)\(+V0\)\ Sin[m\ \[Phi]] 
                \[DifferentialD]\[Phi] + 
            \[Integral]\_\[Pi]\%\(2\ \[Pi]\)\(-V0\)\ Sin[m\ \[Phi]] 
                \[DifferentialD]\[Phi] //. {
            Cos[m\ \[Pi]] \[Rule] \((\(-1\))\)\^m, 
            Cos[2\ m\ \[Pi]] \[Rule] 1}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(aSol = 
      Simplify[\(Solve[rhs == lhs, A[m]]\)\[LeftDoubleBracket]1
          \[RightDoubleBracket]]; \)\), 
    \(A[m_] = A[m] /. aSol\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(potIn[n]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(termOut[m_] = A[m]\ \((r0\/r)\)\^m\ Sin[m\ \[Phi]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(potOut[n_] := \[Sum]\+\(m = 1\)\%n termOut[m]\), 
    \(potOut[n]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)   Plot the value of the potential as a function of \[Phi] for fixed \
r.  Compare the series expansion at r=r0."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(values = {r0 \[Rule] 1, V0 \[Rule] 1}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[pot]; \)\), 
    \(\(pot[n_, x_ /; x < 1] := potIn[n]; \)\), 
    \(\(pot[n_, x_ /; x \[GreaterEqual] 1] := potOut[n]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell["pot[1,1]//.values", "Input"],

Cell[BoxData[
    \(\(Plot[
      Table[pot[20, r/r0] //. values, {r, 0, 1, 0.2}] // Evaluate, {\[Phi], 
        0, 2\ \[Pi]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Plot[
      Table[pot[20, r/r0] //. values, {r, 1, 2, 0.2}] // Evaluate, {\[Phi], 
        0, 2\ \[Pi]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)   Make a three dimensional plot of the potential as a function of r \
and \[Phi]."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(CylindricalPlot3D[
      pot[20, r\/r0] //. values, {r, 0, 3}, {\[Phi], 0, 2\ \[Pi]}, 
      BoxRatios \[Rule] {1, 1, 1}, ViewPoint \[Rule] {4, \(-2\), 0}]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{631, 858},
WindowMargins->{{Automatic, 109}, {22, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 124, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1880, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2015, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2111, 70, 58, 1, 69, "Subtitle"],
Cell[2172, 73, 108, 2, 70, "Input"],
Cell[2283, 77, 96, 2, 30, "Input"],
Cell[2382, 81, 91, 2, 30, "Input"],
Cell[2476, 85, 93, 2, 30, "Input"],
Cell[2572, 89, 90, 2, 30, "Input"],
Cell[2665, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2762, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2852, 104, 96, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2973, 109, 127, 3, 63, "Subsection"],
Cell[3103, 114, 335, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[3463, 123, 180, 4, 59, "Subsubsection"],
Cell[3646, 129, 108, 2, 40, "Input"],
Cell[3757, 133, 102, 2, 49, "Input"],
Cell[3862, 137, 105, 2, 30, "Input"],
Cell[3970, 141, 254, 6, 42, "Input"],
Cell[4227, 149, 382, 8, 65, "Input"],
Cell[4612, 159, 202, 5, 50, "Input"],
Cell[4817, 166, 67, 2, 30, "Input"],
Cell[4887, 170, 109, 2, 42, "Input"],
Cell[4999, 174, 126, 3, 71, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5162, 182, 191, 3, 59, "Subsubsection"],
Cell[5356, 187, 102, 2, 30, "Input"],
Cell[5461, 191, 190, 4, 70, "Input"],
Cell[5654, 197, 34, 0, 30, "Input"],
Cell[5691, 199, 169, 4, 30, "Input"],
Cell[5863, 205, 169, 4, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6069, 214, 161, 3, 59, "Subsubsection"],
Cell[6233, 219, 223, 5, 62, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

