(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7062,        276]*)
(*NotebookOutlinePosition[      7955,        306]*)
(*  CellTagsIndexPosition[      7911,        302]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Electrostatics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.3  Legendre Polynomials and Spherical Harmonics", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 1:  A charged ring", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "Consider a uniformly charged ring of radius ",
  StyleBox["r0",
    FontWeight->"Bold"],
  " and total charge ",
  StyleBox["q",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (a)   Find the potential along thr z-axis.  Find the expansion of the \
potential in the limit r->0 and r->",
  StyleBox["\[Infinity].",
    FontFamily->"Symbol"]
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["potZ=q/Sqrt[r^2+a^2]", "Input"],

Cell["potZin[n_]:= Series[potZ,{r,0,n}]//PowerExpand//Normal", "Input"],

Cell["\<\
potZout[n_]:= Series[potZ,{r,Infinity,n}]//PowerExpand//Normal\
\>", "Input"],

Cell["potZin[9]", "Input"],

Cell["potZout[9]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)   Find the series expansion for the potential at all points in \
space.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["Clear[pot,A,B]", "Input"],

Cell[TextData[
"pot[s_]:= Sum[(B[n] r^n + A[n] (a/r)^(n+1) ) \
LegendreP[n,Cos[\[Theta]]],{n,0,s}]"], "Input"],

Cell["pot[2]", "Input"],

Cell[TextData[
"coeffOut[s_]:=\n\tSolve[0==CoefficientList[\n\t\
((pot[s]-potZout[s])//.{B[i_]->0,\[Theta]->0,r->1/w}),w]\n\t\
,list1[s]]//Flatten"], "Input"],

Cell["list1[s_]:=A[#]&/@Range[0,s]", "Input"],

Cell["list1[3]", "Input"],

Cell["coeffOut[3]", "Input"],

Cell["Clear[potOut]", "Input"],

Cell["potOut[s_]:=pot[s]//.Join[coeffOut[s],{B[x_]->0}]", "Input"],

Cell["eq2 = potOut[6]", "Input"],

Cell[TextData["potZout[9]-(potOut[9]/.\[Theta]->0)==0"], "Input"],

Cell[TextData[
"coeffIn[s_]:=\n\tSolve[0==CoefficientList[\n\t\
((potZin[s]-pot[s])//.{A[x_]->0,\[Theta]->0}),r]\n\t,list2[s]]//Flatten"], 
  "Input"],

Cell["list2[s_]:=Table[B[n],{n,0,s}]", "Input"],

Cell["list2[3]", "Input"],

Cell["coeffIn[3]", "Input"],

Cell["Clear[potIn]", "Input"],

Cell["potIn[s_]:=pot[s]//.Join[coeffIn[s],{A[x_]->0}]", "Input"],

Cell["eq4 = potIn[4]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (c)   Find the electric field at all points in space.", 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["SetCoordinates[Spherical[r,\[Theta],\[Phi]]]"], "Input"],

Cell["electOut[s_]:= -Grad[potOut[s]]", "Input"],

Cell["electOut[3]", "Input"],

Cell["electIn[s_]:= -Grad[potIn[s]]", "Input"],

Cell["electIn[3]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)   Express the potential in Cartesian coordinates and plot this in \
two and three dimensions.  Plot in the plane of the ring and normal to this \
plane.  Plot the equipotential surfaces and electric field lines.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"r2xRule=({r,\[Theta],\[Phi]}->CoordinatesFromCartesian[{x,y,z},Spherical]//\
Thread)"], "Input"],

Cell["values={a->1,q->1}", "Input"],

Cell["potOutXYZ=potOut[4]//.r2xRule//.values//Together", "Input"],

Cell["potInXYZ[x_,y_,z_]:=potIn[4]//.r2xRule//.values//Together", "Input"],

Cell["Clear[ff]", "Input"],

Cell["\<\
ff[x_, y_, z_] = 
   Evaluate[If[N[x^2 + y^2 + z^2] > 1, 
     (x^2 + 4*x^4 + y^2 + 8*x^2*y^2 + 4*y^4 - 2*z^2 + 8*x^2*z^2 + 
        8*y^2*z^2 + 4*z^4)/(4*(x^2 + y^2 + z^2)^(5/2)), 
     1/64*(64 + 16*x^2 + 9*x^4 + 16*y^2 + 18*x^2*y^2 + 9*y^4 - 32*z^2 - 
        72*x^2*z^2 - 72*y^2*z^2 + 24*z^4)]]; \
\>", "Input"],

Cell["ff[1,0,0]", "Input"],

Cell["Plot[ff[x,0,0],{x,-2,2}];", "Input"],

Cell["\<\
Show[GraphicsArray[
\t{Plot3D[ff[x,0,z],{x,-2,2},{z,-2,2},PlotPoints->20]
\t,ContourPlot[ff[x,0,z],{x,-2,2},{z,-2,2},PlotPoints->20
\t,ContourSmoothing->True
\t,ColorFunction->Hue]
\t}]];\
\>", "Input"],

Cell["VEPlot[ff[x,0,z],{x,-2,2},{z,-2,2}];", "Input"],

Cell["\<\
Show[GraphicsArray[
\t{Plot3D[ff[x,y,0],{x,-2,2},{y,-2,2},PlotPoints->20]
\t,ContourPlot[ff[x,y,0],{x,-2,2},{y,-2,2},PlotPoints->20
\t,ContourSmoothing->True
\t,ColorFunction->Hue]
\t}]];\
\>", "Input"],

Cell["VEPlot[ff[x,y,0],{x,-2,2},{y,-2,2}];", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{661, 858},
WindowMargins->{{214, Automatic}, {14, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 124, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1880, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2015, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2111, 70, 58, 1, 69, "Subtitle"],
Cell[2172, 73, 108, 2, 70, "Input"],
Cell[2283, 77, 96, 2, 30, "Input"],
Cell[2382, 81, 91, 2, 30, "Input"],
Cell[2476, 85, 93, 2, 30, "Input"],
Cell[2572, 89, 90, 2, 30, "Input"],
Cell[2665, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2762, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2852, 104, 103, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2980, 109, 81, 1, 63, "Subsection"],
Cell[3064, 112, 190, 8, 33, "Text"],

Cell[CellGroupData[{
Cell[3279, 124, 242, 6, 59, "Subsubsection"],
Cell[3524, 132, 37, 0, 30, "Input"],
Cell[3564, 134, 71, 0, 30, "Input"],
Cell[3638, 136, 87, 2, 30, "Input"],
Cell[3728, 140, 26, 0, 30, "Input"],
Cell[3757, 142, 27, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3821, 147, 148, 4, 59, "Subsubsection"],
Cell[3972, 153, 31, 0, 30, "Input"],
Cell[4006, 155, 110, 2, 30, "Input"],
Cell[4119, 159, 23, 0, 30, "Input"],
Cell[4145, 161, 158, 3, 84, "Input"],
Cell[4306, 166, 45, 0, 30, "Input"],
Cell[4354, 168, 25, 0, 30, "Input"],
Cell[4382, 170, 28, 0, 30, "Input"],
Cell[4413, 172, 30, 0, 30, "Input"],
Cell[4446, 174, 66, 0, 30, "Input"],
Cell[4515, 176, 32, 0, 30, "Input"],
Cell[4550, 178, 65, 0, 30, "Input"],
Cell[4618, 180, 150, 3, 84, "Input"],
Cell[4771, 185, 47, 0, 30, "Input"],
Cell[4821, 187, 25, 0, 30, "Input"],
Cell[4849, 189, 27, 0, 30, "Input"],
Cell[4879, 191, 29, 0, 30, "Input"],
Cell[4911, 193, 64, 0, 30, "Input"],
Cell[4978, 195, 31, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5046, 200, 121, 2, 59, "Subsubsection"],
Cell[5170, 204, 71, 0, 30, "Input"],
Cell[5244, 206, 48, 0, 30, "Input"],
Cell[5295, 208, 28, 0, 30, "Input"],
Cell[5326, 210, 46, 0, 30, "Input"],
Cell[5375, 212, 27, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5439, 217, 288, 5, 76, "Subsubsection"],
Cell[5730, 224, 112, 2, 30, "Input"],
Cell[5845, 228, 35, 0, 30, "Input"],
Cell[5883, 230, 65, 0, 30, "Input"],
Cell[5951, 232, 74, 0, 30, "Input"],
Cell[6028, 234, 26, 0, 30, "Input"],
Cell[6057, 236, 325, 7, 120, "Input"],
Cell[6385, 245, 26, 0, 30, "Input"],
Cell[6414, 247, 42, 0, 30, "Input"],
Cell[6459, 249, 212, 7, 120, "Input"],
Cell[6674, 258, 53, 0, 30, "Input"],
Cell[6730, 260, 212, 7, 120, "Input"],
Cell[6945, 269, 53, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

