(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6660,        232]*)
(*NotebookOutlinePosition[      7551,        262]*)
(*  CellTagsIndexPosition[      7507,        258]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Electrostatics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch5init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["5.2.3  Legendre Polynomials and Spherical Harmonics", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 3:   Sphere with an axially symmetric charge distribution\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Conside a sphere with an axially symmetric charge distribution.  Assume that \
the sphere has a surface-charge density that is in powers of \
Cos^n[\[Theta]]."], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)   Find the potential outside and inside the sphere for an arbitrasry \
charge density.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"potInA[s_]:= \n\tSum[(A[i] (r/a)^i) LegendreP[i,Cos[\[Theta]]],{i,0,s}]"], 
  "Input"],

Cell[TextData[
"potOutA[s_]:=\n\tSum[(A[i] (a/r)^(i+1) ) \
LegendreP[i,Cos[\[Theta]]],{i,0,s}]"], "Input"],

Cell[TextData[
"chargeDensity[s_]:=\n\t\
(1/(4\[Pi]))(D[potInA[s],r]-D[potOutA[s],r])//.{r->a}"], "Input"],

Cell["chargeDensity[2]", "Input"],

Cell[TextData[{
  "Aequation[s_,\[Rho]_]:=\nLogicalExpand[chargeDensity[s]==\[Rho] + O[",
  "Cos[\[Theta]]",
  "]^(s+1)]"
}], "Input"],

Cell[TextData["Aequation[2, Q Cos[\[Theta]]^2]"], "Input"],

Cell[TextData[
"Arule[s_,\[Rho]_]:=\n\tSolve[Aequation[s,\[Rho]],Array[A,s+1,0]]//Flatten"], 
  "Input"],

Cell[TextData["Arule[4, Q Cos[\[Theta]]^2]"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  Let the surface charge density be Q/(a^2)  (Cos[\[Theta]] + \
(1/2)Cos[\[Theta]]^2).  Find the potential using the results derived in Part \
(a) .  Plot the potential in the {r,\[Theta]} plane."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"\[Sigma]=Q/a^2 (Cos[\[Theta]] + 1/2 Cos[\[Theta]]^2)//Expand"], "Input"],

Cell[TextData["potOutQ=potOutA[2]//.Arule[2,\[Sigma]]"], "Input"],

Cell[TextData["potInQ=potInA[2]//.Arule[2,\[Sigma]]"], "Input"],

Cell["values={Q->1,a->1}", "Input"],

Cell[TextData[
"p1 = CylindricalPlot3D[potInQ//.values//Evaluate\n\t,{r,0,1},{\[Theta],0,2\
\[Pi]}\n\t,BoxRatios->{1,1,1}\n\t,ViewPoint->{-1.5,-2,2}];"], "Input"],

Cell[TextData[
"p2 = CylindricalPlot3D[potOutQ//.values//Evaluate\n\t,{r,1,3},{\[Theta],0,2\
\[Pi]}\n\t,BoxRatios->{1,1,1}\n\t,ViewPoint->{-1.5,-2,2}];"], "Input"],

Cell["Show[p1,p2];", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)  Plot the equipotential surfaces and electric field lines for the \
potential found in Pard (b).\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"r2xRule=({r,\[Theta],\[Phi]}->CoordinatesFromCartesian[{x,y,z},Spherical]//\
Thread)"], "Input"],

Cell["eq1=potInQ/.r2xRule/.values/.x->0//ExpandAll//Together", "Input"],

Cell["eq2=potOutQ/.r2xRule/.values/.x->0//ExpandAll", "Input"],

Cell[BoxData[
    \(\(2\ \[Pi]\)\/\(3\ \@\(y\^2 + z\^2\)\) + 
      \(4\ \[Pi]\ z\)\/\(3\ y\^2\ \@\(y\^2 + z\^2\) + 
          3\ z\^2\ \@\(y\^2 + z\^2\)\) - 
      \(2\ \[Pi]\)\/\(15\ y\^2\ \@\(y\^2 + z\^2\) + 
          15\ z\^2\ \@\(y\^2 + z\^2\)\) + 
      \(12\ \[Pi]\ z\^2\)\/\(\((2\ y\^2 + 2\ z\^2)\)\ 
          \((15\ y\^2\ \@\(y\^2 + z\^2\) + 15\ z\^2\ \@\(y\^2 + z\^2\))
            \)\)\)], "Input"],

Cell["\<\
pot = If[y^2 + z^2 < 1
\t, -(2/15)*(-5*Pi + Pi*y^2 - 10*Pi*z - 2*Pi*z^2)
\t,  (2*Pi)/(3*Sqrt[y^2 + z^2]) + 
    \t(4*Pi*z)/(3*y^2*Sqrt[y^2 + z^2] + 3*z^2*Sqrt[y^2 + z^2]) - 
    \t(2*Pi)/(15*y^2*Sqrt[y^2 + z^2] + 15*z^2*Sqrt[y^2 + z^2]) + 
    \t(12*Pi*z^2)/
     \t((2*y^2 + 2*z^2)*(15*y^2*Sqrt[y^2 + z^2]
     \t+ 15*z^2*Sqrt[y^2 + z^2]))];\
\>", "Input"],

Cell[TextData[
"circle=ParametricPlot[{Cos[t],Sin[t]},{t,0,2\[Pi]}\n\t\t,Axes->False\n\t\t\
,PlotStyle->{Thickness[0.030]}];"], "Input"],

Cell["Show[VEPlot[pot,{y,-2,2.1},{z,-2,2.1}],circle];", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{629, 826},
WindowMargins->{{68, Automatic}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 124, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1880, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2015, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2111, 70, 58, 1, 69, "Subtitle"],
Cell[2172, 73, 108, 2, 70, "Input"],
Cell[2283, 77, 96, 2, 30, "Input"],
Cell[2382, 81, 91, 2, 30, "Input"],
Cell[2476, 85, 93, 2, 30, "Input"],
Cell[2572, 89, 90, 2, 30, "Input"],
Cell[2665, 93, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2762, 99, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2852, 104, 103, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2980, 109, 128, 3, 63, "Subsection"],
Cell[3111, 114, 185, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[3321, 121, 163, 4, 59, "Subsubsection"],
Cell[3487, 127, 102, 2, 48, "Input"],
Cell[3592, 131, 106, 2, 48, "Input"],
Cell[3701, 135, 106, 2, 48, "Input"],
Cell[3810, 139, 33, 0, 30, "Input"],
Cell[3846, 141, 134, 4, 48, "Input"],
Cell[3983, 147, 58, 0, 30, "Input"],
Cell[4044, 149, 104, 2, 48, "Input"],
Cell[4151, 153, 54, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4242, 158, 274, 4, 76, "Subsubsection"],
Cell[4519, 164, 88, 1, 30, "Input"],
Cell[4610, 167, 65, 0, 30, "Input"],
Cell[4678, 169, 63, 0, 30, "Input"],
Cell[4744, 171, 35, 0, 30, "Input"],
Cell[4782, 173, 162, 2, 84, "Input"],
Cell[4947, 177, 163, 2, 84, "Input"],
Cell[5113, 181, 29, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5179, 186, 173, 4, 59, "Subsubsection"],
Cell[5355, 192, 112, 2, 30, "Input"],
Cell[5470, 196, 71, 0, 30, "Input"],
Cell[5544, 198, 62, 0, 30, "Input"],
Cell[5609, 200, 411, 8, 100, "Input"],
Cell[6023, 210, 367, 9, 156, "Input"],
Cell[6393, 221, 136, 2, 66, "Input"],
Cell[6532, 225, 64, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

