(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10576,        353]*)
(*NotebookOutlinePosition[     11226,        376]*)
(*  CellTagsIndexPosition[     11182,        372]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[TextData[
"6.2.1  One Dimensional Schr\[ODoubleDot]dinger Equation"], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 2:  Bound particle in an finite potential well", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Suppose a particle is bound by the finite potential well V[x] = -V0 if -a<x<a \
and =0 otherwise.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)  Use the condition that the wave function must vanish at x->\
\[Infinity] or x->-\[Infinity] and write the general form of the wave \
function in the regions to the left, right, and center of the well."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["\[Psi]W[x_] = waveTrig[x,ki,A,B]"], "Input"],

Cell[TextData["kRule = {k -> Sqrt[2m(En-V)]/\[HBar]}//PowerExpand"], "Input"],

Cell["kiRule = {ki -> k}/.kRule//.{V->-V0, En->-Wn}", "Input"],

Cell["waveExp[x,k,c1,c2]", "Input"],

Cell[TextData["\[Psi]L[x_] = waveExp[x,I k0,0,C]  (* x < -a  *)"], "Input"],

Cell[TextData["\[Psi]R[x_] = waveExp[x,I k0,D,0]  (* x > a  *)"], "Input"],

Cell["k0Rule = {k0 -> -I k}/.kRule//.{V->0, En->-Wn}//PowerExpand", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)  Require that the wave function and its derivative be continuous \
across the boundaries of the well and show that there are two classes of \
solutions, odd and even.  Find the relation between the wave function \
constants and derive an equation for the energy eigenvalues.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"eq2 = {(\[Psi]L[ x] - \[Psi]W[ x] == 0)/.{x -> -a}\n\t  ,(\[Psi]W[ x] - \
\[Psi]R[ x] == 0)/.{x -> +a}\n\t  ,(\[Psi]L'[x] - \[Psi]W'[x] == 0)/.{x -> \
-a}\n\t  ,(\[Psi]W'[x] - \[Psi]R'[x] == 0)/.{x -> +a}}"], "Input"],

Cell[TextData[
"eq2a = {(\[Psi]L'[x]/\[Psi]L[x] == \[Psi]W'[x]/\[Psi]W[x])/.{x -> -a}\n\t  \
,(\[Psi]W'[x]/\[Psi]W[x] == \[Psi]R'[x]/\[Psi]R[x])/.{x -> +a}}"], "Input"],

Cell["sSol=Solve[eq2a,{k0,A}]//Flatten", "Input"],

Cell["symEn=Thread[(sSol[[1]]/.{Rule->Equal})/ki,Equal]", "Input"],

Cell["aSol=Solve[eq2a,{k0,B}]//Flatten", "Input"],

Cell["asymEn=Thread[(aSol[[1]]/.{Rule->Equal})/ki,Equal]", "Input"],

Cell["eq3s = eq2//.sSol", "Input"],

Cell["symSol=Join[Solve[eq3s,{B,C}]//Flatten,{A->0}]", "Input"],

Cell["eq3a = eq2//.aSol", "Input"],

Cell["asymSol=Join[Solve[eq3a,{A,C}]//Flatten,{B->0}]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (c)    Express the energy eigenvalues Wn in a form similar to those \
of the infinite well bymeasuring the energy levels from the bottom of the \
well and parametrizing the values with ",
  StyleBox["n",
    FontSlant->"Italic"],
  ", where Wn = -",
  Cell[BoxData[
      \(TraditionalForm\`n\^2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[HBar]\^2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\^2\)]],
  "/(8",
  Cell[BoxData[
      \(TraditionalForm\`a\^2\)]],
  " m).  Solve for the allowed n values by plotting two sides of the \
eigenvalue equation and observing where the curves intersect.  Verify that \
the values of n approach the integer values of the infinite well as V->\
\[Infinity]."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["kRule2 = Join[kiRule,k0Rule]", "Input"],

Cell[TextData["nRule={Wn->V0 - (n \[HBar] \[Pi]/a)^2/(8 m)}"], "Input"],

Cell["eq6=symEn/.kRule2/.nRule//PowerExpand", "Input"],

Cell[TextData[
"values={a->1,m->1,\[HBar]->1,V0->{100,200,500,\[Infinity]}}"], "Input"],

Cell[TextData[
"text1={\n\t Text[FontForm[\"V0=\[Infinity]\"  \
,{\"Courier-Bold\",10}],{1.8,1.65}]\n\t\
,Text[FontForm[\"V0=500\",{\"Courier-Bold\",10}],{5.85,1.4}]\n\t\
,Text[FontForm[\"V0=200\",{\"Courier-Bold\",10}],{7.75,1.05}]\n\t\
,Text[FontForm[\"V0=100\",{\"Courier-Bold\",10}],{7.75,0.75}]};"], "Input"],

Cell["\<\
plot1=Plot[{ArcTan[eq6[[1]]],ArcTan[eq6[[2]]]}
\t/.values//Flatten//Evaluate
\t,{n,0.01,9}
\t,Frame->True
\t,FrameTicks->{{{1,\"n=1\"},{3,\"n=3\"},{5,\"n=5\"}
\t\t\t\t  ,{7,\"n=7\"},{9,\"n=9\"}},{0,0.5,1,1.5}}
\t
\t,PlotRange->{0,2}
\t,Epilog->Graphics[text1][[1]]];\
\>", "Input"],

Cell["eq7=asymEn/.kRule2/.nRule//PowerExpand", "Input"],

Cell[TextData[
"text2={\n\t Text[FontForm[\"V0=\[Infinity]\"  \
,{\"Courier-Bold\",10}],{1.8,1.65}]\n\t\
,Text[FontForm[\"V0=500\",{\"Courier-Bold\",10}],{4.8,1.43}]\n\t\
,Text[FontForm[\"V0=200\",{\"Courier-Bold\",10}],{6.75,1.13}]\n\t\
,Text[FontForm[\"V0=100\",{\"Courier-Bold\",10}],{6.75,0.87}]};"], "Input"],

Cell["\<\
plot2=Plot[{ArcTan[eq7[[1]]],ArcTan[eq7[[2]]]}
\t/.values//Flatten//Evaluate
\t,{n,0.01,9}
\t,Frame->True
\t,FrameTicks->{{{2,\"n=2\"},{4,\"n=4\"},{6,\"n=6\"}
\t\t\t\t  ,{8,\"n=8\"},{10,\"n=10\"}},{0,0.5,1,1.5}}
\t
\t,PlotRange->{0,2}
\t,Epilog->Graphics[text2][[1]]];\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (d)  Solve for the n values in a second way by finding the roots of \
the eigenvalue equation using the command ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontSize->14,
    FontColor->RGBColor[0, 0, 1]],
  "."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"nValues[eq_,potential_,guess_]:=\n\t\
(n/.FindRoot[eq/.{m->1,a->1,\[HBar]->1,V0->potential}\n\t//Evaluate\n\t\
,{n,guess}][[1]])"], "Input"],

Cell["symGuess={.9,2.9,4.9,6.9,8.9};", "Input"],

Cell["\<\
symValues = {nValues[eq6,100,#]
\t\t\t,nValues[eq6,200,#]
\t\t\t,nValues[eq6,500,#]}& /@ symGuess;\
\>", "Input"],

Cell["asymGuess={1.9,3.9,5.9,7.9.9.9};", "Input"],

Cell["\<\
asymValues = {nValues[eq7,100,#]
\t\t\t,nValues[eq7,200,#]
\t\t\t,nValues[eq7,500,#]}& /@ asymGuess;\
\>", "Input"],

Cell["\<\
(Partition[Sort[{symValues,asymValues}
\t//Flatten//N[#,4]&],3]
\t//TableForm[#,TableSpacing->{1,3}
\t\t\t\t ,TableHeadings->{
\t\t\t\t \t{\"n=1\",\"n=2\",\"n=3\",\"n=4\",\"n=5\"
\t\t\t\t \t\t  ,\"n=6\",\"n=7\",\"n=8\",\"n=9\"},
\t\t\t\t \t{\"V0=100\",\"V0=200\",\"V0=500\"}}]&)\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (e)  Plot the various wave functions for a given value of the potential.\
\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"symRules={kRule2,nRule,symSol\n\t\t\
,{a->1,\[HBar]->1,m->1,V0->100,D->100}}//Flatten;"], "Input"],

Cell[TextData[
"asymRules={kRule2,nRule,asymSol\n\t\t \
,{a->1,\[HBar]->1,m->1,V0->100,D->100}}//Flatten;"], "Input"],

Cell[TextData["Clear[\[CapitalPsi]s,\[CapitalPsi]a]"], "Input"],

Cell[TextData[
"(*Symmetric*)\n\[CapitalPsi]s[x_/;   x<-1, n0_]:= \
(\[Psi]L[x]//.symRules//.{n->n0});\n\[CapitalPsi]s[x_/;-1<=x<1, n0_]:= \
(\[Psi]W[x]//.symRules//.{n->n0});\n\[CapitalPsi]s[x_/;   x>=1, n0_]:= \
(\[Psi]R[x]//.symRules//.{n->n0});"], "Input"],

Cell[TextData[
"(*Asymmetric*)\n\[CapitalPsi]a[x_/;   x<-1, n0_]:= \
(\[Psi]L[x]//.asymRules//.{n->n0});\n\[CapitalPsi]a[x_/;-1<=x<1, n0_]:= (\
\[Psi]W[x]//.asymRules//.{n->n0});\n\[CapitalPsi]a[x_/;   x>=1, n0_]:= \
(\[Psi]R[x]//.asymRules//.{n->n0});"], "Input"],

Cell["symEnergy = nValues[eq6,100,#]& /@ symGuess", "Input"],

Cell[TextData[
"plotSym = Plot[\[CapitalPsi]s[x,#]//.symRules//Evaluate\n\t\t\t,{x,-2,2}\n\t\
\t\t,PlotLabel->N[#,3]\n\t\t\t,Axes->None\n\t\t\t,DisplayFunction->Identity]& \
/@ symEnergy;"], "Input"],

Cell["\<\
Show[GraphicsArray[{plotSym[[{1,2,3}]],plotSym[[{4,5}]]}]
\t\t\t,DisplayFunction->$DisplayFunction];\
\>", "Input"],

Cell["asymEnergy = nValues[eq7,100,#]& /@ asymGuess", "Input"],

Cell[TextData[
"plotAsym = Plot[\[CapitalPsi]a[x,#]//.asymRules//Evaluate\n\t\t\t,{x,-2,2}\n\
\t\t\t,PlotLabel->N[#,3]\n\t\t\t,Axes->None\n\t\t\t\
,DisplayFunction->Identity]& /@ asymEnergy;"], "Input"],

Cell["\<\
Show[GraphicsArray[{plotAsym[[{1,2}]],plotAsym[[{3,4}]]}]
\t\t\t,DisplayFunction->$DisplayFunction];\
\>", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{591, 726},
WindowMargins->{{61, Automatic}, {Automatic, 4}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 93, 2, 30, "Input"],
Cell[2481, 85, 90, 2, 30, "Input"],
Cell[2574, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2671, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2761, 100, 118, 2, 69, "Section"],

Cell[CellGroupData[{
Cell[2904, 106, 109, 1, 63, "Subsection"],
Cell[3016, 109, 121, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[3162, 116, 284, 5, 76, "Subsubsection"],
Cell[3449, 123, 59, 0, 30, "Input"],
Cell[3511, 125, 77, 0, 30, "Input"],
Cell[3591, 127, 62, 0, 30, "Input"],
Cell[3656, 129, 35, 0, 30, "Input"],
Cell[3694, 131, 75, 0, 30, "Input"],
Cell[3772, 133, 74, 0, 30, "Input"],
Cell[3849, 135, 76, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3962, 140, 351, 6, 93, "Subsubsection"],
Cell[4316, 148, 233, 3, 84, "Input"],
Cell[4552, 153, 168, 2, 48, "Input"],
Cell[4723, 157, 49, 0, 30, "Input"],
Cell[4775, 159, 66, 0, 30, "Input"],
Cell[4844, 161, 49, 0, 30, "Input"],
Cell[4896, 163, 67, 0, 30, "Input"],
Cell[4966, 165, 34, 0, 30, "Input"],
Cell[5003, 167, 63, 0, 30, "Input"],
Cell[5069, 169, 34, 0, 30, "Input"],
Cell[5106, 171, 64, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5207, 176, 787, 21, 127, "Subsubsection"],
Cell[5997, 199, 45, 0, 30, "Input"],
Cell[6045, 201, 71, 0, 30, "Input"],
Cell[6119, 203, 54, 0, 30, "Input"],
Cell[6176, 205, 87, 1, 30, "Input"],
Cell[6266, 208, 313, 5, 102, "Input"],
Cell[6582, 215, 291, 10, 174, "Input"],
Cell[6876, 227, 55, 0, 30, "Input"],
Cell[6934, 229, 313, 5, 102, "Input"],
Cell[7250, 236, 293, 10, 174, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7580, 251, 303, 9, 77, "Subsubsection"],
Cell[7886, 262, 156, 3, 84, "Input"],
Cell[8045, 267, 47, 0, 30, "Input"],
Cell[8095, 269, 123, 4, 66, "Input"],
Cell[8221, 275, 49, 0, 30, "Input"],
Cell[8273, 277, 125, 4, 66, "Input"],
Cell[8401, 283, 303, 8, 138, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8741, 296, 147, 4, 59, "Subsubsection"],
Cell[8891, 302, 114, 2, 48, "Input"],
Cell[9008, 306, 117, 2, 48, "Input"],
Cell[9128, 310, 63, 0, 30, "Input"],
Cell[9194, 312, 260, 4, 84, "Input"],
Cell[9457, 318, 264, 4, 84, "Input"],
Cell[9724, 324, 60, 0, 30, "Input"],
Cell[9787, 326, 199, 3, 102, "Input"],
Cell[9989, 331, 125, 3, 48, "Input"],
Cell[10117, 336, 62, 0, 30, "Input"],
Cell[10182, 338, 202, 3, 102, "Input"],
Cell[10387, 343, 125, 3, 48, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

