(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8264,        277]*)
(*NotebookOutlinePosition[      8915,        300]*)
(*  CellTagsIndexPosition[      8871,        296]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[TextData[
"6.2.1  One Dimensional Schr\[ODoubleDot]dinger Equation"], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 3:  Particle hitting a finite potential step.", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Consider a particle of energy E approaching a potential barrier V[x] = 0 if \
x<0 and V[x] = V0 if x>=0.  The wave function to the left of the barrier \
(x<0) has an incident and a reflected wave.  The wave function to the right \
of the barrier (x>0) has only a transmitted wave.  \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)  Write the general form of the wave function in the regions x<0 and \
x>=0.  Use the boundary conditions at the barrier to evaluate the amplitudes \
to the reflected and transmitted waves.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["waveExp[x,k,c1,c2]", "Input"],

Cell[TextData["kRule = {k -> Sqrt[2 m (En - V)]/\[HBar]}"], "Input"],

Cell["\<\
kRule2 = {k1->k/.kRule/.V->0
\t\t ,k2->k/.kRule}\
\>", "Input"],

Cell[TextData["\[Psi]L[x_]:= waveExp[x,k1,1,R]"], "Input"],

Cell[TextData["\[Psi]L[x]"], "Input"],

Cell[TextData["\[Psi]R[x_]:= waveExp[x,k2,T,0]"], "Input"],

Cell[TextData["\[Psi]R[x]"], "Input"],

Cell[TextData[
"boundary={\[Psi]L[x] == \[Psi]R[x],\[Psi]L'[x] == \[Psi]R'[x]}//.{x->0}"], 
  "Input"],

Cell["RTrule = Solve[boundary,{R,T}]//Flatten", "Input"],

Cell["RTrule2 = RTrule//.kRule2//PowerExpand//Simplify", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)  The coefficients of transmission T and reflection R are defined as \
thethe rations of transmitted and reflected current density compared to the \
incident current density, respectively.  Assume that En>V0 and find T and R.  \
Plot R and T as a function of En.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["SetCoordinates[Cartesian[x,y,z]]", "Input"],

Cell[TextData["incFlux = flux[\[Psi]L[x][[1]] ]"], "Input"],

Cell[TextData["Rflux = -flux[\[Psi]L[x][[2]] ]"], "Input"],

Cell[TextData["Tflux = flux[\[Psi]R[x]]"], "Input"],

Cell["\<\
{RR,TT}={Rflux[[1]]/incFlux[[1]],
\t\t Tflux[[1]]/incFlux[[1]]}/.RTrule\
\>", "Input"],

Cell["Clear[V]", "Input"],

Cell[TextData["values={m->1,\[HBar]->1,V->1}"], "Input"],

Cell["\<\
Plot[{RR,TT}/.RTrule/.kRule2/.values//Evaluate
\t,{En,1,2}
\t,AxesLabel->{FontForm[\"En\"  ,{\"Courier-Bold\",10}]
\t\t\t\t,FontForm[\"Coef\",{\"Courier-Bold\",10}]}
\t,PlotStyle->{Dashing[{0.1,0.0}],Dashing[{0.01,0.02}]}
\t,Epilog->Graphics[{
\t\t Text[FontForm[\"TT\"  ,{\"Courier-Bold\",10}],{1.8,0.89}]
\t\t,Text[FontForm[\"RR\"  ,{\"Courier-Bold\",10}],{1.8,0.15}]}
\t][[1]]];\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)    Plot the real and imaginary parts of thr wave function for \
energies En above and below the barrier V.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["values={m->1,\[HBar]->1,V->1}"], "Input"],

Cell[TextData[
"\[Psi][x0_ /; x0<=0,Energy_]:=\n\t\
\[Psi]L[x]/.RTrule/.kRule2/.values/.{x->x0,En->Energy}"], "Input"],

Cell[TextData[
"\[Psi][x0_ /; x0>0,Energy_]:=\n\t\
\[Psi]R[x]/.RTrule/.kRule2/.values/.{x->x0,En->Energy}"], "Input"],

Cell[TextData[
"wavePlot2D[Energy_]:=\n\tPlot[{Re[\[Psi][x, Energy]],Im[\[Psi][x, \
Energy]]}//Evaluate\n\t\t,{x,-10,+10}\n\t\t\
,AxesLabel->{FontForm[\"x\",{\"Courier-Bold\",10}]\n\t\t\t\t\t,FontForm[\"\
\[Psi]\",{\"Symbol\",10}]}\n\t\t,AxesOrigin->{0,0}\n\t\t\
,PlotStyle->{Dashing[{0.1,0.0}],Dashing[{0.03,0.02}]}\n\t\t\
,DisplayFunction->Identity];"], "Input"],

Cell["\<\
Show@GraphicsArray[{wavePlot2D[1.2],wavePlot2D[0.9]}
\t\t,DisplayFunction->$DisplayFunction];\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)  Use Plot3D to grah the wave function as a function of the two \
parameters {x,En}.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"wavePlot3D =\n\tPlot3D[Evaluate[#[\[Psi][x \[Pi], Energy]]]\n\t\t\
,{x,-10,+10},{Energy,0.5,1.5}\n\t\t,PlotPoints->35\n\t\t\
,AxesLabel->{\"x\",\"Energy\",\"\[Psi]\"}\n\t\t\
,Ticks->{{-10,-5,{0,\"Barrier\"},5,10}\n\t\t\t\t\
,{5,{0.7,\"E<V\"},{1,\"E=V\"},{1.2,\"E>V\"},1.4}\n\t\t\t\t,{-2,-1,0,1,2}}\n\t\
\t]& /@ {Re,Im};"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (e)  Animate the real part of the incident reflected, and transmitted \
waves.  Do the animation for energies above and below the barrier.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
timePlot[time_,wave_,Energy_,thick_,xrange_] :=
\tPlot[Evaluate[Re[Exp[-I Energy time]*wave
\t\t/.RTrule/.kRule2/.values/.En->Energy ] ]
\t\t,xrange
\t\t,PlotStyle->{Dashing[{0.05,thick}]}
\t\t,AxesOrigin->{0,0}
\t\t,DisplayFunction->Identity];\
\>", "Input"],

Cell[TextData[
"tnumber=12;\ntimestep=2 \[Pi]/tnumber;\nEnergy=1.1;\nDo[Show[{timePlot[time,\
\[Psi]L[x][[1]],Energy,0,{x,-10,0}]\n\t\t\
,timePlot[time,\[Psi]L[x][[2]],Energy,.05,{x,-10,0}]\n\t\t,timePlot[time,\
\[Psi]R[x][[1]],Energy,.02,{x, 0,10}]}\n\t,DisplayFunction->$DisplayFunction]\
\n\t,{time,0,2 \[Pi] - timestep,timestep}]"], "Input"],

Cell[TextData[
"tnumber=12;\ntimestep=2 \[Pi]/tnumber;\nEnergy=0.9;\nDo[Show[{timePlot[time,\
\[Psi]L[x][[1]],Energy,0,{x,-10,0}]\n\t\t\
,timePlot[time,\[Psi]L[x][[2]],Energy,.05,{x,-10,0}]\n\t\t,timePlot[time,\
\[Psi]R[x][[1]],Energy,.02,{x, 0,10}]}\n\t,DisplayFunction->$DisplayFunction]\
\n\t,{time,0,2 \[Pi] - timestep,timestep}]"], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{591, 726},
WindowMargins->{{15, Automatic}, {Automatic, 33}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 93, 2, 30, "Input"],
Cell[2481, 85, 90, 2, 30, "Input"],
Cell[2574, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2671, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2761, 100, 118, 2, 69, "Section"],

Cell[CellGroupData[{
Cell[2904, 106, 108, 1, 63, "Subsection"],
Cell[3015, 109, 306, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[3346, 118, 265, 5, 93, "Subsubsection"],
Cell[3614, 125, 35, 0, 30, "Input"],
Cell[3652, 127, 68, 0, 30, "Input"],
Cell[3723, 129, 73, 3, 48, "Input"],
Cell[3799, 134, 58, 0, 30, "Input"],
Cell[3860, 136, 37, 0, 30, "Input"],
Cell[3900, 138, 58, 0, 30, "Input"],
Cell[3961, 140, 37, 0, 30, "Input"],
Cell[4001, 142, 102, 2, 30, "Input"],
Cell[4106, 146, 56, 0, 30, "Input"],
Cell[4165, 148, 65, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4267, 153, 338, 6, 93, "Subsubsection"],
Cell[4608, 161, 49, 0, 30, "Input"],
Cell[4660, 163, 59, 0, 30, "Input"],
Cell[4722, 165, 58, 0, 30, "Input"],
Cell[4783, 167, 51, 0, 30, "Input"],
Cell[4837, 169, 96, 3, 48, "Input"],
Cell[4936, 174, 25, 0, 30, "Input"],
Cell[4964, 176, 56, 0, 30, "Input"],
Cell[5023, 178, 406, 10, 174, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5466, 193, 183, 4, 76, "Subsubsection"],
Cell[5652, 199, 56, 0, 30, "Input"],
Cell[5711, 201, 118, 2, 48, "Input"],
Cell[5832, 205, 117, 2, 48, "Input"],
Cell[5952, 209, 364, 6, 156, "Input"],
Cell[6319, 217, 118, 3, 48, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6474, 225, 160, 4, 59, "Subsubsection"],
Cell[6637, 231, 347, 6, 174, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7021, 242, 211, 4, 76, "Subsubsection"],
Cell[7235, 248, 269, 8, 138, "Input"],
Cell[7507, 258, 345, 5, 156, "Input"],
Cell[7855, 265, 345, 5, 156, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

