(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9621,        317]*)
(*NotebookOutlinePosition[     10272,        340]*)
(*  CellTagsIndexPosition[     10228,        336]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[TextData[
"6.2.1  One Dimensional Schr\[ODoubleDot]dinger Equation"], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 4:  Particle propagating towards a rectangular potential.\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Consider a particle of energy E>0 propagates from the left (x < -a) toward a \
rectangular well or barrier described by V[x] = V0 if -a< x<+a and V[x] = 0 \
otherwise.  If V0>0, the potential describes a barrier; if V0<0, the \
potential describes a well.  The wave to the left (x < -a) of the potnetial \
has incoming and reflected components. Set the amplitude of the incoming wave \
to 1 and let R be the amplitude of the reflected wave.   The wave to the \
right (x  > a) of the potnetial has only a transmitted component; let its \
amplitude be T.  The wave in the potential has two components; call them A \
and B.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)  Write the general form of the wave function to the left, to the \
right, and in the center of the well.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["\[Psi]L[x_] = waveExp[x,k1,1,R]"], "Input"],

Cell[TextData["\[Psi]R[x_] = waveExp[x,k1,T,0]"], "Input"],

Cell[TextData["\[Psi]W[x_] = waveExp[x,k2,A,B]"], "Input"],

Cell[TextData[
"kRule = {k1 -> Sqrt[2 m (En    )]/\[HBar]\n\t\t,k2 -> Sqrt[2 m (En - V)]/\
\[HBar]\n\t\t}//PowerExpand"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)  Use the  boundary conditions to evaluate the wave amplitudes.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"eq1 = {(\[Psi]L[ x] - \[Psi]W[ x] == 0)/.{x -> -a}\n\t  ,(\[Psi]W[ x] - \
\[Psi]R[ x] == 0)/.{x -> +a}\n\t  ,(\[Psi]L'[x] - \[Psi]W'[x] == 0)/.{x -> \
-a}\n\t  ,(\[Psi]W'[x] - \[Psi]R'[x] == 0)/.{x -> +a}}"], "Input"],

Cell["\<\
ABRTrule = \
Solve[eq1,{A,B,R,T}]//Flatten//Map[Together,#,{2}]&//ExpToTrig//Simplify\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)    The coefficients of transmission T and reflection R are defined \
as thethe ratios of transmitted and reflected currents  to the incident \
current.  Find the transmission and reflection coefficients.  Verify that T + \
R = 1 .\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["SetCoordinates[Cartesian[x,y,z]]", "Input"],

Cell[TextData["incFlux = flux[\[Psi]L[x][[1]] ]"], "Input"],

Cell[TextData["refFlux = flux[\[Psi]L[x][[2]] ]"], "Input"],

Cell[TextData["tnsFlux = flux[\[Psi]R[x]]"], "Input"],

Cell["RR = refFlux[[1]]/incFlux[[1]]//Abs", "Input"],

Cell[BoxData[
    \(TT\  = \ tnsFlux[\([1]\)]/incFlux[\([1]\)] // Abs\)], "Input"],

Cell[BoxData[
    \({TT, RR} = 
      \({T\ Conjugate[T], R\ Conjugate[R]}\n\t\t /. ABRTrule\)\n
          \t\t /. {Conjugate -> conjugate}\n\t // Simplify\)], "Input"],

Cell[BoxData[
    \(TT + RR == 1 // Simplify\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)  Plot R and T as a function of En for the case of a potential well \
(V0<0) and for a potential barrier (V0>0).\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["values={\[HBar]->1,m->1,a->1};"], "Input"],

Cell["Clear[plotOperator]", "Input"],

Cell["\<\
plotOperator[Potential_, EnRange_] :=
Plot[
\tEvaluate[{RR,TT}/.kRule/.V->Potential/.values]
\t,EnRange
\t,AxesLabel->{FontForm[\"En\"  ,{\"Courier-Bold\",10}]
\t\t\t\t,FontForm[\"RR, TT\",{\"Courier-Bold\",10}]}
\t,PlotStyle->{Dashing[{0.1,0.0}],Dashing[{0.02,0.02}]}];\
\>", "Input"],

Cell[BoxData[
    \(\(plotOperator[\(-40\), {En, 1, 40}]; \)\)], "Input"],

Cell[BoxData[
    \(\(plotOperator[1, {En, 0.01, 0.99}]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (e)  Use ",
  StyleBox["Plot3D",
    FontColor->RGBColor[0, 0, 1]],
  " to plot the reflection and transmission curves as a function of the \
energy En and potential Vo."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
pt1 =Plot3D[
\t\tEvaluate[#/.kRule/.ABRTrule/.values]
\t\t,{En,0.01,10}
\t\t,{V,-20,-0.1}
\t\t,AxesLabel->{\"Energy\",\"V\",\"RR, TT\"}
\t\t,DisplayFunction->Identity
\t\t]& /@ {TT,RR};\
\>", "Input"],

Cell[BoxData[
    \(\(Show[GraphicsArray[pt1]]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (f)  Plot the real part of the wave for the complete range of x.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(plotOp[wave_, Energy_, V0_, gap_, xrange_]\  := \n\t\t\t
      Plot[Re[\(\(wave /. ABRTrule\)\n
                \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\  /. kRule\)\n
              \t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  //. {
                m -> 1, \[HBar] -> 1, En -> Energy, a -> 2, V -> V0}\ ]\n
          \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  // Evaluate\n\t\t, xrange\n
        \t\t, PlotStyle -> {Dashing[{0.03, gap}]}\n\t\t, 
        AxesOrigin -> {0, 0}\n\t\t, DisplayFunction -> Identity\n\t]; \)\)], 
  "Input"],

Cell[TextData[
"wavePlot1[En_,V0_,xmin_,xmax_]:=\n\t\
Show[{plotOp[\[Psi]L[x],En,V0,0.0,{x,xmin,-2}]\n\t\t \
,plotOp[\[Psi]R[x],En,V0,0.04,{x,2,xmax}]\n\t\t \
,plotOp[\[Psi]W[x],En,V0,0.02,{x,-2,2}]\n\t\t ,Graphics[\n\t\t \t\
{Line[{{-2,Sign[V0]},{+2,Sign[V0]}}]\n\t\t \t,Line[{{-2,Sign[V0]},{-2,0}}]\n\t\
\t \t,Line[{{+2,Sign[V0]},{+2,0}}] }]\n\t\t }\n\t\
,DisplayFunction->$DisplayFunction];"], "Input"],

Cell[BoxData[
    \(\(wavePlot1[1, \(-12\), \(-12\), 12]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (g)  Animate the time dependence of the real part of the wave as it \
propagates through a barrier (V0>0 and 0<En<V0).\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(Clear[timePlot]\)], "Input"],

Cell[TextData[
"timePlot[time_,wave_,Energy_,V0_,gap_,xrange_] :=\n\tPlot[Evaluate[Re[Exp[-I \
Energy time]*wave\n\t\t/.ABRTrule/.kRule\n\t\t\
/.{m->1,\[HBar]->1,En->Energy,a->2,V->V0} ] ]\n\t\t,xrange\n\t\t,Axes->None\n\
\t\t,PlotStyle->{Dashing[{0.05,gap}]}\n\t\t,DisplayFunction->Identity];"], 
  "Input"],

Cell[TextData[
"tnumber=16;\ntimestep=2 \[Pi]/tnumber;\nV0=1.1;\nEnergy=1;\n\
Do[Show[{timePlot[time,\[Psi]L[x],Energy,V0,0,{x,-10,-2}]\n\t\t\
,timePlot[time,\[Psi]W[x],Energy,V0,0.05,{x,-2,2}]\n\t\t\
,timePlot[time,\[Psi]R[x],Energy,V0,0.02,{x, 2,10}]}\n\t\
,DisplayFunction->$DisplayFunction]\n\t,{time,0,2 \[Pi] - \
timestep,timestep}]"], "Input"],

Cell[TextData[
"tnumber=12;\ntimestep=2 \[Pi]/tnumber;\nV0=1.2;\nEnergy=1;\n\
Do[Show[{timePlot[time,\[Psi]L[x],Energy,V0,0,{x,-10,-2}]\n\t\t\
,timePlot[time,\[Psi]W[x],Energy,V0,0.05,{x,-2,2}]\n\t\t\
,timePlot[time,\[Psi]R[x],Energy,V0,0.02,{x, 2,10}]}\n\t\
,DisplayFunction->$DisplayFunction]\n\t,{time,0,2 \[Pi] - \
timestep,timestep}]"], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{543, 678},
WindowMargins->{{11, Automatic}, {Automatic, 13}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 93, 2, 30, "Input"],
Cell[2481, 85, 90, 2, 30, "Input"],
Cell[2574, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2671, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2761, 100, 118, 2, 69, "Section"],

Cell[CellGroupData[{
Cell[2904, 106, 128, 3, 63, "Subsection"],
Cell[3035, 111, 644, 10, 147, "Text"],

Cell[CellGroupData[{
Cell[3704, 125, 181, 4, 76, "Subsubsection"],
Cell[3888, 131, 58, 0, 30, "Input"],
Cell[3949, 133, 58, 0, 30, "Input"],
Cell[4010, 135, 58, 0, 30, "Input"],
Cell[4071, 137, 130, 2, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4238, 144, 139, 3, 59, "Subsubsection"],
Cell[4380, 149, 233, 3, 84, "Input"],
Cell[4616, 154, 110, 3, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4763, 162, 307, 6, 93, "Subsubsection"],
Cell[5073, 170, 49, 0, 30, "Input"],
Cell[5125, 172, 59, 0, 30, "Input"],
Cell[5187, 174, 59, 0, 30, "Input"],
Cell[5249, 176, 53, 0, 30, "Input"],
Cell[5305, 178, 52, 0, 30, "Input"],
Cell[5360, 180, 82, 1, 30, "Input"],
Cell[5445, 183, 168, 3, 90, "Input"],
Cell[5616, 188, 57, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5710, 194, 188, 4, 76, "Subsubsection"],
Cell[5901, 200, 57, 0, 30, "Input"],
Cell[5961, 202, 36, 0, 30, "Input"],
Cell[6000, 204, 295, 8, 138, "Input"],
Cell[6298, 214, 73, 1, 30, "Input"],
Cell[6374, 217, 72, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6483, 223, 250, 7, 76, "Subsubsection"],
Cell[6736, 232, 210, 8, 138, "Input"],
Cell[6949, 242, 63, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7049, 248, 137, 3, 59, "Subsubsection"],
Cell[7189, 253, 588, 10, 210, "Input"],
Cell[7780, 265, 405, 7, 192, "Input"],
Cell[8188, 274, 73, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8298, 280, 191, 4, 76, "Subsubsection"],
Cell[8492, 286, 48, 1, 30, "Input"],
Cell[8543, 289, 308, 5, 156, "Input"],
Cell[8854, 296, 350, 6, 174, "Input"],
Cell[9207, 304, 350, 6, 174, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

