(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7144,        241]*)
(*NotebookOutlinePosition[      7795,        264]*)
(*  CellTagsIndexPosition[      7751,        260]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`ParametricPlot3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell[TextData[
"6.2.1  One Dimensional Schr\[ODoubleDot]dinger Equation"], "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 5:  Thw one-dimensional harmonic oscillator.", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Consider a particle that is bound by a force proportional to its \
displacement, F = -kx; the potential of the restoring force is V = (1/2)k \
x^2.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)  Define k = \[Omega]^2 m, En = (1/2) en \[HBar] \[Omega], and \
\[Alpha] = Sqrt[\[HBar]/(\[Omega] m}].  Express Schr\[ODoubleDot]dinger's \
equation in terms of z, where x = \[Alpha] z, and show that the equation \
reduces to \[Psi]''[z] == -(en \[Psi][z]) + z^2 \[Psi][z]"], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["SetCoordinates[Cartesian[x,y,z]]", "Input"],

Cell[TextData["eq1 = 0 == schrodinger[1/2 k x^2, En] @ (\[Psi][x])"], "Input"],

Cell[TextData[
"notation = {k -> \[Omega]^2 m, En -> (1/2) en \[HBar] \[Omega]}"], "Input"],

Cell[TextData[
"\[Alpha]Rule = {\[Alpha]->Sqrt[\[HBar]/(\[Omega] m)]}"], "Input"],

Cell[TextData["eq2 = vChange[eq1,\[Psi],x,z,\[Alpha] z]"], "Input"],

Cell[TextData["eq3a = Solve[eq2,\[Psi]''[z]]//Flatten"], "Input"],

Cell["eq3b = eq3a//.notation//Simplify", "Input"],

Cell[TextData["eq3c = eq3b//.\[Alpha]Rule//Simplify"], "Input"],

Cell["eq3 = eq3c//.{Rule->Equal}", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  Define a new function \[Psi][z] = Exp[-z^2 /2] h[z] and show that \
h[z] satisfies the equation h''[z] == h[z] - en h[z] + 2 z h'[z].  Use the \
user-defined operator diffSeriesOne to find a power series solution for h[z]. \
 Show that if the values of en are integers, the power series terminates \
beyond a certain power of z.  verify that these solutions are Hermite \
polynomials."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["\[Psi]Rule = {\[Psi] -> ((h[#] Exp[-#^2/2])&)}"], "Input"],

Cell[TextData["eq4=(eq3//.\[Psi]Rule)//ExpandAll"], "Input"],

Cell["eq5=(Solve[eq4,h''[z]][[1,1]]//ExpandAll)/.{Rule->Equal}", "Input"],

Cell["\<\
diffSol=
\t((diffSeriesOne[eq5,h,z,8,{h[0]->h0,h'[0]->hp0}]
\t\t//Collect[#,{hp0,h0,z}]&
\t\t)//Map[Simplify,#,{2}]&
\t\t)\
\>", "Input"],

Cell["\<\
serOdd=(Coefficient[diffSol,hp0]//.{en->2 n+1}
/.n->{1,3,5,7}//Factor)\
\>", "Input"],

Cell["\<\
serEven=(Coefficient[diffSol,h0]//.{en->2 n+1}
/.n->{0,2,4,6}//Factor)\
\>", "Input"],

Cell["termEven[n_]=(-1)^(n/2) (n/2)! /(n)! HermiteH[n,z]", "Input"],

Cell["serEven/(termEven[#]& /@ {0,2,4,6}) //Factor", "Input"],

Cell["termOdd[n_]=(-1)^((n-1)/2) ((n-1)/2)! /(n)! /2 HermiteH[n,z]", "Input"],

Cell["serOdd/(termOdd[#]& /@ {1,3,5,7}) //Factor", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)    Consider the equation h''[z] == h[z] - en h[z] + 2 z h'[z].  Let  \
en = 2n+1 and declare n to be an integer {0, 1, 2, 3, ...}.  Show that the \
solutions of these equations follow from the user-defined solutions in the \
Introduction (6.1).\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["n /: IntegerQ[n]=True;", "Input"],

Cell["eq6=eq5/.{en->(2 n+1)}//Expand", "Input"],

Cell["sol=DSolve[eq6,{h},z]//Flatten", "Input"],

Cell["Table[eq6/.sol,{n,0,8}]//ExpandAll", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)  Normalize the wave function.  Plot the normalized wave function and \
the square of the normalized wave function for the first eight values of n.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["\[Psi][z_,n_] = h[z] Exp[-z^2/2]//.sol"], "Input"],

Cell[TextData[
"normConst[n_] := normConst[n] = 1/Sqrt[NIntegrate[\[Psi][z,n]^2,{z,-\
\[Infinity],\[Infinity]}]]"], "Input"],

Cell["normConst[#]& /@ {0,1,2,3,4,5,6,7,8}", "Input"],

Cell[TextData[
"Plot[\n\tEvaluate[Table[normConst[n] \[Psi][z,n] + 2 n,{n,0,7}]]\n\t\
,{z,-6,6}\n\t,Epilog->Plot[1.1 z^2,{z,-6,6}\n\t\t\t\t \
,PlotStyle->Thickness[0.01]\n\t\t\t\t ,DisplayFunction->Identity\n\t\t\t\t \
][[1]]\n\t];"], "Input"],

Cell[TextData[
"Plot[\n\tEvaluate[Table[(normConst[n] \[Psi][z,n])^2 + 2 n,{n,0,7}]]\n\t\
,{z,-6,6}\n\t,Epilog->Plot[1.1 z^2,{z,-6,6}\n\t\t\t\t \
,PlotStyle->Thickness[0.01]\n\t\t\t\t ,DisplayFunction->Identity\n\t\t\t\t \
][[1]]\n\t];"], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{616, 653},
WindowMargins->{{11, Automatic}, {Automatic, 13}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 98, 2, 30, "Input"],
Cell[2486, 85, 90, 2, 30, "Input"],
Cell[2579, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2676, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2766, 100, 118, 2, 69, "Section"],

Cell[CellGroupData[{
Cell[2909, 106, 107, 1, 63, "Subsection"],
Cell[3019, 109, 171, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[3215, 117, 352, 5, 76, "Subsubsection"],
Cell[3570, 124, 49, 0, 30, "Input"],
Cell[3622, 126, 78, 0, 30, "Input"],
Cell[3703, 128, 91, 1, 30, "Input"],
Cell[3797, 131, 81, 1, 30, "Input"],
Cell[3881, 134, 67, 0, 30, "Input"],
Cell[3951, 136, 65, 0, 30, "Input"],
Cell[4019, 138, 49, 0, 30, "Input"],
Cell[4071, 140, 63, 0, 30, "Input"],
Cell[4137, 142, 43, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4217, 147, 465, 7, 110, "Subsubsection"],
Cell[4685, 156, 73, 0, 30, "Input"],
Cell[4761, 158, 60, 0, 30, "Input"],
Cell[4824, 160, 73, 0, 30, "Input"],
Cell[4900, 162, 147, 6, 102, "Input"],
Cell[5050, 170, 95, 3, 48, "Input"],
Cell[5148, 175, 95, 3, 48, "Input"],
Cell[5246, 180, 67, 0, 30, "Input"],
Cell[5316, 182, 61, 0, 30, "Input"],
Cell[5380, 184, 77, 0, 30, "Input"],
Cell[5460, 186, 59, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5556, 191, 321, 6, 93, "Subsubsection"],
Cell[5880, 199, 39, 0, 30, "Input"],
Cell[5922, 201, 47, 0, 30, "Input"],
Cell[5972, 203, 47, 0, 30, "Input"],
Cell[6022, 205, 51, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6110, 210, 223, 4, 76, "Subsubsection"],
Cell[6336, 216, 65, 0, 30, "Input"],
Cell[6404, 218, 124, 2, 30, "Input"],
Cell[6531, 222, 53, 0, 30, "Input"],
Cell[6587, 224, 243, 4, 156, "Input"],
Cell[6833, 230, 247, 4, 156, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

