(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5810,        229]*)
(*NotebookOutlinePosition[      6461,        252]*)
(*  CellTagsIndexPosition[      6417,        248]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`ParametricPlot3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["6.2.3  Three Dimensional Schr\[ODoubleDot]dinger Equation", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 1:  The three-dimensional harmonic oscillator in Cartesian \
coordinates.\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider the three-dimensional Schr\[ODoubleDot]dinger equation, where the \
potential is V = Vx[x] + Vy[y] + Vz[z]."], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)  Assume the wave function is separable and of the form X[x]Y[y]Z[z] \
and derive differential equations for X[x], Y[y], and Z[z].\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["V = (1/2) (kx x^2 + ky y^2 + kz z^2)", "Input"],

Cell[TextData["\[Psi][x,y,z] = X[x] Y[y] Z[z]"], "Input"],

Cell["SetCoordinates[Cartesian[x,y,z]]", "Input"],

Cell[TextData["eq1 = schrodinger[V,En] @ \[Psi][x,y,z]"], "Input"],

Cell["eq2 = eq1/(X[x] Y[y] Z[z])//ExpandAll", "Input"],

Cell["eRule = {En -> Ex + Ey + Ez}", "Input"],

Cell["eq3 = eq2/.eRule", "Input"],

Cell["\<\
select[eq_,En_,var_] :=
\tSelect[eq, (!FreeQ[#,var] || !FreeQ[#,En])&]\
\>", "Input"],

Cell["\<\
eq4 = (0 == {select[eq3,Ex,x]
\t\t\t,select[eq3,Ey,y]
\t\t\t,select[eq3,Ez,z]}
\t\t)//Thread\
\>", "Input"],

Cell["\<\
eq5 = {xeq,yeq,zeq} =
\t(( Solve[eq4,{X''[x],Y''[y],Z''[z]}]//Flatten)
\t\t/.{Rule->Equal}
\t\t//ExpandAll)\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  Consider the harmonic oscillator potential Vx = (1/2) kx x^2, Vy = \
(1/2) ky y^2, and Vz = (1/2) kz z^2 .  Solve the Schr\[ODoubleDot]dinger \
equation for the wave function using the one-dimensional harmonic oscillator \
solutions."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["normConst[n_] = 1/Sqrt[Sqrt[\[Pi]] 2^n Factorial[n]]"], "Input"],

Cell["X[x_,nx_] = normConst[nx] HermiteH[nx,x] Exp[-x^2/2]", "Input"],

Cell["Y[y_,ny_] = normConst[ny] HermiteH[ny,y] Exp[-y^2/2]", "Input"],

Cell["Z[z_,nz_] = normConst[nz] HermiteH[nz,z] Exp[-z^2/2]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (c)  Plot the two-dimensional wave function X[x]Y[y].", 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
wavePlot1 = Plot3D[X[x,2] Y[y,1]
\t\t\t,{x,-4,4},{y,-4,4}
\t\t\t,PlotPoints->35
\t\t\t,DisplayFunction->Identity];\
\>", "Input"],

Cell["\<\
potPlot =
\tGraphics3D[Plot3D[-2+.15(x^2 + y^2)
\t\t\t,{x,-4,4},{y,-4,4}
\t\t\t,PlotPoints->35
\t\t\t,DisplayFunction->Identity]
\t\t];\
\>", "Input"],

Cell["\<\
Show[{potPlot,wavePlot1}
\t,PlotRange->{-0.5,0.7}
\t,Boxed->False
\t,ViewPoint->{1,1,2}
\t,Axes->False
\t,DisplayFunction->$DisplayFunction];
\
\>", "Input"],

Cell["\<\
wavePlot2 = Plot3D[X[x,2] Y[y,3]
\t\t\t,{x,-4,4},{y,-4,4}
\t\t\t,PlotPoints->35
\t\t\t,DisplayFunction->Identity];\
\>", "Input"],

Cell["\<\
Show[{potPlot,wavePlot2}
\t,PlotRange->{-0.5,0.7}
\t,Boxed->False
\t,ViewPoint->{1,1,2}
\t,Axes->False
\t,DisplayFunction->$DisplayFunction];
\
\>", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{567, 604},
WindowMargins->{{83, Automatic}, {Automatic, 11}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 98, 2, 30, "Input"],
Cell[2486, 85, 90, 2, 30, "Input"],
Cell[2579, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2676, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2766, 100, 109, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2900, 105, 144, 4, 63, "Subsection"],
Cell[3047, 111, 143, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[3215, 117, 206, 4, 76, "Subsubsection"],
Cell[3424, 123, 53, 0, 30, "Input"],
Cell[3480, 125, 57, 0, 30, "Input"],
Cell[3540, 127, 49, 0, 30, "Input"],
Cell[3592, 129, 66, 0, 30, "Input"],
Cell[3661, 131, 54, 0, 30, "Input"],
Cell[3718, 133, 45, 0, 30, "Input"],
Cell[3766, 135, 33, 0, 30, "Input"],
Cell[3802, 137, 95, 3, 48, "Input"],
Cell[3900, 142, 117, 5, 84, "Input"],
Cell[4020, 149, 132, 5, 84, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4189, 159, 314, 5, 93, "Subsubsection"],
Cell[4506, 166, 79, 0, 30, "Input"],
Cell[4588, 168, 69, 0, 30, "Input"],
Cell[4660, 170, 69, 0, 30, "Input"],
Cell[4732, 172, 69, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4838, 177, 121, 2, 59, "Subsubsection"],
Cell[4962, 181, 139, 5, 84, "Input"],
Cell[5104, 188, 160, 7, 120, "Input"],
Cell[5267, 197, 167, 8, 138, "Input"],
Cell[5437, 207, 139, 5, 84, "Input"],
Cell[5579, 214, 167, 8, 138, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

