(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8182,        280]*)
(*NotebookOutlinePosition[      8833,        303]*)
(*  CellTagsIndexPosition[      8789,        299]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`ParametricPlot3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["6.2.3  Three Dimensional Schr\[ODoubleDot]dinger Equation", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell[TextData[
"Problem 2:  Schr\[ODoubleDot]dinger's equation for spherically symmetric \
potentials."], "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider the three-dimensional Schr\[ODoubleDot]dinger equation with a \
spherically symmetric potential  V = V[r].  Assume the solution separates \
into the form \[Psi][r,\[Theta],\[Phi]] = R[r] \[CapitalTheta][\[Theta]] \
\[CapitalPhi][\[Phi]] ."], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (a)  Express Schr\[ODoubleDot]dinger's equation in spherical \
coordinates and derive an equation for the angular function \[CapitalPhi][\
\[Phi]].  Solve for \[CapitalPhi][\[Phi]] and show that:\n\t\[CapitalPhi][\
\[Phi]] = c1Exp[-I ",
  Cell[BoxData[
      \(TraditionalForm\`m\_\[Phi]\)]],
  " \[Phi]] + c2Exp[I ",
  Cell[BoxData[
      \(TraditionalForm\`m\_\[Phi]\)]],
  " \[Phi]] ."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"\[Psi][r,\[Theta],\[Phi]] = R[r] \[CapitalTheta][\[Theta]] \[CapitalPhi][\
\[Phi]] "], "Input"],

Cell[TextData[{
  "SetCoordinates[Spherical[",
  "r,\[Theta],\[Phi]]]"
}], "Input"],

Cell[TextData[
"eq1 = schrodinger[V[r], En] @ \[Psi][r,\[Theta],\[Phi]]"], "Input"],

Cell[TextData[
"eq2 = (eq1 (r^2 Sin[\[Theta]]^2 /\[Psi][r,\[Theta],\[Phi]])//ExpandAll)"], 
  "Input"],

Cell["\<\
select[eq_,var_] :=
\tSelect[eq, (!FreeQ[#,var])&]\
\>", "Input"],

Cell[TextData[
"\[Phi]Eq1 = select[eq2,\[Phi]] == \[HBar]^2/(2 m) m\[Phi]^2"], "Input"],

Cell["\<\
select[eq_,var_] :=
\tSelect[eq, (!FreeQ[#,var])&]\
\>", "Input"],

Cell[TextData[
"\[Phi]Eq2 = Solve[\[Phi]Eq1,\[CapitalPhi]''[\[Phi]]][[1,1]]/.{Rule->Equal}"],
   "Input"],

Cell[TextData[
"\[Phi]Rule = DSolve[\[Phi]Eq2,{\[CapitalPhi]},\[Phi]]//Flatten"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)  Eliminate the \[Phi] variable from Schr\[ODoubleDot]dinger's \
equation using the result from Part (a).  Separate the remaining r and \
\[Theta] variables and derive equarions for ",
  "R[r] and \[CapitalTheta][\[Theta]] ."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"eq3 = (( eq2 //.\[Phi]Rule//Cancel)/Sin[\[Theta]]^2 //ExpandAll)"], "Input"],

Cell[TextData["rEq1 = select[eq3,r] == L \[HBar]^2/m"], "Input"],

Cell[TextData[
"rEq = (( Solve[rEq1,R''[r]][[1,1]]\n\t\t/.{Rule->Equal}\n\t\t//ExpandAll\n\t\
\t)/.{L->-1/2 \[ScriptL](\[ScriptL]+1)}\n\t\t)"], "Input"],

Cell[TextData[
"\[Theta]Eq = (select[eq3,\[Theta]]+L \[HBar]^2/m == 0\n\t\t/.{L->-1/2 \
\[ScriptL](\[ScriptL]+1)}\n\t\t)"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (c)  Let z = Cos[\[Theta]] and show that R[r] \
\[CapitalTheta][\[Theta]] equation in Part (b) can be expressed in the \
canonical form of Legendre's Equation:\n\t\[ScriptL] \[CapitalTheta][z] + ",
  Cell[BoxData[
      \(TraditionalForm\`\[ScriptL]\^2\)]],
  " \[CapitalTheta][z] + (",
  Cell[BoxData[
      \(TraditionalForm\`m\_\[Phi]\^2\)]],
  "\[CapitalTheta][z])/(-1 + ",
  Cell[BoxData[
      \(TraditionalForm\`z\^2\)]],
  ") - 2z \[CapitalTheta]'[z] + (1 - ",
  Cell[BoxData[
      \(TraditionalForm\`z\^2\)]],
  ") \[CapitalTheta]''[z] == 0  ."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"eq4 = vChange[\[Theta]Eq,\[CapitalTheta],\[Theta],z,ArcCos[z]]//PowerExpand//\
Simplify"], "Input"],

Cell[TextData[
"\[Theta]Eq1 = ((-2 m \[CapitalTheta][z]/\[HBar]^2 eq4)//Thread[#,Equal]&)"], 
  "Input"],

Cell[TextData[
"\[Theta]Eq2 = ((\[Theta]Eq1//.{-1+z^2->zz})//Simplify)//.{zz->-1+z^2}"], 
  "Input"],

Cell[TextData[
"\[Theta]Eq3 = Collect[\[Theta]Eq2[[1]],{\[CapitalTheta]''[z]}]==0"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (d) Declare \[ScriptL] and ",
  Cell[BoxData[
      \(TraditionalForm\`m\_\[Phi]\)]],
  " to be integersand solve Legendre's equation.  Verify that the solutions \
satisfy the equation.  Show that the product of the angular functions P[ \
\[ScriptL], m, Cos[\[Theta]]] and Exp[I m \[Phi]] are related to spherical \
harmonics by the equation:\n\tY[\[ScriptL], m, \[Theta], \[Phi]] == C[\
\[ScriptL], m] P[\[ScriptL], m, Cos[\[Theta]]] Exp[I m \[Phi]]\n\twhere C[\
\[ScriptL], m]  = Sqrt[ (2\[ScriptL] +1) / (4\[Pi]) * (\[ScriptL] - m)! / (\
\[ScriptL] + m)! ]  ."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"IntegerQ[\[ScriptL]]^=True;\nIntegerQ[m\[Phi]]^=True;"], "Input"],

Cell[TextData[
"\[Theta]Rule1 = DSolve[\[Theta]Eq2,{\[CapitalTheta]},z]//Flatten"], "Input"],

Cell[TextData[
"\[Theta]Rule2 = \
DSolve[\[Theta]Eq2//ExpandAll,{\[CapitalTheta]},z]//Flatten"], "Input"],

Cell[TextData[
"\[Theta]Rule = DSolve[\[Theta]Eq3,{\[CapitalTheta]},z]//Flatten"], "Input"],

Cell[TextData[
"Table[\[Theta]Eq3//.\[Theta]Rule,{\[ScriptL],0,3},{m\[Phi],0,\[ScriptL]}]//\
Simplify"], "Input"],

Cell[TextData[
"Coeff[el_,m_] := Sqrt[(2 el + 1)/(4 \[Pi])*(el-m)!/(el+m)!]"], "Input"],

Cell[TextData[
"sphEq :=\n\tSphericalHarmonicY[\[ScriptL],m,\[Theta],\[Phi]] == (Coeff[\
\[ScriptL],m]*LegendreP[\[ScriptL],m,Cos[\[Theta]]]\n\t\t*Exp[I m \[Phi]])"], 
  "Input"],

Cell[TextData[
"Table[sphEq//Simplify//PowerExpand//TrigReduce\n\t,{\[ScriptL],0,3},{m,0,\
\[ScriptL]}]"], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{604, 589},
WindowMargins->{{83, Automatic}, {Automatic, 11}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 98, 2, 30, "Input"],
Cell[2486, 85, 90, 2, 30, "Input"],
Cell[2579, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2676, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2766, 100, 109, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2900, 105, 152, 3, 63, "Subsection"],
Cell[3055, 110, 274, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[3354, 118, 468, 12, 94, "Subsubsection"],
Cell[3825, 132, 111, 2, 30, "Input"],
Cell[3939, 136, 83, 3, 30, "Input"],
Cell[4025, 141, 83, 1, 30, "Input"],
Cell[4111, 144, 102, 2, 30, "Input"],
Cell[4216, 148, 75, 3, 48, "Input"],
Cell[4294, 153, 87, 1, 30, "Input"],
Cell[4384, 156, 75, 3, 48, "Input"],
Cell[4462, 161, 105, 2, 30, "Input"],
Cell[4570, 165, 90, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4697, 171, 308, 6, 76, "Subsubsection"],
Cell[5008, 179, 92, 1, 30, "Input"],
Cell[5103, 182, 64, 0, 30, "Input"],
Cell[5170, 184, 152, 2, 102, "Input"],
Cell[5325, 188, 132, 2, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5494, 195, 634, 17, 94, "Subsubsection"],
Cell[6131, 214, 115, 2, 30, "Input"],
Cell[6249, 218, 104, 2, 30, "Input"],
Cell[6356, 222, 100, 2, 30, "Input"],
Cell[6459, 226, 93, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6589, 232, 643, 12, 128, "Subsubsection"],
Cell[7235, 246, 81, 1, 48, "Input"],
Cell[7319, 249, 92, 1, 30, "Input"],
Cell[7414, 252, 105, 2, 30, "Input"],
Cell[7522, 256, 91, 1, 30, "Input"],
Cell[7616, 259, 113, 2, 30, "Input"],
Cell[7732, 263, 87, 1, 30, "Input"],
Cell[7822, 266, 178, 3, 66, "Input"],
Cell[8003, 271, 115, 2, 48, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

