(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7987,        270]*)
(*NotebookOutlinePosition[      8637,        293]*)
(*  CellTagsIndexPosition[      8593,        289]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`ParametricPlot3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["6.2.3  Three Dimensional Schr\[ODoubleDot]dinger Equation", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 3:  Particle in an infinite spherical box.", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "Consider a three-dimensional square well of infinite depth and radius a \
defined by V[r] = 0 for r<a and V[r] = \[Infinity] for r>a..  Assume the wave \
function separates and is of the form \[Psi][r,\[Theta],\[Phi]] = R[r] \
\[CapitalTheta][\[Theta]] \[CapitalPhi][\[Phi]] .  The radial wave function \
satisfies the equation ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
        \(R[r]\ \((
              \[ScriptL]\ \((1 + \[ScriptL])\) - 
                \(2\ En\ m\ r\^2\)\/\[HBar]\^2 + 
                \(2\ m\ r\^2\ V[r]\)\/\[HBar]\^2)\)\), "-", 
          RowBox[{"2", " ", "r", " ", 
            RowBox[{
              SuperscriptBox["R", "\[Prime]",
                MultilineFunction->None], "[", "r", "]"}]}], "-", 
          RowBox[{\(r\^2\), " ", 
            RowBox[{
              SuperscriptBox["R", "\[DoublePrime]",
                MultilineFunction->None], "[", "r", "]"}]}]}], "==", "0"}]]],
  "\nwhere En = (\[HBar] k)^2/(2 m) + V"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (a)  Express Schr\[ODoubleDot]dinger's equation in spherical \
coordinates and derive an equation for the angular function \[CapitalPhi][\
\[Phi]].  Solve for \[CapitalPhi][\[Phi]] and show that:\n\t\[CapitalPhi][\
\[Phi]] = c1Exp[-I ",
  Cell[BoxData[
      \(TraditionalForm\`m\_\[Phi]\)]],
  " \[Phi]] + c2Exp[I ",
  Cell[BoxData[
      \(TraditionalForm\`m\_\[Phi]\)]],
  " \[Phi]] ."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"\[Psi][r,\[Theta],\[Phi]] = R[r] \[CapitalTheta][\[Theta]] \[CapitalPhi][\
\[Phi]] "], "Input"],

Cell[TextData[{
  "SetCoordinates[Spherical[",
  "r,\[Theta],\[Phi]]]"
}], "Input"],

Cell[TextData[
"eq1 = R[r]*(k^2 r^2 - \[ScriptL](1 + \[ScriptL])) + 2 r R'[r] + r^2 R''[r] \
== 0"], "Input"],

Cell[TextData["kRule = {k -> Sqrt[2 m (En-V)]/\[HBar]} /. {V->0}"], "Input"],

Cell["bfSol = DSolve[eq1,R[r],r]//Flatten//PowerExpand//Simplify", "Input"],

Cell["\<\
norm[el_,k_,a_] = 1/Sqrt[Integrate[(r^2 BesselJ[(1/2)+el,k r]^2/r),{r,0,a}] \
];\
\>", "Input"],

Cell["\<\
rWave[el_,k_,a_,r_] = (norm[el,k,a] BesselJ[(1/2)+el,k r]/Sqrt[r]);\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)  Use the boundary condition at te wall to derive an expression \
for the eigenvalues.  Solve for the eigenvalues by plotting the two sdes of \
the eigenvalue equation and observing where the curves intersect.  olve for \
the eigenvalues a second way by finding the roots of the eigenvalue equation \
using the command ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1]],
  ".  Display the results in tabular and graphical forms."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"Plot[Evaluate[\n\tTable[BesselJ[(1/2)+n,k],{n,0,2,1}]\n\t\
],{k,0.01,6\[Pi]}];"], "Input"],

Cell["\<\
{guess[0],guess[1],guess[2]}=
\t{{3,6,9,13}
\t,{4.5,7.8,11,14}
\t,{5.7,9,12.5,15.5}};\
\>", "Input"],

Cell["\<\
eigenE[el_,guess_] :=
( guess
\t//Map[FindRoot[BesselJ[(1/2)+n,k]==0,{k,#}]& ,#]& )\
\>", "Input"],

Cell["kValues = Table[eigenE[n,guess[n]],{n,0,2,1}];", "Input"],

Cell["\<\
TableForm[k/.kValues
\t,TableSpacing->{0,2,2}
\t,TableHeadings->{{\"S-Wave\",\"P-Wave\",\"D-Wave\"}
\t\t\t\t\t,{\"first\",\"second\",\"third\",\"fourth\"}}]\
\>", "Input"],

Cell["list = k/.kValues;", "Input"],

Cell["\<\
levels =
\tTable[{{2i,list[[i,j]]},{2i+1,list[[i,j]]}}
\t,{i,1,3}
\t,{j,1,Length[list[[1]] ]}];\
\>", "Input"],

Cell["\<\
Show[\t{Graphics[Map[Line,levels,{2}]\t]
\t\t,Graphics[Text[\"S state\",{2.5,1}]\t]
\t\t,Graphics[Text[\"P state\",{4.5,1}]\t]
\t\t,Graphics[Text[\"D state\",{6.5,1}]\t]}
\t\t,Frame->True\t];\
\>", "Input"],

Cell["kv1=k/.kValues[[1]]", "Input"],

Cell["tr1 = Table[Evaluate[rWave[0,k,1,r]/.k->kv1[[m]]],{m,1,4}]", "Input"],

Cell[TextData[
"pt0 = Plot[Evaluate[tr1],{r,.001,1}\n\t\t,PlotStyle->{Dashing[{.01,.00}]\n\t\
\t\t\t\t,Dashing[{.05,.02}]\n\t\t\t\t\t,Dashing[{.03,.02}]\n\t\t\t\t\t\
,Dashing[{.01,.02}]\t}\n\t\t\
,PlotLabel->FontForm[\"\[Psi](0)\",{\"Symbol\",10}]\n\t];"], "Input"],

Cell["kv2=k/.kValues[[2]];", "Input"],

Cell["tr2 = Table[Evaluate[rWave[1,k,1,r]/.k->kv2[[m]]],{m,1,4}];", "Input"],

Cell[TextData[
"pt1 = Plot[Evaluate[tr2],{r,.001,1}\n\t\t,PlotStyle->{Dashing[{.01,.00}]\n\t\
\t\t\t\t,Dashing[{.05,.02}]\n\t\t\t\t\t,Dashing[{.03,.02}]\n\t\t\t\t\t\
,Dashing[{.01,.02}]\t}\n\t\t\
,PlotLabel->FontForm[\"\[Psi](1)\",{\"Symbol\",10}]\n\t];"], "Input"],

Cell["kv3=k/.kValues[[3]];", "Input"],

Cell["tr3 = Table[Evaluate[rWave[2,k,1,r]/.k->kv3[[m]]],{m,1,4}];", "Input"],

Cell[TextData[
"pt2 = Plot[Evaluate[tr3],{r,.001,1}\n\t\t,PlotStyle->{Dashing[{.01,.00}]\n\t\
\t\t\t\t,Dashing[{.05,.02}]\n\t\t\t\t\t,Dashing[{.03,.02}]\n\t\t\t\t\t\
,Dashing[{.01,.02}]\t}\n\t\t\
,PlotLabel->FontForm[\"\[Psi](2)\",{\"Symbol\",10}]\n\t];"], "Input"],

Cell["Show@GraphicsArray[{pt0,pt1,pt2}];", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{929, 751},
WindowMargins->{{67, Automatic}, {Automatic, 9}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 98, 2, 30, "Input"],
Cell[2486, 85, 90, 2, 30, "Input"],
Cell[2579, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2676, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2766, 100, 109, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2900, 105, 105, 1, 63, "Subsection"],
Cell[3008, 108, 989, 22, 75, "Text"],

Cell[CellGroupData[{
Cell[4022, 134, 468, 12, 77, "Subsubsection"],
Cell[4493, 148, 111, 2, 30, "Input"],
Cell[4607, 152, 83, 3, 30, "Input"],
Cell[4693, 157, 109, 2, 30, "Input"],
Cell[4805, 161, 76, 0, 30, "Input"],
Cell[4884, 163, 75, 0, 30, "Input"],
Cell[4962, 165, 105, 3, 30, "Input"],
Cell[5070, 170, 92, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5199, 177, 548, 11, 95, "Subsubsection"],
Cell[5750, 190, 106, 2, 66, "Input"],
Cell[5859, 194, 110, 5, 84, "Input"],
Cell[5972, 201, 108, 4, 66, "Input"],
Cell[6083, 207, 63, 0, 30, "Input"],
Cell[6149, 209, 181, 5, 84, "Input"],
Cell[6333, 216, 35, 0, 30, "Input"],
Cell[6371, 218, 120, 5, 84, "Input"],
Cell[6494, 225, 216, 6, 102, "Input"],
Cell[6713, 233, 36, 0, 30, "Input"],
Cell[6752, 235, 75, 0, 30, "Input"],
Cell[6830, 237, 265, 4, 138, "Input"],
Cell[7098, 243, 37, 0, 30, "Input"],
Cell[7138, 245, 76, 0, 30, "Input"],
Cell[7217, 247, 265, 4, 138, "Input"],
Cell[7485, 253, 37, 0, 30, "Input"],
Cell[7525, 255, 76, 0, 30, "Input"],
Cell[7604, 257, 265, 4, 138, "Input"],
Cell[7872, 263, 51, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

