(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7671,        278]*)
(*NotebookOutlinePosition[      8323,        301]*)
(*  CellTagsIndexPosition[      8279,        297]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`ParametricPlot3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["6.2.3  Three Dimensional Schr\[ODoubleDot]dinger Equation", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 4:  Particle with negative energy in a finite spherical box.\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider a three-dimensional square well of infinite depth and radius a \
defined by V[r] = -V0 for r<a and V[r] = 0 for r>a..  Assume the wave \
function separates and is of the form \[Psi][r,\[Theta],\[Phi]] = R[r] \
\[CapitalTheta][\[Theta]] \[CapitalPhi][\[Phi]] .  The radial wave function \
satisfies the equation  ((k r)^2 - \[ScriptL](\[ScriptL]+1)) R[r] + 2r R'[r] \
+ r^2 R''[r] == 0 , where En = (\[HBar] k)^2/(2 m) + V ."], "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)   Use the conditions that the wave function must be finite at the \
origin and vanish as r->\[Infinity].  Write the general form of the wave \
function inside and outside the well."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "rEq = ",
  "((k r)^2 - \[ScriptL](\[ScriptL]+1)) R[r] + 2r R'[r] + r^2 R''[r] == \
0//ExpandAll"
}], "Input"],

Cell["rRule = DSolve[rEq,{R[r]},r]//Flatten//PowerExpand", "Input"],

Cell[TextData[
"kRule = {k1 -> Sqrt[2 m (V0 - Wn)]/\[HBar]\n\t\t,k2 -> Sqrt[2 m (   - Wn)]/\
\[HBar]}//PowerExpand"], "Input"],

Cell["wave1[k_,el_,r_] = A BesselJ[(1/2)+el, k r]/Sqrt[r];", "Input"],

Cell["\<\
symBes[k_,el_,r_] :=
\tB (BesselJ[(1/2)+el, k r] + I BesselY[(1/2)+el, k r])/Sqrt[r]\
\>", "Input"],

Cell["\<\
asymBes[k_,el_,r_] :=
\tB (BesselJ[(1/2)+el, k r] - I BesselY[(1/2)+el, k r])/Sqrt[r]\
\>", "Input"],

Cell["((symBes[I q,2,r])//TrigToExp)//ExpandAll//Factor", "Input"],

Cell["((asymBes[I q,2,r])//TrigToExp)//ExpandAll//Factor", "Input"],

Cell["wave2[k_,el_,r_] = symBes[k,el,r]", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)  Use the boundary condition at the wall to derive an expression for \
the eigenvalues.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"bc1 =(wave1[k1,\[ScriptL],r] == wave2[k2,\[ScriptL],r])//.{r->a};"], "Input"],

Cell[TextData[
"bc2 =(D[wave1[k1,\[ScriptL],r],r] == \
D[wave2[k2,\[ScriptL],r],r])//.{r->a};"], "Input"],

Cell["bc1Sol = Solve[bc1,B]//Flatten", "Input"],

Cell["bc2Sol = (bc2//.bc1Sol/.A->1)//Simplify", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)  Find the energy eigenvalues for \[ScriptL]=0 and plot the radial \
solution."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"allRules = Union[kRule,{\[HBar]->1,a->1,m->1,V0->100}];"], "Input"],

Cell[TextData[
"eq3 = bc2Sol//.{\[ScriptL]->0}//PowerExpand//Simplify"], "Input"],

Cell["Plot[eq3[[1]]//.allRules//Evaluate,{Wn,0,99}];", "Input"],

Cell["\<\
eigen[0] = \
{33,62,83,95}//Map[FindRoot[eq3[[1]]//.allRules//Evaluate,{Wn,#}]&,#]&\
\>", "Input"],

Cell["eq3[[1]]//.allRules//.eigen[0]//Chop[#,10^-6]&", "Input"],

Cell["region1s = (wave1[k1,0,r]/.A->1//.allRules//.eigen[0]);", "Input"],

Cell[TextData[{
  "region2s = (wave2[k2,0,r]",
  "//.bc1Sol/.\[ScriptL]->0",
  "/.A->1//.allRules//.eigen[0]);"
}], "Input"],

Cell["\<\
plotOp[region_,range_List] :=
\tPlot[region//Evaluate,range
\t\t,PlotStyle->{Dashing[{.05,.00}]
\t\t\t\t\t,Dashing[{.04,.02}]
\t\t\t\t\t,Dashing[{.03,.03}]
\t\t\t\t\t,Dashing[{.02,.04}]\t}
\t\t,DisplayFunction->Identity
\t]\
\>", "Input"],

Cell["\<\
Show[ plotOp[region1s,{r,0.001,1}]
\t ,plotOp[region2s,{r,1,1.3}]
\t ,Graphics[Line[{{1,-1},{1,3}}]]
\t ,Graphics[
\t \tText[FontForm[\"Boundary\",{\"Courier-Bold\",10}],{1,2}]]
\t ,PlotRange->{-0.6,2.8}
\t ,DisplayFunction->$DisplayFunction
\t];\
\>", "Input"]
}, Open  ]],

Cell[TextData[
"Part (d)  Find the energy eigenvalues for \[ScriptL]=1 and plot the radial \
solution."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)  Find the energy eigenvalues for \[ScriptL]=0 and plot the radial \
solution."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"eq4 = bc2Sol//.{\[ScriptL]->1}//PowerExpand//Simplify"], "Input"],

Cell["Plot[eq4[[1]]//.allRules//Evaluate,{Wn,0,99}];", "Input"],

Cell["\<\
eigen[1] = \
{17,49,74,91}//Map[FindRoot[eq4[[1]]//.allRules//Evaluate,{Wn,#}]&,#]&//Chop[#\
,10^-6]&\
\>", "Input"],

Cell["eq4[[1]]//.allRules//.eigen[1]//Chop[#,10^-6]&", "Input"],

Cell["region1p = (wave1[k1,1,r]/.A->1//.allRules//.eigen[1]);", "Input"],

Cell[TextData[
"region2p = \
(wave2[k2,1,r]//.bc1Sol/.\[ScriptL]->1/.A->1//.allRules//.eigen[1]);"], 
  "Input"],

Cell["\<\
Show[ plotOp[region1p,{r,0.001,1}]
\t ,plotOp[region2p,{r,1,1.3}]
\t ,Graphics[Line[{{1,-1},{1,3}}]]
\t ,Graphics[
\t \tText[FontForm[\"Boundary\",{\"Courier-Bold\",10}],{1,2}]]
\t ,PlotRange->{-0.5,1.3}
\t ,DisplayFunction->$DisplayFunction
\t];\
\>", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{897, 719},
WindowMargins->{{Automatic, 102}, {47, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 98, 2, 30, "Input"],
Cell[2486, 85, 90, 2, 30, "Input"],
Cell[2579, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2676, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2766, 100, 109, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2900, 105, 131, 3, 63, "Subsection"],
Cell[3034, 110, 459, 6, 52, "Text"],

Cell[CellGroupData[{
Cell[3518, 120, 260, 4, 76, "Subsubsection"],
Cell[3781, 126, 128, 4, 30, "Input"],
Cell[3912, 132, 67, 0, 30, "Input"],
Cell[3982, 134, 126, 2, 48, "Input"],
Cell[4111, 138, 69, 0, 30, "Input"],
Cell[4183, 140, 109, 3, 48, "Input"],
Cell[4295, 145, 110, 3, 48, "Input"],
Cell[4408, 150, 66, 0, 30, "Input"],
Cell[4477, 152, 67, 0, 30, "Input"],
Cell[4547, 154, 50, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4634, 159, 163, 4, 59, "Subsubsection"],
Cell[4800, 165, 93, 1, 30, "Input"],
Cell[4896, 168, 105, 2, 30, "Input"],
Cell[5004, 172, 47, 0, 30, "Input"],
Cell[5054, 174, 56, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5147, 179, 157, 3, 59, "Subsubsection"],
Cell[5307, 184, 83, 1, 30, "Input"],
Cell[5393, 187, 81, 1, 30, "Input"],
Cell[5477, 190, 63, 0, 30, "Input"],
Cell[5543, 192, 108, 3, 30, "Input"],
Cell[5654, 197, 63, 0, 30, "Input"],
Cell[5720, 199, 72, 0, 30, "Input"],
Cell[5795, 201, 124, 4, 30, "Input"],
Cell[5922, 207, 248, 9, 156, "Input"],
Cell[6173, 218, 271, 9, 156, "Input"]
}, Open  ]],
Cell[6459, 230, 157, 3, 59, "Subsubsection"],

Cell[CellGroupData[{
Cell[6641, 237, 157, 3, 59, "Subsubsection"],
Cell[6801, 242, 81, 1, 30, "Input"],
Cell[6885, 245, 63, 0, 30, "Input"],
Cell[6951, 247, 126, 4, 30, "Input"],
Cell[7080, 253, 63, 0, 30, "Input"],
Cell[7146, 255, 72, 0, 30, "Input"],
Cell[7221, 257, 112, 3, 30, "Input"],
Cell[7336, 262, 271, 9, 156, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

