(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7558,        268]*)
(*NotebookOutlinePosition[      8209,        291]*)
(*  CellTagsIndexPosition[      8165,        287]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6. Quantum Mechanics", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`ParametricPlot3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch6init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["6.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["6.2.3  Three Dimensional Schr\[ODoubleDot]dinger Equation", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 5:  The hydrogen atom in spherical coordinates", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider Schr\[ODoubleDot]dinger's equation with the Coulomb potential V[r] \
= -Ze^2/r .  The angular dependence is given by \
Y[\[ScriptL],m,\[Theta],\[Phi]].  The radial function satisfies the equation\n\
\t0 ==  ((k r)^2 - \[ScriptL](\[ScriptL]+1)) R[r] + 2r R'[r] + r^2 R''[r] \
where  k^2 = (En - V) 2 m/(\[HBar]^2) .  Because En is negative, set Wn = -En \
."], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (a)   Find the normalized radial wave equation in therms of the \
orbital quantum number n and the angular momentum quantum number \[ScriptL].  \
Normalizt the solution using ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\+0\%\[Infinity]\)]],
  Cell[BoxData[
      \(TraditionalForm\`R[r]\^2\)]],
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " dr = 1."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "rEq = ",
  "((k r)^2 - \[ScriptL](\[ScriptL]+1)) R[r] + 2r R'[r] + r^2 R''[r] == \
0//ExpandAll"
}], "Input"],

Cell[TextData[
"rule1 = {k -> Sqrt[2 m (En - V[r])]/\[HBar]\n\t\t,V[r] -> -Z e^2/r\n\t\t,En \
-> -Wn}"], "Input"],

Cell["rEq2 = rEq//.rule1//ExpandAll", "Input"],

Cell["\<\
rSol = ( DSolve[rEq2,{R[r]},r]//Flatten//PowerExpand//Simplify)//.{Sqrt[x_^2]-\
>x}//Simplify\
\>", "Input"],

Cell[TextData[
"rule2 = {Wn -> e^4 m Z^2/(2 n^2 \[HBar]^2)\n\t\t,e -> \[HBar]/Sqrt[m a0]}"], 
  "Input"],

Cell["rSol2 = (R[r]/.rSol)//.rule2//PowerExpand//Simplify", "Input"],

Cell[TextData["Series[HypergeometricU[-a,b,r],{r,\[Infinity],0}]"], "Input"],

Cell["rSol3 = rSol2//.{C[1]->0, C[2]->1}", "Input"],

Cell["int/:IntegerQ[int]=True", "Input"],

Cell["n/:IntegerQ[n]=True", "Input"],

Cell[TextData["\[ScriptL]/:IntegerQ[\[ScriptL]]=True"], "Input"],

Cell["\<\
H2LRule = {Hypergeometric1F1[a_,b_,c_]->(Gamma[b] Gamma[1-a] / Gamma[b-a]) \
LaguerreL[-a,b-1,c]} ;\
\>", "Input"],

Cell["rSol4 = rSol3/.H2LRule//Simplify", "Input"],

Cell[TextData[
"Integrate[ExpandAll[r^2*(rSol4//.{n->1,\[ScriptL]->0})^2],{r,0,\[Infinity]}, \
GenerateConditions -> False]"], "Input"],

Cell[TextData[
"norm[n_, \[ScriptL]_] := norm[n, \[ScriptL]] = \
Integrate[ExpandAll[r^2*(rSol4)^2],{r,0,\[Infinity]}, GenerateConditions -> \
False]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Table[norm[n, \[ScriptL]],{n,1,3},{\[ScriptL],0,n-1}]"], "Input"],

Cell[TextData[
"rWave[n_,\[ScriptL]_,r_] := rWave[n,\[ScriptL],r] = \
PowerExpand[rSol4/Sqrt[norm[n,\[ScriptL]]] ]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Table[Integrate[ExpandAll[rWave[n,\[ScriptL],r]^2 * r^2],{r,0,\[Infinity]}, \
GenerateConditions -> False],{n,1,3},{\[ScriptL],0,n-1}]"], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((rWave[1, 0, r])\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((rWave[2, #1, r]&)\)/@{0, 1}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\((rWave[3, #1, r]&)\)/@{0, 1, 2}\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)  Graph the radial probability density \[Rho][r] = ",
  Cell[BoxData[
      \(TraditionalForm\`R[r]\^2\)]],
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " for the states n={1,2,3}."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
value = {Z -> 1, a0 -> 1}; 
plot[n_, el_, rmax_] := 
   Plot[Evaluate[r^2*rWave[n, el, r]^2 /. value], {r, 0.01, rmax}, Ticks -> \
None, 
    DisplayFunction -> Identity]; \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[
      GraphicsArray[
        Evaluate[Table[plot[n, el, 10  n\ ], {n, 1, 3}, {el, 0, n - 1}]]]]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)  Plot the absolute value of the wave function for \[ScriptL]=0, 1, \
1nd 2 for all the allowable values of m and for fixed r."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(plot[el_, m_] := 
      SphericalPlot3D[
        Evaluate[Abs[SphericalHarmonicY[el, m, \[Theta], \[Phi]]]], {
          \[Theta], 0, \[Pi]}, {\[Phi], 0, 2\ \[Pi]}, Boxed \[Rule] False, 
        Axes \[Rule] False, DisplayFunction \[Rule] Identity]; \)\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(\(pt1 = 
      Table[plot[\[ScriptL], m], {\[ScriptL], 0, 2}, {m, \(-\[ScriptL]\), 
          \[ScriptL]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[GraphicsArray[pt1]]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{769, 591},
WindowMargins->{{153, Automatic}, {Automatic, 5}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 127, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1883, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2018, 63, 59, 2, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2114, 70, 58, 1, 69, "Subtitle"],
Cell[2175, 73, 108, 2, 70, "Input"],
Cell[2286, 77, 96, 2, 30, "Input"],
Cell[2385, 81, 98, 2, 30, "Input"],
Cell[2486, 85, 90, 2, 30, "Input"],
Cell[2579, 89, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2676, 95, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2766, 100, 109, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2900, 105, 109, 1, 63, "Subsection"],
Cell[3012, 108, 392, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[3429, 118, 449, 12, 93, "Subsubsection"],
Cell[3881, 132, 128, 4, 30, "Input"],
Cell[4012, 138, 113, 2, 66, "Input"],
Cell[4128, 142, 46, 0, 30, "Input"],
Cell[4177, 144, 118, 3, 30, "Input"],
Cell[4298, 149, 104, 2, 48, "Input"],
Cell[4405, 153, 68, 0, 30, "Input"],
Cell[4476, 155, 76, 0, 30, "Input"],
Cell[4555, 157, 51, 0, 30, "Input"],
Cell[4609, 159, 40, 0, 30, "Input"],
Cell[4652, 161, 36, 0, 30, "Input"],
Cell[4691, 163, 64, 0, 30, "Input"],
Cell[4758, 165, 124, 3, 48, "Input"],
Cell[4885, 170, 49, 0, 30, "Input"],
Cell[4937, 172, 135, 2, 30, "Input"],
Cell[5075, 176, 187, 4, 48, "Input"],
Cell[5265, 182, 81, 1, 30, "Input"],
Cell[5349, 185, 152, 3, 30, "Input"],
Cell[5504, 190, 188, 3, 48, "Input"],
Cell[5695, 195, 79, 2, 30, "Input"],
Cell[5777, 199, 89, 2, 30, "Input"],
Cell[5869, 203, 92, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5998, 210, 272, 8, 59, "Subsubsection"],
Cell[6273, 220, 223, 7, 84, "Input"],
Cell[6499, 229, 171, 5, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6707, 239, 205, 3, 59, "Subsubsection"],
Cell[6915, 244, 315, 7, 50, "Input"],
Cell[7233, 253, 169, 4, 30, "Input"],
Cell[7405, 259, 89, 2, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

