(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4610,        163]*)
(*NotebookOutlinePosition[      5262,        186]*)
(*  CellTagsIndexPosition[      5218,        182]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.1  Special Relativity Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 2:  Two particle collision", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
A particle of rest mass m1 collides with a stationary particle of mass m2.  \
The collision produces two particles with masses m3 and m4.  The threshold \
kinetic energy in the laboratory is the energy just sufficient to make the \
center-of-mass emergy equal to the sum of the rest masses of the particles in \
the final state. \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)    Write the total four-momentum vectors for the initial particles \
in the laboratory frame and in the center-of-mass frame.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(pL1\  = \ {E1, p1, 0, \ 0}\)], "Input"],

Cell[BoxData[
    \(pL2\  = \ {m2, 0, 0, 0}\)], "Input"],

Cell["pLT = pL1+pL2", "Input"],

Cell[BoxData[
    \(pCM1\  = \ {ECM1, kCM1, 0, \ 0}\)], "Input"],

Cell[BoxData[
    \(pCM2\  = \ {ECM2, \(-kCM1\), 0, 0}\)], "Input"],

Cell["pCMT = pCM1+pCM2", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)    Consider the scalar invariant ",
  StyleBox["p.",
    FontSlant->"Italic"],
  "\[Eta]",
  StyleBox[".p",
    FontSlant->"Italic"],
  ", where p is the total momentum.  Evaluate this invariant in the \
laboratory and center-of-mass frames and equate the expressions to solve for \
the threshold energy.  Express the results in terms of the kinetic energy of \
the particle with mass m1."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["eq1 = pLT.\[Eta].pLT == pCMT.\[Eta].pCMT"], "Input"],

Cell["eq2 = ECM1+ECM2 == m3+m4", "Input"],

Cell["{eq3,eq4} = {E1==T1+m1,p1==Sqrt[E1^2-m1^2]}", "Input"],

Cell["sol = Solve[{eq1,eq2,eq3,eq4},{T1},{E1,p1,ECM1}]//Flatten", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowSize->{640, 774},
WindowMargins->{{234, Automatic}, {43, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 86, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2783, 98, 89, 1, 63, "Subsection"],
Cell[2875, 101, 353, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[3253, 111, 202, 4, 76, "Subsubsection"],
Cell[3458, 117, 59, 1, 30, "Input"],
Cell[3520, 120, 56, 1, 30, "Input"],
Cell[3579, 123, 30, 0, 30, "Input"],
Cell[3612, 125, 64, 1, 30, "Input"],
Cell[3679, 128, 67, 1, 30, "Input"],
Cell[3749, 131, 33, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3819, 136, 473, 12, 93, "Subsubsection"],
Cell[4295, 150, 67, 0, 30, "Input"],
Cell[4365, 152, 41, 0, 30, "Input"],
Cell[4409, 154, 60, 0, 30, "Input"],
Cell[4472, 156, 74, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

