(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5644,        199]*)
(*NotebookOutlinePosition[      6536,        229]*)
(*  CellTagsIndexPosition[      6492,        225]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.1  Special Relativity Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 3:  Compton  Scattering", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"A photon with wavelength \[Lambda]0 collides with an electron of mass m at \
rest and scatters with a new wavelength \[Lambda]1.  Let the incident photon \
move along the x axisand let the scattered photon make an angle \[Theta]1 \
with the x axis.  The scattered photon moves in a direction making an angle \
\[Theta]2 with the x axis.  Let p1 and p2 be the initial four-momenta fo the \
photon and electron, respectively.  "], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)  Write the equations that follow from the conservation of \
four-momentum.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["p1 = (h {1, 0, 0, 1})/\[Lambda]0"], "Input",
  AspectRatioFixed->True],

Cell["p2 = m {1, 0, 0, 0}", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"p3 = (h*{1, Sin[\[Theta]1], 0, Cos[\[Theta]1]})/\[Lambda]1"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"p4 = m*\[Gamma]f*{1, -\[Beta]f*Sin[\[Theta]2], 0, \[Beta]f*Cos[\[Theta]2]}"],
   "Input",
  AspectRatioFixed->True],

Cell["eq1 = Thread[p1 + p2 == p3 + p4]", "Input",
  AspectRatioFixed->True],

Cell["ColumnForm[eq1]", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  Consider the scalar invariant m^2 = (p1+p2-p3).\[Eta]. (p1+p2-p3) \
and solve for the wavelength \[Lambda]1 of the final photon."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"eq2 = ExpandAll[Simplify[m^2 == (p1 + p2 - p3) . \[Eta] . (p1 + p2 - p3)]]"],
   "Input",
  AspectRatioFixed->True],

Cell[TextData[
"\[Lambda]Rule = ExpandAll[Solve[eq2, \[Lambda]1][[1]]]"], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Part (c)  Find the kinetic energy of the recoil electron.", 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["eq3 = eq1[[1]] /. \[Lambda]Rule"], "Input",
  AspectRatioFixed->True],

Cell[TextData["\[Gamma]fRule = Simplify[Solve[eq3, \[Gamma]f][[1]]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Simplify[m*\[Gamma]f - m /. \[Gamma]fRule]"], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (d)  Find a relation between \[Theta]1, \[Theta]2, and \[Lambda]0."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["eq4 = Simplify[eq1[[{2, 4}]]]", "Input",
  AspectRatioFixed->True],

Cell[TextData["sol1 = Solve[eq4, {\[Gamma]f, Sin[\[Theta]1]}][[1]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["eq5 = Sin[\[Theta]1] == (Sin[\[Theta]1] /. sol1)"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"sol2 = Simplify[Solve[eq5, {Tan[\[Theta]2]}][[1]] /. \[Lambda]Rule]"], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{476, 724},
WindowMargins->{{20, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 166, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 86, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2783, 98, 86, 1, 63, "Subsection"],
Cell[2872, 101, 452, 6, 109, "Text"],

Cell[CellGroupData[{
Cell[3349, 111, 151, 4, 76, "Subsubsection"],
Cell[3503, 117, 85, 1, 30, "Input"],
Cell[3591, 120, 62, 1, 30, "Input"],
Cell[3656, 123, 112, 2, 30, "Input"],
Cell[3771, 127, 131, 3, 30, "Input"],
Cell[3905, 132, 75, 1, 30, "Input"],
Cell[3983, 135, 58, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4078, 141, 212, 4, 76, "Subsubsection"],
Cell[4293, 147, 131, 3, 48, "Input"],
Cell[4427, 152, 108, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4572, 159, 120, 2, 59, "Subsubsection"],
Cell[4695, 163, 84, 1, 30, "Input"],
Cell[4782, 166, 105, 1, 30, "Input"],
Cell[4890, 169, 95, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5022, 175, 145, 3, 59, "Subsubsection"],
Cell[5170, 180, 72, 1, 30, "Input"],
Cell[5245, 183, 104, 1, 30, "Input"],
Cell[5352, 186, 101, 1, 30, "Input"],
Cell[5456, 189, 124, 3, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

