(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5330,        172]*)
(*NotebookOutlinePosition[      6222,        202]*)
(*  CellTagsIndexPosition[      6178,        198]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.1  Special Relativity Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 4:  Moving mirror and generalized Snell's Law.", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider a mirror at rest in reference frame S'.  As observed in S'. the \
mirror's rest frame, an incident beam of light makes an angle \[Theta]m \
relative to the normal and, according to Snell's Law, reflects at the same \
angle.  the frequency of the light in S' is fm and is the same fro the \
incident and reflected beams.  The laboratory frame S is moving with a \
velocity \[Beta] along the normal.  In the laboratory frame, the incident \
light has a frequency fi and makes an angle \[Theta]i with the normal to the \
mirror.  The reflected beam in S has a frequency fr and makes an angle \
\[Theta]r with the normal."], "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)  Show that the generalized Doppler formula is:\n\t\t fi = fr (1-\
\[Beta]^2) / (1 + \[Beta]^2 + 2\[Beta]Cos[\[Theta]i])"], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["Ki = fi{1, Cos[\[Theta]i],Sin[\[Theta]i],0}"], "Input"],

Cell[TextData["Kr = fr{1,-Cos[\[Theta]r],Sin[\[Theta]r],0}"], "Input"],

Cell[TextData["Kmi = fm{1, Cos[\[Theta]m],Sin[\[Theta]m],0}"], "Input"],

Cell[TextData["Kmr = fm{1,-Cos[\[Theta]m],Sin[\[Theta]m],0}"], "Input"],

Cell[TextData["eq1 = (Ki == boostx[\[Gamma],\[Beta]].Kmi)//Thread;"], "Input"],

Cell["eq1//ColumnForm", "Input"],

Cell[TextData["eq2 = (Kr == boostx[\[Gamma],\[Beta]].Kmr)//Thread;"], "Input"],

Cell["eq2//ColumnForm", "Input"],

Cell[TextData[
"eq3 = {eq1,eq2,{fr!=0,fi!=0,\[Gamma]!=0,\[Beta]!=0}}//Flatten;"], "Input"],

Cell[TextData[
"eq4 = Eliminate[eq3,{Cos[\[Theta]r],Sin[\[Theta]r],Cos[\[Theta]m],Sin[\
\[Theta]m]}]"], "Input"],

Cell["sol1 = Solve[eq4,{fi,fm}]//Flatten", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  Show that the generalized Snell's Law is:\n\t\t Cot[\[Theta]i/2] \
Tan[\[Theta]r/2] = (1-\[Beta]) / (1 + \[Beta])"], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["eq5 = Eliminate[eq3,{Cos[\[Theta]m],Sin[\[Theta]m]}]"], "Input"],

Cell["eq6 = eq5/.sol1//Simplify", "Input"],

Cell[TextData[
"sol2 = Solve[eq6,{Sin[\[Theta]i],Cos[\[Theta]r]}]//Flatten"], "Input"],

Cell[TextData[
"sol3 = (Solve[Cos[\[Theta]r] == (Cos[\[Theta]r]/.sol2),\[Beta]][[1]]\n\t\t\
//Simplify\n\t\t//PowerExpand\n\t\t//Simplify)"], "Input"],

Cell[TextData["temp=(1-\[Beta])/(1+\[Beta])"], "Input"],

Cell["temp==(temp/.sol3)//Simplify", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{762, 657},
WindowMargins->{{19, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 86, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2783, 98, 109, 1, 63, "Subsection"],
Cell[2895, 101, 653, 9, 90, "Text"],

Cell[CellGroupData[{
Cell[3573, 114, 199, 3, 76, "Subsubsection"],
Cell[3775, 119, 70, 0, 30, "Input"],
Cell[3848, 121, 70, 0, 30, "Input"],
Cell[3921, 123, 71, 0, 30, "Input"],
Cell[3995, 125, 71, 0, 30, "Input"],
Cell[4069, 127, 78, 0, 30, "Input"],
Cell[4150, 129, 32, 0, 30, "Input"],
Cell[4185, 131, 78, 0, 30, "Input"],
Cell[4266, 133, 32, 0, 30, "Input"],
Cell[4301, 135, 90, 1, 30, "Input"],
Cell[4394, 138, 112, 2, 30, "Input"],
Cell[4509, 142, 51, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4597, 147, 194, 3, 76, "Subsubsection"],
Cell[4794, 152, 79, 0, 30, "Input"],
Cell[4876, 154, 42, 0, 30, "Input"],
Cell[4921, 156, 86, 1, 30, "Input"],
Cell[5010, 159, 150, 2, 84, "Input"],
Cell[5163, 163, 55, 0, 30, "Input"],
Cell[5221, 165, 45, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

