(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5309,        191]*)
(*NotebookOutlinePosition[      6201,        221]*)
(*  CellTagsIndexPosition[      6157,        217]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.1  Special Relativity Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 6:  Two-dimensional motion of a relativistic particle in a uniform \
electric field.\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
A particle with mass m and charge e moves in a static uniform electric field \
E0.  The electric field is assumed to be along the y axis.  The equations of \
motion for the particle are: px'[t]=0, py'[t]=eE0, and pz'[t]=0, where \
{px,py,pz} is the three-space components of thw four-momentum vector.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a) Solve for the velocity and momentum of the particle as explicit \
functions of time.  Assume that the initial momentum is perpendicular to the \
electric field, {px[0]=px0, py[0]=0,  pz[0]=0}.  Find the non-relativistic \
limit.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["eqMotion = {px'[t]==0, py'[t]== e E0, pz'[t] == 0}", "Input"],

Cell["initial = {px[0]==p0x, py[0]== 0, pz[0] == 0}", "Input"],

Cell["\<\
momRule = DSolve[eqMotion~Join~initial,{px[t],py[t],pz[t]},t]//Flatten\
\>", "Input"],

Cell["pVec[t_] = {px[t],py[t],pz[t]}", "Input"],

Cell[TextData[
"eq1 = m \[Gamma] == Sqrt[pVec[t].pVec[t] + m^2 /.momRule]"], "Input"],

Cell[TextData["\[Gamma]Rule = Solve[eq1,\[Gamma]]//Flatten"], "Input"],

Cell[TextData[
"eq2 = (m \[Gamma] x'[t] == px[t])/.momRule/.\[Gamma]Rule"], "Input"],

Cell["\<\
xRule = DSolve[{eq2,x[0]==0},x[t],t]//Flatten//PowerExpand//ExpandAll\
\>", "Input"],

Cell[TextData[{
  "yEq = (m \[Gamma] y'[t] == py[t]) /.momRule",
  "/.\[Gamma]Rule"
}], "Input"],

Cell["yRule = DSolve[{yEq,y[0]==0},y[t],t]//Flatten", "Input"],

Cell["relXY = {x[t],y[t]} /.xRule/.yRule", "Input"],

Cell["\<\
nonRelXY = (Map[Series[#,{t,0,2}]&,relXY]/.{p0x^2->0})//PowerExpand//Normal\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)  Compare the plots for the nonrelativistic linit with the \
relativistic plots.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["values = {m->1, e->1, E0->0.1, p0x->0.1}", "Input"],

Cell["Clear[plotOp]", "Input"],

Cell["\<\
plotOp[eqs_List,axis_,tRange_] :=
Plot[eqs/.values//Evaluate
\t,{t,0,tRange}
\t,GridLines->Automatic
\t,AxesLabel->{\"t\",axis}
\t,PlotStyle->{{Thickness[0.01]}
\t\t\t\t,{Dashing[{0.06,0.1}],Thickness[0.001]}}
\t,DisplayFunction->Identity ];\
\>", "Input"],

Cell["\<\
Show[GraphicsArray[
\t{plotOp[{relXY[[1]],nonRelXY[[1]]},\"x\",30]
\t,plotOp[{relXY[[2]],nonRelXY[[2]]},\"y\",30]} ]];\
\>", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{671, 625},
WindowMargins->{{78, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 69, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 86, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2783, 98, 155, 4, 63, "Subsection"],
Cell[2941, 104, 324, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[3290, 113, 305, 6, 76, "Subsubsection"],
Cell[3598, 121, 67, 0, 30, "Input"],
Cell[3668, 123, 62, 0, 30, "Input"],
Cell[3733, 125, 95, 2, 30, "Input"],
Cell[3831, 129, 47, 0, 30, "Input"],
Cell[3881, 131, 85, 1, 30, "Input"],
Cell[3969, 134, 70, 0, 30, "Input"],
Cell[4042, 136, 84, 1, 30, "Input"],
Cell[4129, 139, 94, 2, 30, "Input"],
Cell[4226, 143, 96, 3, 30, "Input"],
Cell[4325, 148, 62, 0, 30, "Input"],
Cell[4390, 150, 51, 0, 30, "Input"],
Cell[4444, 152, 100, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4581, 159, 156, 4, 59, "Subsubsection"],
Cell[4740, 165, 57, 0, 30, "Input"],
Cell[4800, 167, 30, 0, 30, "Input"],
Cell[4833, 169, 266, 9, 156, "Input"],
Cell[5102, 180, 143, 4, 66, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

