(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4243,        151]*)
(*NotebookOutlinePosition[      5135,        181]*)
(*  CellTagsIndexPosition[      5091,        177]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.2  General Relativity and Cosmology Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 1:  Schwartzschild solution in null coordinates", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider a spherically symmetric metric expressed in null coordinates {u,r,\
\[Theta],\[Phi]}.  The metric is non-diagonal and is of the form:\n\t{{g00[r]\
\t-1\t 0\t 0\t\t}\n\t  {-1\t\t 0\t 0\t 0\t\t}\n\t  { 0\t\t 0\t-r^2\t 0\t\t}\n\
\t  { 0\t\t 0\t 0\t-r^2Sin[\[Theta]]^2\t}}  ."], "Text"],

Cell[CellGroupData[{

Cell["\<\
Part (a)  Find the solution of Einstein's vacuum equations with the boundary \
conditions that g00[r] -> (1 - 2m/r) as r goes to infinity.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  "varNull = ",
  "{u,r,\[Theta],\[Phi]}"
}], "Input"],

Cell[TextData[
"nullMet = {\t{g00[r],-1,0,0},\n\t  \t\t{-1,0,0,0},\n\t  \t\t{0,0,-r^2,0},\n\t\
  \t\t{0,0,0,-(r Sin[\[Theta]])^2} }"], "Input"],

Cell["nullChrist = christ[nullMet,varNull]", "Input"],

Cell["nullCur = curvR[nullChrist,varNull]//Simplify;", "Input"],

Cell["Short[nullCur,7]", "Input"],

Cell["nullRicci = ricciR[nullCur]//Simplify", "Input"],

Cell["\<\
vacuumEq =
\tSelect[(nullRicci//Flatten)==0//Thread,FreeQ[#,
\t\tTrue]&]//Together//Numerator\
\>", "Input"],

Cell["", "Input"],

Cell["nullRule = DSolve[vacuumEq[[4]],g00,r]//Flatten", "Input"],

Cell["vacuumEq/.nullRule", "Input"],

Cell["nullMet/.nullRule/.{C[1]->-2 m}", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{671, 625},
WindowMargins->{{78, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 69, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 100, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2797, 98, 110, 1, 63, "Subsection"],
Cell[2910, 101, 307, 4, 128, "Text"],

Cell[CellGroupData[{
Cell[3242, 109, 206, 4, 76, "Subsubsection"],
Cell[3451, 115, 70, 3, 30, "Input"],
Cell[3524, 120, 143, 2, 84, "Input"],
Cell[3670, 124, 53, 0, 30, "Input"],
Cell[3726, 126, 63, 0, 30, "Input"],
Cell[3792, 128, 33, 0, 30, "Input"],
Cell[3828, 130, 54, 0, 30, "Input"],
Cell[3885, 132, 118, 4, 66, "Input"],
Cell[4006, 138, 17, 0, 30, "Input"],
Cell[4026, 140, 64, 0, 30, "Input"],
Cell[4093, 142, 35, 0, 30, "Input"],
Cell[4131, 144, 48, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

