(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5707,        198]*)
(*NotebookOutlinePosition[      6599,        228]*)
(*  CellTagsIndexPosition[      6555,        224]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.2  General Relativity and Cosmology Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 3:  Killing vectors and constants of motion", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Consider the following problems for the Schwartzschild and Kerr metrics on \
killing vectors.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)  Consider the following four contravariant vectors:\n\t\tkt = \
{1,0,0,0}\n\t\tkz = {0,0,0,-1}\n\t\tkx = {0,0,-Sin[\[Phi]],-Cos[\[Phi]]Cot[\
\[Theta]]}\n\t\tky = {0,0,Cos[\[Phi]],-Sin[\[Phi]]Cot[\[Theta]]}\nVerify that \
they satisfy Killing's equations for the Schwartzschild metric."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["kt = {1,0,0,0}", "Input"],

Cell["kz = {0,0,0,-1}", "Input"],

Cell[TextData["kx = {0,0,-Sin[\[Phi]],-Cos[\[Phi]]Cot[\[Theta]]}"], "Input"],

Cell[TextData["ky = {0,0,Cos[\[Phi]],-Sin[\[Phi]]Cot[\[Theta]]}"], "Input"],

Cell["ke = killingEq[#,ssMet,ssChrist]&/@{kt,kz,ky,kx}", "Input"],

Cell["ke/.ssComp//Simplify", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  let V = {t'[s],r'[s],\[Theta]'[s],\[Phi]'[s]} be a geodesic \
four-vector velocity.  Constants of motion follow from equating the scalar \
dot product V.\[Eta].K to a constant, where K is a Killing vector and \[Eta] \
is the metric.  Express the components of the four-vector velocity V in terms \
of the killing constants."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[" velocity = {t'[s],r'[s],\[Theta]'[s],\[Phi]'[s]}"], "Input"],

Cell["\<\
kconst = {\ten == ssMet.velocity.kt,
\t\t\tjx == ssMet.velocity.kx,
\t\t\tjy == ssMet.velocity.ky,
\t\t\tjz == ssMet.velocity.kz};\
\>", "Input"],

Cell["kconst//ColumnForm", "Input"],

Cell["tRule = (Solve[kconst[[1]],t'[s]]//Flatten)/.ssComp", "Input"],

Cell[TextData[
"\[Phi]Rule = (Solve[kconst[[4]],\[Phi]'[s]]//Flatten)"], "Input"],

Cell[TextData[
"jRule = (Solve[kconst[[{2,3}]],{\[Phi]'[s],\[Theta]'[s]}]//Flatten)//\
Simplify"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)  Verify that the two contravariant vectors kt = {1,0,0,0} and kz = \
{0,0,0,-1} satisfy Killing's equations for the Kerr metric.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["kt = {1,0,0,0}", "Input"],

Cell["kz = {0,0,0,-1}", "Input"],

Cell["killingEq[#,kMet,kChrist]&/@{kt,kz}", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (d)  Express the two components of the four-velocity {t'[s],r'[s]} for \
the Kerr metric in terms of the Killing constants.  Write the explicit \
expressions when \[Theta]=\[Pi]/2."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
kconst = {\ten == kMet.velocity.kt,
\t\t\tjz == kMet.velocity.kz}\
\>", "Input"],

Cell[TextData[
"eq1 = Solve[kconst,{t'[s],\[Phi]'[s]}]//Flatten//Simplify"], "Input"],

Cell[TextData["(eq1/.kComp/.{\[Theta]->\[Pi]/2})//Simplify"], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{671, 625},
WindowMargins->{{78, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 100, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2797, 98, 106, 1, 63, "Subsection"],
Cell[2906, 101, 117, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[3048, 108, 367, 6, 144, "Subsubsection"],
Cell[3418, 116, 31, 0, 30, "Input"],
Cell[3452, 118, 32, 0, 30, "Input"],
Cell[3487, 120, 76, 0, 30, "Input"],
Cell[3566, 122, 75, 0, 30, "Input"],
Cell[3644, 124, 65, 0, 30, "Input"],
Cell[3712, 126, 37, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3786, 131, 404, 6, 93, "Subsubsection"],
Cell[4193, 139, 76, 0, 30, "Input"],
Cell[4272, 141, 155, 5, 84, "Input"],
Cell[4430, 148, 35, 0, 30, "Input"],
Cell[4468, 150, 68, 0, 30, "Input"],
Cell[4539, 152, 81, 1, 30, "Input"],
Cell[4623, 155, 107, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4767, 162, 205, 4, 76, "Subsubsection"],
Cell[4975, 168, 31, 0, 30, "Input"],
Cell[5009, 170, 32, 0, 30, "Input"],
Cell[5044, 172, 52, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5133, 177, 256, 4, 76, "Subsubsection"],
Cell[5392, 183, 90, 3, 48, "Input"],
Cell[5485, 188, 85, 1, 30, "Input"],
Cell[5573, 191, 70, 0, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

