(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7050,        211]*)
(*NotebookOutlinePosition[      7942,        241]*)
(*  CellTagsIndexPosition[      7898,        237]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.2  General Relativity and Cosmology Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 4:  Potential analysis for timelike geodesics.", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider the Schwartzschild metric and assume that the timelike geodesics \
are confined to the plane \[Theta]=\[Pi]/2.  Use the first two integrals that \
follow from Killing vectors: E = t'[s](1 - 2m/r) and \[ScriptL] = r^2 \
\[Phi]'[s]."], "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)  Consider the timelike condition 1 = v . \[Eta] . v , where v is \
the geodesic four-velocity and \[Eta] is the metric.  If the effective \
potential V is defined by the equation r'[s] == -(1 - E^2) -V, show that V = \
(-2\[ScriptL]^2 m)/r^3 + \[ScriptL]^2/r^2 - (2m)/r .  The first term is the \
relativistic correction, the second term is the centrifugal barrier, and the \
third term is the gravitational potential."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["planeRule = {\[Theta] -> ((\[Pi]/2)&)}"], "Input"],

Cell[TextData[
"SSconst = {t'[s] -> en/(1-2 m/r[s])\n\t\t  ,t''[s]-> D[en/(1-2 m/r[s]),s]\n\t\
\t  ,\[Phi]'[s] -> \[ScriptL]/r[s]^2\n\t\t  ,\[Phi]''[s]-> \
D[\[ScriptL]/r[s]^2,s]}"], "Input"],

Cell[TextData["vel = {t'[s],r'[s],\[Theta]'[s],\[Phi]'[s]}"], "Input"],

Cell[TextData[
"eq1 = 1 == \
((ssMet/.ssComp/.r->r[s]/.\[Theta]->\[Theta][s]).vel.vel)/.planeRule/.\
SSconst"], "Input"],

Cell["eq2 = r'[s]^2 == -(1-en^2)-V", "Input"],

Cell["\<\
eq3 = (Solve[{eq1,eq2},V,r'[s]][[1,1]])/.{r[s]->r}//ExpandAll\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  Show that the potential has two extrema if \[ScriptL]^2 > 12 m^2 \
."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["{rmax,rmin} = r/.Solve[D[V/.eq3,r]==0,r]//Simplify", "Input"],

Cell["\<\
{Vmax,Vmin} = {V/.eq3/.r->rmin,V/.eq3/.r->rmax}//Together//Simplify\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)  Graph the three parts of the effective potential for \[ScriptL]^2 \
> 12 m^2 .  Also, graph the effective potential for the three cases: \
\[ScriptL]^2 > 12 m^2, \[ScriptL]^2 = 12 m^2 .\[ScriptL]^2 < 12 m^2 ."], 
  "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["list = {eq3[[2]],List @@ eq3[[2]]}//Flatten", "Input"],

Cell[TextData[
"potPlot[L_] :=\n\tPlot[list//.{m->1,\[ScriptL]->L}//Evaluate\n\t\t\
,{r,2.1,50}\n\t\t,Prolog->Graphics[{PointSize[0.02]\n\t\t\t\
,Map[Point,{{rmax,Vmin},{rmin,Vmax}}\n\t\t\t]/.m->1/.\[ScriptL]->(1.3 \
Sqrt[12])}][[1]]\n\t\t,Axes->False\n\t\t,Frame->True\n\t\t,PlotLabel-> \
eq3[[2]]\n\t\t\
,FrameLabel->{\"Radius\",\"Potential\",\"Radius\",\"Potential\"}\n\t\t\
,FrameTicks->Automatic\n\t\t,PlotStyle->{Thickness[0.006]\n\t\t\t\t\t\
,Dashing[{0.01}]\n\t\t\t\t\t,Dashing[{0.02}]\n\t\t\t\t\t,Dashing[{0.03}]\t}\n\
\t\t,DisplayFunction->Identity];"], "Input"],

Cell["\<\
label =
\tGraphics[
\t\t{Text[FontForm[\" Unstable \",{\"Times-Roman\",10}],{4,.16}]
\t\t,Text[FontForm[\" Stable   \",{\"Times-Roman\",10}],{17,-.08}]\t\t\t\
,Text[FontForm[  eq3[[2,2]],{\"Times-Roman\",10}],{36,-.1}]\t\t\t\
,Text[FontForm[  eq3[[2,3]],{\"Times-Roman\",10}],{20,.11}]\t\t\t\
,Text[FontForm[  eq3[[2,1]],{\"Times-Roman\",10}],{14,.03}]
\t\t}];\
\>", "Input"],

Cell["\<\
Show[potPlot[1.3 Sqrt[12]],label
\t\t\t,PlotRange->{0.2,-0.2}
\t\t\t,DisplayFunction->$DisplayFunction];\
\>", "Input"],

Cell[TextData[
"\tPlot[Evaluate[(eq3[[2]]/.m->1/.\n\t\t\[ScriptL]->{.9 Sqrt[12],Sqrt[12],1.1 \
Sqrt[12]})]\n\t\t,{r,2.1,15}\n\t\t,Axes->False\n\t\t,Frame->True\n\t\t\
,PlotLabel->\"Potential with Different \[ScriptL]\"\n\t\t\
,FrameLabel->{\"Radius\",\"Potential\",\"Radius\",\"Potential\"}\n\t\t\
,FrameTicks->Automatic\n\t\t,PlotStyle->{Thickness[0.006]\n\t\t\t\t\t\
,Dashing[{0.01}]\n\t\t\t\t\t,Dashing[{0.02}]\n\t\t\t\t\t,Dashing[{0.03}]\t}\n\
\t\t,PlotRange->{0,-0.2}\n\t\t,Epilog->Graphics[\n\t\t\t{Text[FontForm[\
\[ScriptL]^2 > 12m^2//StandardForm,{\"Times-Roman\",10}]\n\t\t\t\t\t\t\
,{4.5,-0.03}]\n\t\t\t,Text[FontForm[\[ScriptL]^2 == \
12m^2//StandardForm,{\"Times-Roman\",10}]\n\t\t\t\t\t\t,{7,-0.095}]\n\t\t\t\
,Text[FontForm[\[ScriptL]^2 < 12m^2//StandardForm,{\"Times-Roman\",10}]\n\t\t\
\t\t\t\t,{11,-0.14}]}][[1]]];\n\t\t\t"], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{591, 545},
WindowMargins->{{78, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 100, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2797, 98, 109, 1, 63, "Subsection"],
Cell[2909, 101, 266, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[3200, 109, 498, 7, 110, "Subsubsection"],
Cell[3701, 118, 65, 0, 30, "Input"],
Cell[3769, 120, 191, 3, 84, "Input"],
Cell[3963, 125, 70, 0, 30, "Input"],
Cell[4036, 127, 120, 3, 48, "Input"],
Cell[4159, 132, 45, 0, 30, "Input"],
Cell[4207, 134, 86, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4330, 141, 149, 3, 59, "Subsubsection"],
Cell[4482, 146, 67, 0, 30, "Input"],
Cell[4552, 148, 92, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4681, 155, 292, 5, 76, "Subsubsection"],
Cell[4976, 162, 60, 0, 30, "Input"],
Cell[5039, 164, 572, 9, 300, "Input"],
Cell[5614, 175, 385, 9, 156, "Input"],
Cell[6002, 186, 129, 4, 66, "Input"],
Cell[6134, 192, 852, 12, 444, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

