(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7890,        295]*)
(*NotebookOutlinePosition[      8783,        325]*)
(*  CellTagsIndexPosition[      8739,        321]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell[CellGroupData[{

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Null\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.2  General Relativity and Cosmology Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 5:  Time It Takes to Fall into a Black Hole    ", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell["\<\
Consider the Schwartzschild geodesics.  Assume that the geodesic \
four-velocity is given by v = {t'[s],r'[s],0,0}, where E = t'[s](1 - 2m/r).  \
Let the initial conditions be r'[0]=0 and r[0]=r0.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)  Derive an equation for r'[s] from the timelike condition 1 = v . \
\[Eta] . v  ."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
construle = {t'[s] -> en/(1 - (2*m)/r[s]), 
\t\t\t t''[s] -> D[en/(1 - (2*m)/r[s]), s]}; \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
m/:Sign[m]=1;
en/:Sign[en]=1;\
\>", "Input"],

Cell["\<\
vel = {t'[s],r'[s], 0, 0}; 
met = ssMet /. ssComp /. r -> r[s]; \
\>", "Input",
  AspectRatioFixed->True],

Cell["eq1 = 1 == met . vel . vel /. construle//Simplify", "Input",
  AspectRatioFixed->True],

Cell["\<\
eq2 = Solve[eq1,r'[s]][[1,1]] /.{Rule -> Equal}//PowerExpand//Simplify\
\>", "Input",
  AspectRatioFixed->True],

Cell["eq3 = 0 == eq2[[2]] /. s -> 0 /. r[0] -> r0", "Input",
  AspectRatioFixed->True],

Cell["\<\
rprimerule = PowerExpand[MapAt[Factor, 
    Solve[{eq2, eq3}, {r'[s], en}][[2]], {1, 2, 2, 1}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
radialEq = rprimerule[[1]] /. Rule -> Equal//ExpandAll//PowerExpand\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)  Verify from the user-defined function geodesic that \
{t'[s],r'[s],0,0} satisfies the geodesic equations, where t'[s] is given by \
the first integral and r'[s] is given by the timelike condition derived in \
Part (a).\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["geovel = vel /. (radialEq /. Equal -> Rule) /. construle", "Input",
  AspectRatioFixed->True],

Cell["metric = ssMet /. ssComp", "Input",
  AspectRatioFixed->True],

Cell[TextData["geoEq = geodesic[metric, {t, r, \[Theta], \[Phi]}];"], "Input",
  AspectRatioFixed->True],

Cell["Short[geoEq,4]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"eq4 = Simplify[geoEq /. {\[Phi] -> (\[Phi]0 & ), \[Theta] -> (\[Theta]0 & \
)}]"], "Input",
  AspectRatioFixed->True],

Cell["\<\
Simplify[eq4 /. 
     Derivative[2][r][s] -> D[Derivative[1][r][s]
     /. rprimerule, s] /.construle /. rprimerule]\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (c)  Derive an expression for the proper time as a function of the \
radial  position.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["rchange = r -> (r0*Cos[x[#1]]^2 & )", "Input",
  AspectRatioFixed->True],

Cell["r0/:Sign[r0]=1", "Input"],

Cell["radialEq2 = radialEq /.rchange//PowerExpand//Simplify", "Input",
  AspectRatioFixed->True],

Cell["\<\
eq5 = PowerExpand[Simplify[Solve[radialEq2,x'[s]][[1,1]]]]//Simplify\
\>", "Input",
  AspectRatioFixed->True],

Cell["Stimex = Simplify[Integrate[1/x'[s] /. eq5, {x[s], 0, x}]]", "Input",
  AspectRatioFixed->True],

Cell["\<\
xrule = Solve[r == (r[s] /. rchange), x[s]][[4]] /. x[s] -> x\
\>", "Input",
  AspectRatioFixed->True],

Cell["Stime = Stimex /. xrule", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (d)  Derive an expression for the coordinate time as a function of the \
radial  position.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["\<\
eq6 = Simplify[PowerExpand[ExpandAll[-(t'[s]/
           r'[s]) /. construle /. rprimerule /. r[s] -> r[t]]]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["eq7 = Integrate[eq6, r[t]]//ExpandAll//PowerExpand//Simplify", "Input",
  AspectRatioFixed->True],

Cell["\<\
r0lim = (Limit[eq7,r[t] -> r0]) //ExpandAll//PowerExpand//Simplify\
\>", "Input"],

Cell["Ttime = (r0lim - (eq7 /. r[t] -> r))//Simplify//PowerExpand", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (e)  Plot the proper and coordinate times as a function of r.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["value = {m -> 1, r0 -> 8}; ", "Input",
  AspectRatioFixed->True],

Cell["\<\
pt1 = Plot[Evaluate[(Chop[#1, 1/10^5] & )[Ttime /. value]], 
    {r, 2.008999999999999, 7.99}
    ,DisplayFunction -> Identity]; \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
pt2 = Plot[Evaluate[Stime /. value], {r, 0, 8}
\t\t\t, DisplayFunction -> Identity]; \
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
Show[{pt1, pt2, Graphics[{Line[{{2, 0}, {2, 40}}], 
      Text[FontForm[\"Proper Time\", {\"Times-Roman\", 10}], 
       {1.199999999999999, 22}], 
      Text[FontForm[\"Coordinate Time\", {\"Times-Roman\", 10}], {4.5, 30}], 
      Text[FontForm[\"r=2 m \", {\"Times-Roman\", 10}], {2.6, 10}]}]}, 
   AxesLabel -> {\"Distance\", \"Time\"}, DisplayFunction -> \
$DisplayFunction, 
   PlotRange -> {0, 40}]; \
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{714, 572},
WindowMargins->{{Automatic, 148}, {Automatic, 84}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],

Cell[CellGroupData[{
Cell[1890, 58, 132, 3, 43, "Subsubsection",
  Evaluatable->False],
Cell[2025, 63, 85, 3, 30, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[2147, 71, 58, 1, 69, "Subtitle"],
Cell[2208, 74, 108, 2, 70, "Input"],
Cell[2319, 78, 96, 2, 30, "Input"],
Cell[2418, 82, 93, 2, 30, "Input"],
Cell[2514, 86, 90, 2, 30, "Input"],
Cell[2607, 90, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2704, 96, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2794, 101, 100, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2919, 106, 110, 1, 63, "Subsection"],
Cell[3032, 109, 220, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[3277, 117, 161, 3, 59, "Subsubsection"],
Cell[3441, 122, 140, 4, 48, "Input"],
Cell[3584, 128, 54, 3, 48, "Input"],
Cell[3641, 133, 115, 4, 48, "Input"],
Cell[3759, 139, 92, 1, 30, "Input"],
Cell[3854, 142, 121, 3, 30, "Input"],
Cell[3978, 147, 86, 1, 30, "Input"],
Cell[4067, 150, 146, 4, 48, "Input"],
Cell[4216, 156, 118, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4371, 164, 296, 6, 76, "Subsubsection"],
Cell[4670, 172, 99, 1, 30, "Input"],
Cell[4772, 175, 67, 1, 30, "Input"],
Cell[4842, 178, 104, 1, 30, "Input"],
Cell[4949, 181, 57, 1, 30, "Input"],
Cell[5009, 184, 133, 3, 30, "Input"],
Cell[5145, 189, 167, 5, 66, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5349, 199, 159, 4, 59, "Subsubsection"],
Cell[5511, 205, 78, 1, 30, "Input"],
Cell[5592, 208, 31, 0, 30, "Input"],
Cell[5626, 210, 96, 1, 30, "Input"],
Cell[5725, 213, 119, 3, 30, "Input"],
Cell[5847, 218, 101, 1, 30, "Input"],
Cell[5951, 221, 112, 3, 30, "Input"],
Cell[6066, 226, 66, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6169, 232, 163, 4, 59, "Subsubsection"],
Cell[6335, 238, 160, 4, 48, "Input"],
Cell[6498, 244, 103, 1, 30, "Input"],
Cell[6604, 247, 91, 2, 30, "Input"],
Cell[6698, 251, 102, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6837, 257, 134, 3, 59, "Subsubsection"],
Cell[6974, 262, 70, 1, 30, "Input"],
Cell[7047, 265, 180, 5, 66, "Input"],
Cell[7230, 272, 136, 4, 48, "Input"],
Cell[7369, 278, 457, 10, 138, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

