(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4893,        170]*)
(*NotebookOutlinePosition[      5785,        200]*)
(*  CellTagsIndexPosition[      5741,        196]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.2  General Relativity and Cosmology Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 6:  Circular geodesics for the Schwartzschild metric.\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[
"Consider the timelike circular geodesics for the Schwartzschild metric with \
four-velocity given by v = {t'[s],r'[s],\[Theta]'[s],\[Phi]'[s]}.  Assume \
that the geodesics are in the plane \[Theta][s] = \[Pi]/2 and that the radius \
is a constant with r[s] = r0."], "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)  Solve for t[s] and \[Phi][s] with the initial conditions that \
t[0[=0 and \[Phi][0]=0."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData["circleRule = {r->(((r0))&),\[Theta]->(((\[Pi]/2))&)}"], "Input"],

Cell[TextData[
"eq1 = (geodesic[ssMet/.ssComp,{t,r,\[Theta],\[Phi]}]/.circleRule)//Simplify"]\
, "Input"],

Cell["tRule = DSolve[{eq1[[1]],t[0]==0},{t},s]/.C[2]->c1", "Input"],

Cell[TextData[
"\[Phi]Rule = DSolve[{eq1[[4]],\[Phi][0]==0},{\[Phi]},s]/.C[2]->c2"], "Input"],

Cell[TextData["eq2 = eq1[[2]]/.tRule/.\[Phi]Rule//Flatten"], "Input"],

Cell[TextData["vel = {t'[s],r'[s],\[Theta]'[s],\[Phi]'[s]}"], "Input"],

Cell[TextData[
"met = (ssMet/.ssComp/.{\[Theta]->\[Theta][s],r->r[s]})"], "Input"],

Cell[TextData[
"eq3 = 1 == vel.met.vel/.circleRule/.tRule/.\[Phi]Rule//Flatten"], "Input"],

Cell["\<\
constRule = ((Solve[{eq3,eq2}/.m->temp r0//Flatten,
\t\t\t\t\t{c1,c2}][[4]]//ExpandAll)/.
\t\t\t\t\ttemp->m/r0//PowerExpand)/.
\t\t\t\t\t1/Sqrt[a_] -> -I/Sqrt[-a]\
\>", "Input"],

Cell["eq4 = CoordT == (t[s]/.tRule/.constRule)[[1]]", "Input"],

Cell[TextData[
"eq5 = \[CapitalPhi] == (\[Phi][s]/.\[Phi]Rule/.constRule)[[1]]"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Part (b)  Find the coordinate and proper periods for the circular orbit.\
\>", "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"coordPeriod = \
CoordT/.Solve[{eq4,eq5},CoordT,s][[1]]/.\[CapitalPhi]->2\[Pi]"], "Input"],

Cell[TextData[
"properPeriod = \
MapAt[Apart,s/.Solve[eq5,s][[1]]/.\[CapitalPhi]->2\[Pi],{5,1}]"], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{607, 561},
WindowMargins->{{78, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 100, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2797, 98, 124, 3, 63, "Subsection"],
Cell[2924, 103, 290, 4, 71, "Text"],

Cell[CellGroupData[{
Cell[3239, 111, 168, 3, 59, "Subsubsection"],
Cell[3410, 116, 79, 0, 30, "Input"],
Cell[3492, 118, 105, 2, 30, "Input"],
Cell[3600, 122, 67, 0, 30, "Input"],
Cell[3670, 124, 93, 1, 30, "Input"],
Cell[3766, 127, 69, 0, 30, "Input"],
Cell[3838, 129, 70, 0, 30, "Input"],
Cell[3911, 131, 82, 1, 30, "Input"],
Cell[3996, 134, 90, 1, 30, "Input"],
Cell[4089, 137, 187, 5, 84, "Input"],
Cell[4279, 144, 62, 0, 30, "Input"],
Cell[4344, 146, 90, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4471, 152, 140, 3, 59, "Subsubsection"],
Cell[4614, 157, 105, 2, 30, "Input"],
Cell[4722, 161, 107, 2, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

