(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8066,        278]*)
(*NotebookOutlinePosition[      8958,        308]*)
(*  CellTagsIndexPosition[      8914,        304]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.2  General Relativity and Cosmology Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 7:  Field Equations for Robertson-Walker cosmology", 
  "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "Consider the Robertson-Walker metric defined by the diagonal matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\_RW\)]],
  " = DiagonalMatrix[{1, -",
  Cell[BoxData[
      \(TraditionalForm\`R[t]\^2\)]],
  "/(1-",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\_RW\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  "), -",
  Cell[BoxData[
      \(TraditionalForm\`R[t]\^2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ", -",
  Cell[BoxData[
      \(TraditionalForm\`R[t]\^2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  " Sin[\[Theta]]^2}].  Assume the model is defined by the covariant \
energy-momentum tensor ",
  Cell[BoxData[
      \(TraditionalForm\`T\^ij\)]],
  " = (\[Rho] + P)",
  Cell[BoxData[
      \(TraditionalForm\`V\^i\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`V\^j\)]],
  " - ",
  Cell[BoxData[
      \(TraditionalForm\`g\^ij\)]],
  "(P) where ",
  Cell[BoxData[
      \(TraditionalForm\`V\^i\)]],
  " = {1,0,0,0}."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (a)  From Einstein's equation with a cosmological constant \[Lambda], \
show that R[t] obeys the following two equations:\n                    ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["R", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}], "==", 
        \(1\/3\ R[t]\ 
          \((\[Lambda] - 12\ G\ \[Pi]\ P[t] - 4\ G\ \[Pi]\ \[Rho][t])
            \)\)}]]],
  "\n                    ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"], "==", 
        \(1\/3\ \((
            \(-3\)\ \[Kappa]RW + 
              R[t]\^2\ \((\[Lambda] + 8\ G\ \[Pi]\ \[Rho][t])\))\)\)}]]]
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"RWmet = \n  DiagonalMatrix[{1, -(R[t]^2/(1 - \[Kappa]RW r^2)), \n    \
-(R[t]^2 r^2), -(R[t]^2 r^2 Sin[\[Theta]]^2)}]"], "Input"],

Cell["RWchrist = christ[RWmet]", "Input"],

Cell["RWcurve = curvR[RWchrist]//Simplify;  Short[RWcurve,12]", "Input"],

Cell["einsteinT = einstein[RWcurve,RWmet]", "Input"],

Cell["vel = {1,0,0,0}\t(* Contravariant four-velocity *)", "Input"],

Cell["covel = RWmet.vel\t(* Contravariant four-velocity *)", "Input"],

Cell[TextData[
"T = Table[\n\t(\[Rho][t] + press[t])covel[[i]]covel[[j]]-\n\t\t\t\
RWmet[[i,j]]press[t],\n\t\t\t{i,4},{j,4}]"], "Input"],

Cell[TextData[
"eq1 = Map[Flatten,einsteinT == - 8 \[Pi] G T - \[Lambda] RWmet]//\n\t\
Thread//Select[#1,FreeQ[#,True]&]&//Simplify"], "Input"],

Cell["\<\
fieldEq = (Solve[eq1/.R'[t]->Sqrt[x],{R''[t],x}][[1]]/.
\tx->R'[t]^2//Simplify)/.Rule->Equal\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)  Assume that the pressure P[t] and density \[Rho][t] are related \
by the equation of state P[t] = \[Alpha] \[Rho][t].  Show from conservation \
of energy-momentum ",
  Cell[BoxData[
      \(TraditionalForm\`T\_ij\%ij\)]],
  " = 0 that:\n                           ",
  Cell[BoxData[
      \(\[Rho][t] = \ \[Rho][0] \((R0/R[t])\)\^\(3\ \((1 + \[Alpha])\)\)\)]]
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"conT = Table[(\[Rho][t] + press[t])vel[[i]]vel[[j]]-\n\t\t\t\
Inverse[RWmet][[i,j]]press[t],\n\t\t\t{i,4},{j,4}]//Simplify"], "Input"],

Cell[TextData[
"dconT[conT_,christ_,var_:{t,r,\[Theta],\[Phi]}] :=\n\tSimplify[Expand[Table[\
\n\t\tD[conT[[i,j]],var[[k]] ]+\n\t\t\tSum[christ[[i,s,k]]conT[[s,j]]+\n\t\t\t\
\tchrist[[j,s,k]]conT[[i,s]],\n\t\t\t\t\t{s,4}],{i,4},{j,4},{k,4}] ]]\n\t\t\t\
"], "Input"],

Cell["eq2 = dconT[conT,RWchrist]", "Input"],

Cell["eq3 = Table[Sum[eq2[[i,s,s]],{s,1,4}],{i,1,4}]", "Input"],

Cell["eq4 = eq3[[1]]==0", "Input"],

Cell[TextData["eqState = {press[t] -> \[Alpha] \[Rho][t]}"], "Input"],

Cell["\<\
eq5 = (DSolve[{eq4/.eqState,R[0]==R0},R[t],t][[1,1]]//Simplify)/.
\tRule->Equal//PowerExpand\
\>", "Input"],

Cell[TextData[{
  "\[Rho]Rule = Solve[eq5/.\[Rho][t]->x,x]",
  "[[1,1]]/.x->\[Rho][t]//PowerExpand//Simplify"
}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (c)  Let \[Alpha] = 0 and show that the rquations for ",
  Cell[BoxData[
      \(TraditionalForm\`\(R'\)[t]\^2\)]],
  " and R''[t] can be written:\n\t\t",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["R", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}], "==", 
        \(1\/3\ R[t] \[Lambda] - 
          4\/3\ \ G\ \[Pi]\ R\_0\^3\ \[Rho][t]/R[t]\^2\)}]]],
  "\n\t\t",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"], "==", " ", 
        \(\(-\[Kappa]RW\) + \(1\/3\) \[Lambda]\ R[t]\^2 + 
          8\/3\ G\ \[Pi]\ R\_0\^3\ \[Rho][0]/R[t]\)}]]]
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"eq7 = fieldEq/.\[Rho]Rule/.eqState/.\[Alpha]->0//ExpandAll//Simplify"], 
  "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{591, 545},
WindowMargins->{{78, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 100, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2797, 98, 116, 2, 63, "Subsection"],
Cell[2916, 102, 1036, 42, 71, "Text"],

Cell[CellGroupData[{
Cell[3977, 148, 841, 22, 118, "Subsubsection"],
Cell[4821, 172, 145, 2, 66, "Input"],
Cell[4969, 176, 41, 0, 30, "Input"],
Cell[5013, 178, 72, 0, 30, "Input"],
Cell[5088, 180, 52, 0, 30, "Input"],
Cell[5143, 182, 67, 0, 30, "Input"],
Cell[5213, 184, 69, 0, 30, "Input"],
Cell[5285, 186, 136, 2, 84, "Input"],
Cell[5424, 190, 143, 2, 48, "Input"],
Cell[5570, 194, 117, 3, 48, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5724, 202, 444, 10, 96, "Subsubsection"],
Cell[6171, 214, 150, 2, 66, "Input"],
Cell[6324, 218, 265, 4, 138, "Input"],
Cell[6592, 224, 43, 0, 30, "Input"],
Cell[6638, 226, 63, 0, 30, "Input"],
Cell[6704, 228, 34, 0, 30, "Input"],
Cell[6741, 230, 69, 0, 30, "Input"],
Cell[6813, 232, 117, 3, 48, "Input"],
Cell[6933, 237, 122, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7092, 245, 808, 22, 101, "Subsubsection"],
Cell[7903, 269, 99, 2, 30, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

