(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8031,        270]*)
(*NotebookOutlinePosition[      8924,        300]*)
(*  CellTagsIndexPosition[      8880,        296]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.2  General Relativity and Cosmology Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["Problem 8:  Zero-pressure cosmological models", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "The equations for the zero-pressure Robertson-Walker models can be written \
as:\n\t\t ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          SuperscriptBox["R", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}], "==", 
        \(1\/3\ R[t] \[Lambda] - 
          4\/3\ \ G\ \[Pi]\ R\_0\^3\ \[Rho][t]/R[t]\^2\)}]], "Input",
    FontWeight->"Plain"],
  "\n\tor\n\t\t",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox[
          RowBox[{
            SuperscriptBox["R", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"], "==", " ", 
        \(\(-\[Kappa]RW\) + \(1\/3\) \[Lambda]\ R[t]\^2 + 
          8\/3\ G\ \[Pi]\ R\_0\^3\ \[Rho][0]/R[t]\)}]], "Input",
    FontWeight->"Plain"],
  "\nParameters directly related to observation are:\n\t1.  The Hubble \
expansion rate ",
  Cell[BoxData[
      \(TraditionalForm\`H\_0\)]],
  " = R'[0]/R[0] ;\n\t2.  The dimensionless deceleration parameter ",
  Cell[BoxData[
      \(TraditionalForm\`q\_0\)]],
  " = -R''[0]/ (",
  Cell[BoxData[
      \(TraditionalForm\`H\_0\^2\)]],
  " R[0]) ;\n\t3.  The dimensionless density parameter \[Sigma] = 4 G \[Pi] \
\[Rho][0] /  (3 ",
  Cell[BoxData[
      \(TraditionalForm\`H\_0\^2\)]],
  ") ; and\n\t4.  The dimensionless cosmological parameter L = \[Lambda] / (3 \
",
  Cell[BoxData[
      \(TraditionalForm\`H\_0\^2\)]],
  ") ."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (a)  Show that ",
  Cell[BoxData[
      \(TraditionalForm\`q\_0\)], "Input"],
  " and ",
  Cell[BoxData[
      \(\[Kappa]\_RW\)], "Input"],
  " satisfy the following equations:\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`q\_0\)], "Input"],
  " = - L + \[Sigma]\n\t\t",
  Cell[BoxData[
      \(\[Kappa]\_RW\)], "Input"],
  " =  -",
  Cell[BoxData[
      \(TraditionalForm\`H\_0\)]],
  " R[0] (1 - L - 2\[Sigma])"
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"eq1 = R''[t] == (\[Lambda] R[t])/3 - (4 G \[Pi] R[0]^3 \[Rho][0])/(3 \
R[t]^2)"], "Input"],

Cell[TextData[
"eq2 = R'[t]^2 == -\[Kappa]RW + (\[Lambda] R[t]^2)/3 + (8 G \[Pi] R[0]^3 \
\[Rho][0])/(3 R[t])"], "Input"],

Cell[TextData[
"parameterRule = {R'[0] -> Ho R[0]\n\t\t\t\t,R''[0]-> - Ho^2 qo R[0]\n\t\t\t\t\
,\[Rho][0] -> 3 Ho^2 \[Sigma]/(4 G \[Pi])\n\t\t\t\t,\[Lambda] -> 3 L Ho^2 }"],
   "Input"],

Cell[TextData[
"qRule = Solve[{eq1,eq2}/.t->0/.parameterRule,{qo,\[Kappa]RW}]//Flatten//\
Simplify"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (b)  Derive an analytical expression for the cosmological age of the \
universe as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`q\_0\)], "Input"],
  " when the cosmological parameter L is zero.  Plot the results."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["change = {R'[t]->X'[t] R[0], R[t]->X[t] R[0]}", "Input"],

Cell["\<\
eq4 = (eq2/.parameterRule/.qRule/.change//Solve[#,X'[t]]&)[[2]]\
\>", "Input"],

Cell[TextData[
"integrand = (1/X'[t]/.eq4/.{L->0,Ho->1,\[Sigma]->qo}//Together)"], "Input"],

Cell["??Integrate", "Input"],

Cell["\<\
age0 = Integrate[integrand,{X[t],0,1},GenerateConditions -> \
False]//PowerExpand//Simplify\
\>", "Input"],

Cell["Re[Evaluate[age0/. qo->.5001]]", "Input"],

Cell["\<\
label = Graphics[
\t{PointSize[.03],Point[{.5,Re[Evaluate[age0/. qo->.500001]]}]
\t,Text[FontForm[\"k=0 Flat\",{\"Times-Roman\",10}],{.77,.67}]
\t,Text[FontForm[\"k=1 Closed\",{\"Times-Roman\",10}],{1.4,.58}]
\t,Text[FontForm[\"k=-1 Open\",{\"Times-Roman\",10}],{.44,.82}]}];\
\>", "Input"],

Cell["\<\
agePlot[Ho_] := Plot[age0,{qo,.00001,2}
\t\t\t\t,Frame->True
\t\t\t\t,PlotLabel->\"Age for zero cosmological constant\"
\t\t\t\t,FrameLabel->{\"10^-29 gm/cc\",\"Age\"
\t\t\t\t\t,\"Density\",\"Billion Years\"}
\t\t\t\t,FrameTicks->
\t\t\t\t\t{ {0,{1/2, .000196 Ho^2}
\t\t\t\t\t    ,{1,2*.000196 Ho^2},{1.5,3*.000196 Ho^2}}
\t\t\t\t\t,{ {.5,.5*9.78*(100/Ho)},{.6,.6*9.78*(100/Ho)}
\t\t\t\t\t  ,{.7,.7*9.78*(100/Ho)},{.8,.8*9.78*(100/Ho)}
\t\t\t\t\t  ,{.9,.9*9.78*(100/Ho)},{1,1*9.78*(100/Ho)}}}
\t\t\t\t,GridLines->Automatic
\t\t\t\t,Epilog->label[[1]]\t]\
\>", "Input"],

Cell["agePlot[50];", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Part (c)  Consider models with a non-zero cosmological parameter and make \
a table of ages for different values of \[Sigma] and ",
  Cell[BoxData[
      \(TraditionalForm\`q\_0\)], "Input"],
  "."
}], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell[TextData[
"ageL[q_,dimmass_] := NIntegrate[(1/X'[t]/.eq4/.\n\t\t\
{Ho->1}/.{L->dimmass-q}/.{qo->q}/.\n\t\t\
{\[Sigma]->dimmass}/.{X[t]->x}),{x,0,1}]//N[#,4]&"], "Input"],

Cell[TextData[
"ageTable[Ho_] := Table[N[ 9.78*(100/Ho) ageL[q,\[Sigma]],3],\n\t\t\t\t\t\t\t\
{q,0,2,.5},{\[Sigma],0,2.5,.5}]"], "Input"],

Cell[TextData[
"TableForm[ageTable[50],TableSpacing->{0,3,3}\n\t\t,TableHeadings->{{\"qo=0.0\
\",\"qo=0.5\",\"qo=1.0\",\"qo=1.5\",\"qo=2.0\"}\n\t\t\t\t\
,{\"\[Sigma]=0.0\",\"\[Sigma]=0.5\",\"\[Sigma]=1.0\",\"\[Sigma]=1.5\",\"\
\[Sigma]=2.0\",\"\[Sigma]=2.5\"}}]"], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{667, 529},
WindowMargins->{{Automatic, 126}, {Automatic, 19}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 100, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2797, 98, 100, 1, 63, "Subsection"],
Cell[2900, 101, 1401, 40, 191, "Text"],

Cell[CellGroupData[{
Cell[4326, 145, 496, 18, 93, "Subsubsection"],
Cell[4825, 165, 106, 2, 30, "Input"],
Cell[4934, 169, 121, 2, 30, "Input"],
Cell[5058, 173, 185, 3, 84, "Input"],
Cell[5246, 178, 110, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5393, 185, 306, 7, 76, "Subsubsection"],
Cell[5702, 194, 62, 0, 30, "Input"],
Cell[5767, 196, 88, 2, 30, "Input"],
Cell[5858, 200, 91, 1, 30, "Input"],
Cell[5952, 203, 28, 0, 30, "Input"],
Cell[5983, 205, 116, 3, 48, "Input"],
Cell[6102, 210, 47, 0, 30, "Input"],
Cell[6152, 212, 300, 6, 102, "Input"],
Cell[6455, 220, 578, 14, 246, "Input"],
Cell[7036, 236, 29, 0, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7102, 241, 272, 7, 76, "Subsubsection"],
Cell[7377, 250, 174, 3, 66, "Input"],
Cell[7554, 255, 137, 2, 48, "Input"],
Cell[7694, 259, 273, 4, 66, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

