(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7605,        254]*)
(*NotebookOutlinePosition[      8497,        284]*)
(*  CellTagsIndexPosition[      8453,        280]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Relativity and Cosmology", "Title",
  TextAlignment->-0.5,
  FontColor->RGBColor[1, 1, 0],
  Background->GrayLevel[0.500008]],

Cell["Legal Notice, Disclaimer, and Book Ordering Information:", 
  "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Setup", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[BoxData[
    \(Clear["\<Global`*\>"]; \nOff[General::spell]; \nOff[General::spell1]; 
    \)], "Input"],

Cell[BoxData[
    \(Needs["\<Calculus`VectorAnalysis`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Graphics`PlotField3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(<< "\<D:\Mma\Inits\ch7init.m\>"\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Clear["\<Global`*\>"]; \)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.2 Problems", "Subtitle",
  Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["7.2.2  General Relativity and Cosmology Problems", "Section",
  Background->RGBColor[0, 1, 0]],

Cell[CellGroupData[{

Cell["\<\
Problem 9:  The expansion and age of the universe in the Standard Model\
\>", "Subsection",
  Background->RGBColor[1, 1, 0]],

Cell[TextData[{
  "The standard cosmological models are Robertson-Walker models with zero \
pressure and a zero cosmological parameter.  The scale factor obeys the \
equation R'[t]^2 = - \[Kappa]RW + 2 qo Ho^2 R[0]^3/R[t] , where R[0] = (1/Ho) \
Sqrt[\[Kappa]RW/(2 qo - 1)] for \[Kappa]RW",
  StyleBox[" \[NotEqual] ",
    FontFamily->"Symbol"],
  " 0."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[
"Part (a)  Find the solutions for R[t] and age for the model when \[Kappa]RW \
= 0  (flat).  Graph the results."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["eq1 = R'[t]^2 == Ho^2 R[0]^3/R[t]", "Input"],

Cell["eq2 = t == Integrate[Sqrt[1/eq1[[2]]],R[t]]//PowerExpand", "Input"],

Cell["age0 = eq2[[2]]/.R[t]->R[0]", "Input"],

Cell["scale0 = Solve[eq2,R[t]][[2,1]]/.Rule->Equal", "Input"],

Cell["\<\
Plot[Evaluate[scale0[[2]]/.{Ho->1,R[0]->1}],{t,0,1}
\t\t,Frame->True
\t\t,PlotLabel-> scale0
\t\t,FrameLabel->{\"Time (Hubble units)\",\"R[t}\",\" \",\" \"}
\t\t,FrameTicks->{{{0,\"Big Bang\"},{1/3,\"1/(3Ho)\"}
\t\t\t\t\t  ,{2/3,\"Now\"},{1,\"1/Ho\"}}
\t\t\t\t\t  ,{0,{1/2,\" R[0]/2 \"},{1,\"R[0]\"}}}
\t\t,Epilog->Graphics[{PointSize[.03],Point[{2/3,1}]}][[1]]];\
\>", "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (b)  Find the solutions for R[t] and age for the model when \[Kappa]RW \
= 1  (closed).  Graph the results."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["eq3 = R'[t]^2 == -1 + 2 qo Ho^2 R[0]^3/R[t]", "Input"],

Cell["R0rule = {R[0]-> 1/Ho  Sqrt[1/(2 qo - 1)]}", "Input"],

Cell["eq4 = eq3/.R0rule//PowerExpand", "Input"],

Cell["change = R->((2 qo/(Ho(2 qo - 1)^(3/2))Sin[x[#]]^2)&)", "Input"],

Cell["scale1 = R[x]/.change/.x[x]->x//PowerExpand", "Input"],

Cell["eq4a = eq4/.change//Simplify", "Input"],

Cell["\<\
eq5 = Solve[eq4a,x'[t]][[2]]/.
(z_)^(3/2)->-I(-z)^(3/2)\
\>", "Input"],

Cell["time1 = Integrate[(1/x'[t]/.eq5),{x[t],0,x}]", "Input"],

Cell["solx = Solve[R[0]==scale1,x]/.R0rule//ExpandAll//PowerExpand", "Input"],

Cell["xage = solx[[2]]", "Input"],

Cell["age1 = time1/.xage//ExpandAll//Simplify", "Input"],

Cell["value = {Ho->1,qo->1}", "Input"],

Cell[TextData[
"label = Graphics[{PointSize[.03]\n\t\t\
,Text[FontForm[(time1/.xage/.value//N[#,2]&)\"/Ho==age\"\n\t\t\t\
,{\"Times-Roman\",10}],{2,1}]\n\t\t,Point[{time1/.x->\[Pi]/2/.value\n\t\t\t\t\
,scale1/.x->\[Pi]/2/.value}]\t\t\t\t\t\t\t\t,Point[{time1/.xage/.value\n\t\t\t\
\t,scale1/.xage/.value}]\t}];"], "Input"],

Cell[TextData[
"ParametricPlot[Evaluate[{time1,scale1}/.value],{x,0,\[Pi]}\n\t\t,Frame->True\
\n\t\t,PlotLabel-> \"Closed Model, qo=1\"\n\t\t\
,FrameLabel->{\"t\",\"R[t}\",\" \",\" \"}\n\t\t\
,FrameTicks->{{{0,\"Bang\"},{age1/.value//N,\"Now\"}\n\t\t\t\t\t  \
,{3*age1/.value//N,\"3*age\"}\n\t\t\t\t\t  \
,{time1/.value/.x->\[Pi]/2,\"max\"}\n\t\t\t\t\t  \
,{9*age1/.value//N,\"9*age\"}\n\t\t\t\t\t  \
,{time1/.value/.x->\[Pi],\"Crunch\"}}\n\t\t\t\t,{0,1/2,{1,\"R[0]\"},1.5,2}}\n\
\t\t,Epilog->label[[1]]\t];\n"], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Part (c)  Find the solutions for R[t] and age for the model when \[Kappa]RW \
= -1  (open).  Graph the results."], "Subsubsection",
  Background->GrayLevel[0.900008]],

Cell["eq6 = R'[t]^2 == 1 + 2 qo Ho^2 R[0]^3/R[t]", "Input"],

Cell["R0rule = {R[0]-> 1/Ho  Sqrt[1/(1 - 2 qo)]}", "Input"],

Cell["eq7 = eq6/.R0rule//PowerExpand", "Input"],

Cell["change = R->((2 qo/(Ho(1 -2 qo)^(3/2))Sinh[x[#]]^2)&)", "Input"],

Cell["scale2 = R[x]/.change/.x[x]->x//PowerExpand", "Input"],

Cell["eq7a = eq7/.change//Simplify", "Input"],

Cell["eq8 = Solve[eq7a,x'[t]][[2]]", "Input"],

Cell["time2 = Integrate[(1/x'[t]/.eq8),{x[t],0,x}]", "Input"],

Cell["solx2 = Solve[R[0]==scale2,x]/.R0rule//PowerExpand", "Input"],

Cell["xage = solx2[[2]]", "Input"],

Cell["age2 = time2/.xage", "Input"],

Cell["value = {Ho->1,qo->.02}", "Input"],

Cell["\<\
label = Graphics[{PointSize[.03]
\t\t,Text[FontForm[(time2/.xage/.value//N[#,2]&)\"/Ho==age\"
\t\t\t,{\"Times-Roman\",10}]
\t\t\t,{1.5 time2/.xage/.value,scale2/.xage/.value}]
\t\t,Point[{time2/.xage/.value
\t\t\t\t,scale2/.xage/.value}]\t}];\
\>", "Input"],

Cell["\<\
ParametricPlot[Evaluate[{time2,scale2}/.value],{x,0,3}
\t\t,Frame->True
\t\t,PlotLabel-> \"Open Model, qo=.02\"
\t\t,FrameLabel->{\"t\",\"R[t}\",\" \",\" \"}
\t\t,FrameTicks->{{{0,\"Bang\"}
\t\t\t\t\t  ,{age2/2/.value//N,\"1/2*age\"}
\t\t\t\t\t  ,{age2/.value//N,\"age\"}
\t\t\t\t\t  ,{1.5*age2/.value//N,\"3/2*age\"}
\t\t\t\t\t  ,{2*age2/.value//N,\"2*age\"}
\t\t\t\t\t  }
\t\t\t\t,{0,1/2,{1,\"R[0]\"},1.5,2}}
\t\t,Epilog->label[[1]]\t];
\
\>", "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1280}, {0, 968}},
WindowToolbars->{},
WindowSize->{575, 529},
WindowMargins->{{78, Automatic}, {Automatic, 38}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 134, 3, 121, "Title"],
Cell[1868, 56, 132, 3, 43, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2025, 63, 58, 1, 80, "Subtitle"],
Cell[2086, 66, 108, 2, 70, "Input"],
Cell[2197, 70, 96, 2, 30, "Input"],
Cell[2296, 74, 93, 2, 30, "Input"],
Cell[2392, 78, 90, 2, 30, "Input"],
Cell[2485, 82, 60, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2582, 88, 65, 1, 80, "Subtitle"],

Cell[CellGroupData[{
Cell[2672, 93, 100, 1, 69, "Section"],

Cell[CellGroupData[{
Cell[2797, 98, 134, 3, 63, "Subsection"],
Cell[2934, 103, 365, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[3324, 115, 181, 3, 76, "Subsubsection"],
Cell[3508, 120, 50, 0, 30, "Input"],
Cell[3561, 122, 73, 0, 30, "Input"],
Cell[3637, 124, 44, 0, 30, "Input"],
Cell[3684, 126, 61, 0, 30, "Input"],
Cell[3748, 128, 388, 9, 156, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4173, 142, 183, 3, 76, "Subsubsection"],
Cell[4359, 147, 60, 0, 30, "Input"],
Cell[4422, 149, 59, 0, 30, "Input"],
Cell[4484, 151, 47, 0, 30, "Input"],
Cell[4534, 153, 70, 0, 30, "Input"],
Cell[4607, 155, 60, 0, 30, "Input"],
Cell[4670, 157, 45, 0, 30, "Input"],
Cell[4718, 159, 80, 3, 48, "Input"],
Cell[4801, 164, 61, 0, 30, "Input"],
Cell[4865, 166, 77, 0, 30, "Input"],
Cell[4945, 168, 33, 0, 30, "Input"],
Cell[4981, 170, 56, 0, 30, "Input"],
Cell[5040, 172, 38, 0, 30, "Input"],
Cell[5081, 174, 322, 5, 138, "Input"],
Cell[5406, 181, 521, 9, 228, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5964, 195, 182, 3, 76, "Subsubsection"],
Cell[6149, 200, 59, 0, 30, "Input"],
Cell[6211, 202, 59, 0, 30, "Input"],
Cell[6273, 204, 47, 0, 30, "Input"],
Cell[6323, 206, 70, 0, 30, "Input"],
Cell[6396, 208, 60, 0, 30, "Input"],
Cell[6459, 210, 45, 0, 30, "Input"],
Cell[6507, 212, 45, 0, 30, "Input"],
Cell[6555, 214, 61, 0, 30, "Input"],
Cell[6619, 216, 67, 0, 30, "Input"],
Cell[6689, 218, 34, 0, 30, "Input"],
Cell[6726, 220, 35, 0, 30, "Input"],
Cell[6764, 222, 40, 0, 30, "Input"],
Cell[6807, 224, 267, 7, 120, "Input"],
Cell[7077, 233, 464, 14, 246, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

